%% Author: Lionel Feugère lionel.feugere@riseup.net
% institutions: MIVEGEC - Institut de Recherche pour le Développement, France
%               NRI - University of Greenwhich, UK

%%%%%%%%%%%%%%%% Context %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Matlab code for experiment about both-sex mosquitoes exposed to opposite-sex sound stimuli

%%%%%%%%%%%%%%%% Data dependence %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Sound and trackit raw data (8Go) available at https://doi.org/10.5061/dryad.9cnp5hqhj
% SPL_stim_mean_error.csv (<1Mo)
% metadata file data_181208.csv (<1Mo)

%%%%%%%%%%%%%%%% Function dependence %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% averagingOverEachObject.m  
% ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder.m
% plotSoundStimShapeAndXYZpos.m

%%%%%%%%%%%%%%%% What this code does%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1) Import the sounds
% 2) import the 3900Hz-bip sound time-location
%    Add the stimuli temporal shape (binary)
% 3) Split the sound into subreplicates
%    Plotting Sound and sync flag
% 4) Import the tracked trajectories
% 5) Remove too short flights and immobile mosquitoes
% 6) Trackit position Interpolation on same objects (in order to have a fixed sample frequency) + filling with NaN value in order to have a commun time vector for each subreplicate
% 7) Isolating Tracked Synchronization light indexes 
%    Detecting both onset and offset in synchIR_xyz_extrema=[0.69 -0.46 -0.46]; % minX, maxY, maxZ
% 8) Changing the TRackit time origin to 10-sec before the first stimuli onset (same as sound subreplicate)
    % Plot Trackit and subreplicate in synchrony  
% 9) importing the metadata file data_181208.csv with number of  mosquitoes swarming 1sec before and after sound stimulus onsets
% 10) Filter the trackit data. Removing the mosquitoes which
    % does not fly inside the control area 
    % does not fly long enough before/after each stimulus onset
% 11) Subreplicates split into stimuli sequences + mosquito filtering 
    % Split the subreplicates into stimuli sequences (10sec before the stim onset and 10sec after the stim offset) 
    % Plotting each stimulus feature on a different figure
% 12) Computing angular velocity
% 13) Computing WBF (and Number of swarming mosquitoes)
    % FFT parameters: Nfft size 2^(2+nextpow2(floor(wind_t_wbf_sec*fs))), FFT window hann(floor(wind_t_wbf_sec*fs));
    % Median filter lenght over time over 3 points
    % Plotting 1 figure per {stim, subreplicate}
% 14) Moving selected features to table (each feature(t) in a different row) 
    % add temperature
    % Window duration for the stat (averaged over that window): 
        % t_step=wind_t_wbf_sec;
    % Window start DurPause_sec -DurPause_sec
    % Window end:  DurPause_sec + DurStim_sec+ DurPause_sec
% 15) Generation of the table file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 



clear variables
close all
%% Structure where data is saved (before being exported into a table format)
% data()            .day (d01, ...)
%                   .sex
%                   .date
%                   .sound
%                   .fs
%                   .synchroSound             Energy above threshold (binary)
%                   .timeSoundRec_start       'HH:MN' time when sound recording starts
%                   .timeSoundRec_end         'HH:MN' time when sound recording ends
%                   .bip_index                1 line for each new subreplicate; 0 at 16h00 (absolute "16h00" from Sound time, by hand so not so precise)
%                        bip_index(:,1):      bip start (signaling the sequence's START)
%                        bip_index(:,2):      bip manually interrupted (synchro with LED)
%                        bip_index(:,3):      bip manually started again (synchro with LED)
%                        bip_index(:,4):      bip stopped
%                        bip_index(:,5):      bip start (signaling the sequence's END)
%                        bip_index(:,6):      bip manually interrupted (synchro with LED)
%                        bip_index(:,7):      bip manually started again (synchro with LED)
%                        bip_index(:,8):      bip stopped 
%                   .synchroSoundFlagIndex    Synchro sound index (middle of onset and offset of the synchro BIP) --  0 at 16h00 (absolute "16h00" from Sound time, by hand so not so precise)
%                   .stim_v                   stim_v(n° stimulus, [onset offset]) ; index of stimulus onset/offset with the origin at 10-sec-before the first onset of each subreplicate. Same values for each sex for all replicate.
%                   .durBeforeStimOnsetMin_sec  I the whole object is aways outside the interval [Duration before/after the stimulus onset], hte object is removed (no NaN in that area). THe reshults depends on the time window to which we apply it (won't be the ame results if we consider several stimuli or only 1 for ex, as the object is removed only if NONE of the data is inside these time intervals)
%                   .durAfterStimOnsetMin_sec   
%                   .swarmingArenaDim           If the whole object is outside this arena, we delete the object
%                   .subrep()               
%                                           .sound                  Sub replicate sound, 10sec before the first Stim onset and 10sec after the last silence offset (i.e. 20sec after the last stim offset)
%                                           .soundSynchIndex        subreplicate-local index of the synchro bip
%                                           .soundSynchFlagIndex    subreplicate-local index of the chosen synchro flag 
%                                           .timeStart              15h30 or 15h45 (removed)
%                                           .VidData_full(:,8)   
%                                                                   col 1   object
%                                                                   col 2   time (sec)
%                                                                   col 3   X (m)
%                                                                   col 4   Y (m)
%                                                                   col 5   Z (m)
%                                                                   col 6   X'(t) (m/s)
%                                                                   col 7   Y'(t)
%                                                                   col 8   Z'(t)
%                                           .date                   Date
%                                           .time                   Starting time of TRackit recording (HH:MM:SS)
%                                           .trackitSynchIndex_sec  INdex (second) of the middle of onset  and offset of the synchro LED (1st column: starting bip, 2nd column: ending bip )
%                                           .VidData_washed(:,8)  VidData_full without object which duration is less than trackingDurMin_sec and without immobile object
%                                           .washedParam                .trackingDurMin_sec;
%                                                                               Minimal duration of an object to be kept
%                                                                       .stdXYZMin
%                                                                                minimal standard std for all X, Y, Z positions in ordet o keep the object (wllows to remove immobile mosquitoes or when the background creates a fixed tracked position)
%                                           .VideoData_w_i(:,8)     VidData_washed with fixed sample frequency and same first and last time value for all the objects
%                                                                   col 1   object
%                                                                   col 2   time (sec), constant sample period over each object (fs=200Hz)
%                                                                   col 3   X (m)
%                                                                   col 4   Y (m)
%                                                                   col 5   Z (m)
%                                                                   col 6   X'(t) (m/s)
%                                                                   col 7   Y'(t)
%                                                                   col 8   Z'(t)
%                                           .VidData_sync(:,8)     VideoData_w_i with me index synchronized with sound, and subreplicate data removed if no synchro was possible
%                                                                   col 1   object
%                                                                   col 2   time (sec) synchronized with sound; t=0 corresponds to {10-sec before the first stimuli onset}
%                                                                   col 3   X (m)
%                                                                   col 4   Y (m)
%                                                                   col 5   Z (m)
%                                                                   col 6   X'(t) (m/s)
%                                                                   col 7   Y'(t)
%                                                                   col 8   Z'(t)
%                                           .VidData_JASO_swarmArena     VidData_sync with 2 additional condition, for each of the whole subreplicate
%                                                                        
%                                           .timeTrackSynch_sec     Commun time vector for all objects synchronized with the sound subreplicate
%                                                                   NaN means that no synchronization is possible.
%                                           .synchFlag              which LED ("starting-LED" or "ending-LED") or both is/are used for the synchronization
%                                                                   'bothLED', '1stLED', or '2ndLED'
%                                           .swarming               0 if none swarming during the subreplicate, 1 otherwise
%                                           .stimResp(n°Stim)     .sound(:,2)      1st col: sound amplitude
%                                                                                  2nd col: time vector (sample at fs)
%                                                                 .stimCode             Stimulus code (e.g 'fcn114')
%                                                                 .Nobjects             Number of swarming mosquitoes (by eye from CSVfile, or from Trackit)
%                                                                 .soundPeak    .pks(wind_index)
%                                                                               .locs(wind_index)
%                                                                               .width(wind_index)
%                                                                               .time_pks(wind_index)
%                                                                               .wind_t_wbf_sec
%                                                                               .coef_threshold_peak   ---> removed from current version (I now have a fixed amplitude threshold)
%                                                                               .MinPeakWidth (Hz)
%                                                                               .smoothingLength_Hz
%                                                                               .peak_fminfmax
%                                                                               .Nfft_sec
%                                                                               .Npeaks_sec: nhumber of peaks detected and over which we averaged
%                                                                 .VidData_stim [obj,time,X,Y,Z,VX,VY,VZ,avel]
%              
%           fem()   ... idem




%%%%% Parameters

folder_main='../type/soundProofChamber/dataAndExtractedFeatures/181000_exp1/data/';

fs=8000; % sound Sample frequency
folderSound_name='/sound/';
f_bip=3900; % bip frequency
read_start_mn=30; % from where we start reading the audio file after 15h30 % SHOULD NOT BE CHANGED
Nsubrep_mal=8; % max number  of subreplicates for males
Nsubrep_fem=10;  % max number  of subreplicates for females
sunset_start_time='15:30';
% Threshold parameters for detecting the 3900Hz pure sound and filtering the noise
    % thres_env = min(thres_env_coeff *  max(envelop3900Hz) , {thres_env})
    %thres_env_coeff=1/2;
    % with flying males:
    thres_env=2.4e-10; % empirical value working well with flying male (below that, false detection ocurs)
    thres_env_coeff=1/4; % coeff working for female

% Duration between the end of the "start" bip and the beginning of the "final" bip
Nstim_mal=16; %  female stimuli for experiment with live male
Nstim_fem=8; % male stimuli for experiment with live female
DurBip_sec=10; %sec
DurPause_sec=10;
DurStim_sec=7;
Dur_2bipOffset_mal_sec=(DurPause_sec+DurStim_sec)*Nstim_mal+DurBip_sec;    
Dur_2bipOffset_fem_sec=(DurPause_sec+DurStim_sec)*Nstim_fem+DurBip_sec;    


%%% PeakFinder settings
Numharm_mal_fem=[3 1]; % Harmonics to which we look
peak_fminfmax= [ 730*[Numharm_mal_fem(1) 1+Numharm_mal_fem(1)]; ...for males % we look a the 3rd harmonics
                 370 660]; %330 640]; % for females

% Criterion to be sure that  the mosquitoe swarms before the stimulus & at controlled distance from the speaker 
durBeforeStimOnsetMin_sec=1; % Minimal object duration before the stim onset below which objects are not kept
durAfterStimOnsetMin_sec=1; % Minimal object duration after the stim onset below which objects are not kept
swarmingArenaDim = [0.3 ; 0.3 ; 0.2 ] ;    
                   % Space beyond which mosquitoes are considered not at the correct distance from the speaker to be considered 
                   % It only applies if all the trajectoies are outside one of the XYZ boundaries
 
trackingDurMin_sec=1; % sec % Minimal duration below which objects are not kept
stdXYZMin=0.01; % cm ;  minimal standard std for all X, Y, Z positions in order to keep the object (wllows to remove immobile mosquitoes or when the background creates a fixed tracked position)             

% Peak detection parameters:
%smoothMethod='movmean';
%coef_threshold_peak=1.6; % coeff*mean(spectrum(peak_fmin:peak_fmax)) below which the spectrum peak is not corresponding to a peak
    % 1.5 set from female coluzzi on day10, subrep 5
MinPeakHeight=[0.0018 0.003];%0.004]; %     MinPeakHeight(1) for male, MinPeakHeight(2) for female; set empirically
wind_t_wbf_sec=0.04; % was 0.03 % was 0.1; % sec % time window length ; should be calculated as a function of fastest frequency in the mosquito WBF (which is RFM). From 
    % smallest RFM period is 83ms – 4 *2.1ms =75ms ==> wind_t_wbf_sec should be smallest than 75ms/2=37ms --> 30 ms for security  SimoesIngGibRus16
MinPeakWidth=7;% Hz , multiplied by the harmonic numero to be analyzed; if greater, then issues with females & male stimuli which overlap
%smoothingLength_Hz=10;  % Hz % audio file preprocessing: smoothing frequency band of the raw spectrum     
                        % multiplied by the harmonic numero to be analyzed
                        %  if greater than 20Hz, then issues with females & male stimuli which overlap
   

%trackit's data processing
fs_trackit= 200; % Hz ; Should be set to the TRackit-postprocessing sample frequency (at the end of this page, it will be sampled to the same as sound sampled freq (1/wind_t_wbf_sec))
interp_method='linear';

% Stim code list
stimCode_mal={'fcn220';'fcn222';'fcn213';'fcn223';'fcn224';   'fgn220';'fgn222';'fgn223';'fgn224';   'fcn121';'fcn122';'fcn113';'fcn123';'fcn124';   'fcs113';'fcs213'};
stimCode_fem={'mgn2a0';'mgn2a2';'mgn2a3';'mgn2a4';   'mcn2a0';'mcn2a2';'mcn2a3';'mcn2a4'};
stimCode={stimCode_mal,stimCode_fem};


% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );   
folderName_v=1:length(folderName);


%%% Manual 1st stimuli onset on each subreplicate
%stimOnset_sec{replicate}(subreplicate)
% manually checked on spectrogram with 128 points at fs=8000Hz (16ms window); measure
% uncertainty à 95%: ±0.02sec, using both the duration of the stim (7s)
% and the onset/offet of one of the loudest stim of the subreplicate
stimOnset_sec ={ ...
  [60*44+53.87     60*50+45.64       60*56+38.50      3600+60*2+37.84],...
  [60*44+20.50     60*50+54.28       60*56+39.48      3600+60*2+30.35    3600+60*8+22.29 3600*1+60*14+22.152],...
  [3600+60*5+8.11  3600+60*15+19.15  3600+60*25+44.09 3600+60*31+39.13], ...
  [60*42+27.41     60*47+37.57       3600+60*13+23.61 3600+60*0+19.34    3600+60*5+24.85     3600+60*20+56.53        3600+60*26+0.08    3600+60*31+12.01], ...
  [3600+36.36-17 3600+60*6+15.87-3*17 3600+60*15+49.31 3600+60*21+13.55-17 3600+60*28+33.04-17*9 3600+60*31+46.01-17*2],...
  [60*51+2.77      60*56+4.91        3600+60*5+24.32  3600+60*10+43.25    3600+60*18+34.28    3600+60*24+10.86-17*2  3600+60*29+10.52-17],...
  [60*43+14.29-17   60*47+59.84     60*54+0.55-17     60*58+52.33         3600+60*5+9.17-4*17 3600+60*9+5.77         3600+60*14+39.51    3600+60*22+49.69-3*17], ...
  [60*41+54.6       60*47+34.26     60*56+27.66-17    3600+60*1+48.44-2*17 3600+60*6+50.29-2*17 3600+60*23+8.9-17*2     ],...
  [60*44+0.06-2*17  60*51+4.24   3600+60*16+23.34-6*17 3600+60*21+2.47-3*17 3600+60*28+16.29],...
  [60*45+0.68      60*51+13.55-4*17 60*55+25.25-17    3600+31.09-17         3600+60*5+14.96    3600+60*11+29.23-17*3 3600+60*15+44.3],... male d14
  [60*33+49.86-3*17 60*35+55.54     60*39+56.1-3*17   60*41+56.89        60*44+45.8          60*48+30.77-3*17       60*50+51.53         60*54+27.97         60*57+14.35         3600+59.06-3*17],... female d01
  [60*47+49.76-2*17  60*50+12.49    60*53+51.15-3*17    60*55+54.5      60*59+42.44-3*17    3600+60*2+59.28-3*17   3600+60*4+58.39      3600+60*7+46.75     3600+60*10+43.83    3600+60*13+47.91],... female d02
  [60*59+20.65-3*17 3600+60*3+4.1-4*17 3600+60*6+34.1-17 3600+60*9+28.05 3600+60*13+51.15-17],... female d04
  [60*52+59.5-2*17 60*57+35.74-5*17 60*59+52.98     3600+60*2+50.82     3600+60*5+48.7      3600+60*9+25.04         3600+60*13+12.38-2*17 3600+60*15+31.32  3600+60*18+26.35    3600+60*21+55.66-17],... female d06
  [60*51+3.35       60*54+0.82      60*57+39.41     3600+60*1+46.05-2*17   3600+60*5+32.72-17 3600+60*8+37.38       3600+60*11+58.47-17  3600+60*15+22.75-2*17  3600+60*18+38.82-2*17   3600+60*21+50.72-3*17  ],... female d08
  [60*46+6.33   60*50+20.51-2*17    60*53+43.41-17  3600+60*8+4.52-5*17     3600+60*9+45.31     3600+60*12+33.98    3600+60*16+10.78-3*17   3600+60*18+12.21 3600+60*21+11.44   3600+60*23+59.91],... female d10
  [60*55+46.8   60*59+13.95-2*17    3600+60+59.18-2*17  3600+60*4+46.16     3600+60*9+58.01     3600+60*15+19.23    3600+60*18+37.39],... female d12
  [3600+60*2+52.44 3600+60*6+0.1-17 3600+60*9+34.62-3*17 3600+60*12+19.74-3*17 3600+60*14+57.18-2*17 NaN             NaN                 3600+60*23+35.92-17 NaN                 3600+60*29+34.28],... female d14
  [NaN          60*47+9.68-17       60*50+59.99-4*17    60*53+30.48-2*17    60*58+14.01-3*17    3600+60+16.43-4*17  3600+5*60+49.21-2*17    3600+60*8+57.07 3600+60*11+50.67    3600+60*17+39.86],... female d15
  [60*48+48.16-2*17 60*53+20.84-17  60*58+11.27-17  3600+60*2+39.53-17   3600+60*10+13.21-17    ],... female d16
  [NaN          3600+60*22+53.36-2*17 3600+60*28+13.3-17   NaN            3600+60*40+49.75-17],... female d18
  [NaN          60*52+29.92-2*17    60*55+37.4-2*17        NaN            3600+60*38+22.54-3*17],... female d19
  [3600+60*2+29.83-17 3600+60*6+17.06-17 3600+60*9+5.13 3600+60*13+49.04 3600+60*17+40.46-2*17 3600+60*23+28.91-4*17 3600+60*25+31.89   3600+60*28+42.16-17 3600+60*31+31.16-17 3600+60*34+52.81-3*17]... female d20
};
%%% 3900Hz-sound mid-offset and mid-onset.
% THe 3900Hz bip is a 10sec sound which is iterrupted inside for less than a second. 
%   The sound interruption trigger a LED light to switch on and then the interruption can be synhronized with the tracked LED light
%   Below is th eoffset and onset of the bip interruption
% BipSoundOffOnOnsets{1:Nday}{1:Nsubreplicate}(1:2 1 meaning before the subreplicate // 2 meaning after the subreplicate , 1:2 1 meaning first bip offset time // 2 meaning second bip onset time)
% NaN means that no Trackit data kept (from previous data filtering)
% By eye, using spectrogram computed with Hanning winfow of 64 samples (8ms). CI = ±8ms
BipSoundOffOnOnsets={...
 {[60*44+[45.28 46.18];60*49+[27.23 28.07]], [49*60+[27.23 28.08];60*55+[21.75 22.12]], [60*56+[30.27 30.93];61*60+[16.03 16.65]], [62*60+[28.70 30.18];67*60+[09.77 10.22]] },...d03 all 3sr
 {[60*44+[12.17 13.16];60*48+[54.26 54.97]], [50*60+[45.51 46.09];55*60+[24.12 24.71]], [56*60+[32.68 33.36];61*60+[09.14 09.81]], [62*60+[23.63 24.41];67*60+[03.69 04.25]], [68*60+[13.94 14.60];72*60+[54.57 55.22]], [74*60+[13.78 14.61];78*60+[52.38 52.97]] }, ...d04 all 6sr
 {[60*64+[59.99 60.98];69*60+[39.97 40.88]], [75*60+[11.28 12.27];79*60+[50.31 51.03]], [85*60+[37.06 37.96];90*60+[15.81 16.85]], [91*60+[31.31 32.09];96*60+[10.29 11.00]] },... d05 all 4 sr
 {[60*42+[18.54 19.21];47*60+[00.15 00.92]], [47*60+[28.87 29.83];52*60+[10.94 11.64]], [73*60+[14.81 16.11];77*60+[55.98 57.04]] }, ... d06 all (3)
 {[60*60+[10.55 11.53];64*60+[51.27 52.33]], [65*60+[15.96 16.89];69*60+[57.46 58.63]], [75*60+[40.71 42.23];80*60+[21.34 22.45]], [80*60+[48.03 49.29];85*60+[29.18 30.16]], [85*60+[51.39 52.57];90*60+[33.63 34.61]], [91*60+[02.90 03.61];95*60+[44.36 45.19]] },... d07 all 6sr
 {[60*50+[54.41 55.25];55*60+[34.89 36.05]], [55*60+[56.45 57.42];60*60+[37.01 38.09]], [65*60+[15.75 16.99];69*60+[57.27 58.56]], [70*60+[34.49 35.50];75*60+[15.53 16.61]], [78*60+[26.00 26.90];83*60+[07.00 07.81]], [83*60+[28.22 29.50];88*60+[08.85 09.70]], [88*60+[45.28 46.33];93*60+[26.92 28.18]] },...    d08 all 7sr
 {[60*42+[48.74 50.04];47*60+[29.37 31.42]], [47*60+[51.91 52.93];60*52+[32.28 33.36]], [53*60+[35.04 36.72];58*60+[15.92 17.15]], [58*60+[44.48 45.71];63*60+[25.06 26.01]], [63*60+[52.76 54.21];68*60+[34.71 35.69]], [68*60+[57.02 58.18];73*60+[37.91 38.89]], [74*60+[30.82 32.15];79*60+[11.73 13.35]], [81*60+[50.08 51.22];86*60+[31.90 32.87]] },...   d10 all 8sr
 {[60*41+[45.87 47.13];46*60+[26.23 27.72]], [47*60+[25.71 27.18];52*60+[07.77 08.88]], [56*60+[02.60 03.67];60*60+[42.68 43.95]], [61*60+[06.41 07.73];65*60+[46.95 48.59]], [66*60+[08.16 09.70];70*60+[49.50 51.62]], [82*60+[26.18 27.68];87*60+[07.05 08.44]] }, ... d11 all 6sr
 {[60*43+[17.04 18.45];47*60+[58.09 59.69]], [50*60+[55.61 56.83];55*60+[37.60 38.47]], [74*60+[32.83 34.21];79*60+[15.60 16.46]], [80*60+[02.69 03.70];84*60+[43.66 45.51]], [88*60+[07.96 09.12];92*60+[49.94 51.18]] },... d13 all 5sr
 {[60*44+[51.97 53.21];49*60+[33.11 34.54]], [49*60+[57.23 58.33];54*60+[39.18 40.37]], [54*60+[59.51 60.87];59*60+[40.75 41.76]], [60*60+[05.30 06.37];64*60+[46.01 47.56]],                                  NaN(2,2),                                  NaN(2,2), NaN(2,2) }, ... d14 1:4 NaN NaN NaN
 {[60*32+[50.95 51.80];35*60+[16.09 17.38]], [35*60+[47.51 48.37];38*60+[12.92 13.88]], [38*60+[56.66 57.65];41*60+[23.93 25.06]], [41*60+[48.26 49.85];44*60+[14.03 15.21]], [44*60+[37.41 38.31];47*60+[03.83 04.94]], [47*60+[32.04 33.27];49*60+[57.23 58.52]], [50*60+[43.55 44.41];53*60+[08.93 09.83]], [54*60+[19.54 20.81];56*60+[44.38 45.67]], [57*60+[05.79 07.38];59*60+[33.28 35.06]], [59*60+[59.91 61.55];62*60+[26.79 28.92]] },... d01 1:8 NaN NaN
 {[60*47+[07.17 08.40];49*60+[33.40 35.72]], [50*60+[03.62 04.53];52*60+[29.60 30.83]], [52*60+[52.14 53.48];55*60+[17.63 19.03]], [55*60+[45.82 47.17];58*60+[12.02 13.48]], [58*60+[42.77 44.76];61*60+[08.85 10.62]], [62*60+[00.88 02.13];64*60+[25.88 26.97]], [64*60+[49.72 51.02];67*60+[15.89 17.13]], [67*60+[38.21 39.65];70*60+[02.28 03.88]], [70*60+[35.44 37.59];73*60+[03.00 05.35]], [73*60+[39.39 40.67];76*60+[06.40 08.18]] },... d02 all 10sr
 {[58*60+[21.25 22.38];60*60+[47.15 48.41]], [61*60+[48.24 49.11];64*60+[16.20 17.60]], [66*60+[09.44 10.20];68*60+[34.45 36.03]], [69*60+[19.63 20.80];71*60+[45.66 46.83]], [73*60+[26.37 27.64];75*60+[52.28 53.33]] }, ... d04 all 5sr
 {                                 NaN(2,2),                                  NaN(2,2), [59*60+[44.41 45.37];62*60+[11.81 12.55]], [62*60+[42.11 43.32];65*60+[09.64 11.03]], [65*60+[40.37 41.71];68*60+[06.65 08.27]], [69*60+[17.32 19.14];71*60+[44.53 45.78]], [72*60+[30.66 31.82];74*60+[55.83 57.61]], [75*60+[23.14 24.50];77*60+[46.65 47.97]], [78*60+[18.02 19.16];80*60+[44.18 45.05]], [81*60+[30.51 32.01];83*60+[55.73 56.81]] },...   d06 NaN NaN 3:10
 {[50*60+[54.92 55.84];53*60+[21.91 23.33]], [53*60+[52.39 53.47];56*60+[18.71 20.97]], [57*60+[31.42 32.61];59*60+[58.32 60.30]], [61*60+[03.32 04.59];63*60+[29.75 31.79]], [65*60+[07.59 08.79];67*60+[33.16 34.72]], [68*60+[29.03 30.24];70*60+[55.59 57.34]], [71*60+[33.14 35.42];73*60+[59.17 61.25]], [74*60+[40.35 41.31];77*60+[03.95 05.09]], [77*60+[56.62 57.73];80*60+[23.62 25.77]], [80*60+[51.43 53.27];83*60+[17.76 19.48]] }, ...  d08 all 10sr
 {[60*45+[58.39 59.85];48*60+[23.96 25.40]], [49*60+[38.20 39.38];52*60+[04.70 05.93]], [53*60+[18.06 19.65];55*60+[44.91 46.22]], [66*60+[30.99 32.01];68*60+[57.03 58.36]], [69*60+[36.67 38.24];72*60+[03.02 04.52]], [72*60+[26.73 27.89];74*60+[51.03 52.24]], [75*60+[11.84 12.95];77*60+[37.10 38.32]], [78*60+[03.77 05.43];80*60+[28.74 30.38]], [81*60+[02.81 04.40];83*60+[28.93 31.16]], [83*60+[51.11 52.09];86*60+[17.11 18.12]] }, ... d10 all 10sr
 {[60*55+[37.85 38.97];58*60+[03.99 05.23]], [58*60+[31.14 32.40];60*60+[57.15 58.12]], [61*60+[17.14 18.60];63*60+[42.31 47.62]], [64*60+[37.17 38.18];67*60+[03.68 04.65]], [69*60+[49.10 50.46];72*60+[16.76 17.78]], [75*60+[10.40 11.36];77*60+[37.12 38.60]], [78*60+[28.69 30.20];80*60+[54.41 55.22]] },... d12 all 7
 {[60*62+[43.82 44.90];65*60+[09.82 11.09]], [65*60+[34.42 35.53];68*60+[01.84 03.22]], [68*60+[34.99 36.18];71*60+[01.13 03.25]], [71*60+[20.14 21.39];73*60+[46.58 48.14]], [74*60+[15.13 16.31];76*60+[40.67 41.80]],                                  NaN(2,2),                                  NaN(2,2), [83*60+[10.20 11.37];85*60+[33.80 34.64]],                                  NaN(2,2), [89*60+[26.35 27.20];91*60+[52.92 53.80]] },... d14 1:5 NaN NaN 8 NaN 10
 {                                 NaN(2,2), [46*60+[47.99 48.52];49*60+[10.80 12.01]], [49*60+[43.90 45.17];52*60+[09.97 11.04]], [52*60+[47.79 48.71];55*60+[15.52 16.96]], [57*60+[14.92 15.92];59*60+[41.25 42.46]], [59*60+[59.67 60.45];62*60+[26.28 27.65]], [65*60+[06.96 08.00];67*60+[32.25 33.38]], [68*60+[48.71 49.60];71*60+[11.91 13.11]], [71*60+[42.33 43.57];74*60+[09.78 11.04]], [77*60+[31.44 32.61];79*60+[58.54 59.57]] },... d15 NaN 2:10
 {[48*60+[05.60 06.48];50*60+[33.27 34.20]], [52*60+[55.28 56.29];55*60+[22.84 24.02]], [57*60+[45.78 46.76];60*60+[12.08 13.67]], [62*60+[14.22 15.26];64*60+[41.54 42.90]], [69*60+[48.09 49.18];72*60+[14.64 15.56]] }, ...   d16 all 5
 {[72*60+[17.45 18.59];74*60+[44.69 45.95]], [82*60+[10.45 11.56];84*60+[36.97 38.20]], [87*60+[48.04 49.34];90*60+[13.73 15.62]], [92*60+[40.04 41.30];95*60+[06.16 07.78]], [100*60+[24.01 25.00];102*60+[51.53 53.59]] },...    d18 NaN 2:3 NaN 5
 {                                 NaN(2,2), [47*60+[31.25 32.19];49*60+[56.31 57.26]], [51*60+[47.50 48.59];54*60+[14.47 15.75]],                                  NaN(2,2), [54*60+[55.23 56.49];57*60+[21.01 22.28]] },... d19 NaN 2:3 NaN 5
 {[62*60+[04.98 06.45];64*60+[29.13 30.97]], [65*60+[52.77 53.92];68*60+[17.38 18.40]], [68*60+[56.49 57.41];71*60+[22.68 25.74]], [73*60+[40.21 41.19];76*60+[06.48 08.39]], [76*60+[57.68 58.92];79*60+[24.97 26.47]], [82*60+[15.07 16.31];84*60+[40.56 41.86]], [85*60+[23.12 24.05];87*60+[49.32 50.50]], [88*60+[16.63 17.34];90*60+[40.82 41.68]], [91*60+[05.28 06.11];93*60+[33.30 34.58]], [93*60+[53.73 54.99];96*60+[21.29 22.77]] }}; % d20 all 10

%% Looking for any typing errors in BipSoundOffOnOnsets:
figure,
s1=subplot(2,1,1);
s2=subplot(2,1,2);
% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' ); 
folderName_v=1:length(folderName) ;   
legend_v=[];
color_v=hsv(length(folderName_v));
for foldNam_ind=folderName_v
        temp=cell2mat(BipSoundOffOnOnsets{foldNam_ind});
        hold(s1,'on'), plot(s1,0.5+(1:size(temp,2))/2, temp(1,:),0.5+(1:size(temp,2))/2, temp(2,:),'color',color_v(1+foldNam_ind-folderName_v(1),:));
        xlabel(s1,'subreplicate index')
        ylabel(s1,'Bip interruption offset/onset manually measured from spectrogram (s)')
        temp2=[];
        for indi=1:2:size(temp,2)
            temp2(1:2,indi)=diff(temp(:,indi : indi+1),1,2);
        end
        hold(s2,'on'), plot(s2,0.5+(1:size(temp2,2))/2, temp2(1,:),0.5+(1:size(temp2,2))/2, temp2(2,:),'color',color_v(1+foldNam_ind-folderName_v(1),:));
        xlabel(s2,'subreplicate index')
        ylabel(s2,'Duration of bip interruption manually measured from spectrogram, (s)')
        legend_v{1+2*(foldNam_ind-folderName_v(1))}=[ 'Replicate index ' num2str(foldNam_ind)];
        legend_v{2+2*(foldNam_ind-folderName_v(1))}='';
        
end
legend(legend_v,'FontSize',5);
print(gcf,strcat(folder_main,'../','_general_analysis','/1_bipDetection_check/','bipManualMeasurement','.pdf'),'-dpdf','-r0')
saveas(gcf,strcat(folder_main,'../','_general_analysis','/1_bipDetection_check/','bipManualMeasurement','fig'))

%% Importing sound and saving synchronization bip sound indexes              
     
% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );  
for foldNam_ind=folderName_v % for each replicate (i.e. day)
    disp(['Loading sound file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
    audio_str=dir(strcat(folder_main,folderName(foldNam_ind).name,folderSound_name,'*.wav'));
    [fullAudio,fss]= audioread(strcat(audio_str.folder,'/',audio_str.name) );
    if fss~= fs
        error(['The Sampling frequency of file ' folderName(foldNam_ind).name ' is different from ' num2str(fs)])
    end
    
    data(foldNam_ind).sex=folderName(foldNam_ind).name(8:10); 
    data(foldNam_ind).date=folderName(foldNam_ind).name(1:6);
    data(foldNam_ind).day=folderName(foldNam_ind).name(16:18);
    data(foldNam_ind).timeSoundRec_start=audio_str.name(20:24);
    data(foldNam_ind).sound=fullAudio;    
    data(foldNam_ind).fs=fs;
    
    % Extracting the bip sound indexes:
    time_start_absolute_mn = - str2double(sunset_start_time(1:2)) ...
                            - str2double(sunset_start_time(4:5)) ...
                            + str2double(data(foldNam_ind).timeSoundRec_start(1:2))...
                            + str2double(data(foldNam_ind).timeSoundRec_start(4:5)) ;
                                 % in general 15h30, but sometimes 15h45
    time_read_offset_mn = read_start_mn - time_start_absolute_mn;    
       
    
    Nsubrep=size(BipSoundOffOnOnsets{foldNam_ind},2); % number of subreplicate
    BipInterruptionOnsetOffset=cell2mat(BipSoundOffOnOnsets{foldNam_ind});
    
    bip_index=[];
    bip_index(:,1)=NaN(Nsubrep,1); %       bip start (signaling the sequence's START)
        % can be computed from automatic algo (see below, but not used in the manual measurement)
    bip_index(:,2)=(BipInterruptionOnsetOffset(1,1:2:end)- time_read_offset_mn*60)*fs;%      bip manually interrupted (synchro with LED)
    bip_index(:,3)=(BipInterruptionOnsetOffset(1,2:2:end)- time_read_offset_mn*60)*fs;%      bip manually started again (synchro with LED)
    bip_index(:,4)=NaN(Nsubrep,1); %      % bip stopped
        % can be computed from automatic algo (see below, but not used in the manual measurement)
    bip_index(:,5)=NaN(Nsubrep,1); %      bip start (signaling the sequence's END)
        % can be computed from automatic algo (see below, but not used in the manual measurement)
    bip_index(:,6)=(BipInterruptionOnsetOffset(2,1:2:end)- time_read_offset_mn*60)*fs;%      bip manually interrupted (synchro with LED)
    bip_index(:,7)=(BipInterruptionOnsetOffset(2,2:2:end)- time_read_offset_mn*60)*fs;%      bip manually started again (synchro with LED)
    bip_index(:,8)=NaN(Nsubrep,1); %      bip stopped     
        % can be computed from automatic algo (see below, but not used in the manual measurement)
    
    data(foldNam_ind).bip_index = bip_index;
    data(foldNam_ind).synchroSoundFlagIndex = ... Index at half distance between the onset and offset of bip sound (1st column: starting bip, 2nd column: ending bip)
        data(foldNam_ind).bip_index(:,[2 6])+ (data(foldNam_ind).bip_index(:,[3 7])-data(foldNam_ind).bip_index(:,[2 6]))/2; 


end



%% Add the stimuli temporal shape (binary) to the structure for each replicate 

% Temporal Shape of the stimuli
stim_shape_mal_sec =  DurBip_sec+...
                        [(0:(Nstim_mal-1))'*(DurStim_sec+DurPause_sec) ,...
                         (0:(Nstim_mal-1))'*(DurStim_sec+DurPause_sec)+DurStim_sec ];
stim_shape_fem_sec =   DurBip_sec+...
                        [ (0:(Nstim_fem-1))'*(DurStim_sec+DurPause_sec) ,...
                          (0:(Nstim_fem-1))'*(DurStim_sec+DurPause_sec)+DurStim_sec ];

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );      
for foldNam_ind=folderName_v
    disp(['   Replicate from file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);

    if data(foldNam_ind).sex=='mal'
        data(foldNam_ind).stim_v=stim_shape_mal_sec;
    elseif data(foldNam_ind).sex=='fem'
        data(foldNam_ind).stim_v=stim_shape_fem_sec;
    else
        error(' ')
    end

%    end
end





%% 3) Split the sound in subreplicates
disp(['Splitting sound files']);

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );   

for foldNam_ind=folderName_v
% if wanting to have an indepent FOR from above, change fullAudio by "data(foldNam_ind).sound" and uncomment the
% assignment of data(foldNam_ind).sound above.

    disp(['   file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
    time_start_absolute_mn = - str2double(sunset_start_time(1:2)) ...
                            - str2double(sunset_start_time(4:5)) ...
                            + str2double(data(foldNam_ind).timeSoundRec_start(1:2))...
                            + str2double(data(foldNam_ind).timeSoundRec_start(4:5)) ;
                                 % in general 15h30, but sometimes 15h45
    time_read_offset_mn = read_start_mn - time_start_absolute_mn;
    
    
    bip=data(foldNam_ind).bip_index;
    synchroSoundFlagIndex=data(foldNam_ind).synchroSoundFlagIndex;
    Nsubrep=size(bip,1 );
    for subrep_index=1:Nsubrep
        disp(['   Subreplicate sound n°' num2str(subrep_index) '/' num2str(Nsubrep)]);
                
        % subreplicate sound (new method, by starting the subreplicate sound by the manually-extracted index)
        indexSubrep_start=stimOnset_sec{foldNam_ind}(subrep_index)*fs-DurBip_sec*fs;
     
        if ~isnan(indexSubrep_start)

            if data(foldNam_ind).sex=='mal'
                indexSubrep_end=indexSubrep_start + (DurBip_sec+(DurStim_sec+DurPause_sec)*Nstim_mal+DurBip_sec)*fs -1;
            elseif data(foldNam_ind).sex=='fem'
                indexSubrep_end=indexSubrep_start + (DurBip_sec+(DurStim_sec+DurPause_sec)*Nstim_fem+DurBip_sec)*fs -1;
            else
                error(['Check data(' num2str(foldNam_ind) ').sex which should be either ''mal'' or ''fem''']);
            end
            data(foldNam_ind).subrep(subrep_index).sound = ...   
                data(foldNam_ind).sound(indexSubrep_start:indexSubrep_end);
            % subreplicate-relative index of the two 3900Hz manual cuts (i.e. synchro IR light Off):
            data(foldNam_ind).subrep(subrep_index).soundSynchIndex  =...  % To understand, make a draw
                [DurBip_sec*fs-...
                (stimOnset_sec{foldNam_ind}(subrep_index)*fs-... % first stimulis onset index (in the full-sound coordinate)
                time_read_offset_mn*60*fs-... to make the diff between full-sound coordinate aand 16h-origin coordinate
                synchroSoundFlagIndex(subrep_index,1)),... in the 16h-origin sound coordinate
                synchroSoundFlagIndex(subrep_index,2)+... in the 16h-origin sound coordinate
                DurBip_sec*fs-... 
                stimOnset_sec{foldNam_ind}(subrep_index)*fs+...
                time_read_offset_mn*60*fs]; %to make the diff between full-sound coordinate aand 16h-origin coordinate

        else % The sound exists but there is no mosquito swarming no useless
            data(foldNam_ind).subrep(subrep_index).sound = NaN;
            % subreplicate-relative index of the two 3900Hz manual cuts (i.e. synchro IR light Off):
            data(foldNam_ind).subrep(subrep_index).soundSynchIndex=[NaN NaN]; % we remove the index onset to the subreplicate synch index

       end
    end
end

clear bip
    

    
%%    Plotting Sound and sync flag
for foldNam_ind=folderName_v
    disp(['   Plotting subreplicates from file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
    Nsubrep=length(data(foldNam_ind).subrep);
    axis_subp=[];
    figure
    for subrep_index=1:Nsubrep
        axis_subp(subrep_index)=subplot(Nsubrep,1,subrep_index);
        sound_subreplicate= data(foldNam_ind).subrep(subrep_index).sound;
        time_subreplicate_min=(0:length(sound_subreplicate)-1)/fs/60;
        time_soundSynch_min = data(foldNam_ind).subrep(subrep_index).soundSynchIndex/fs/60 ;%+ index_subreplicate;
        hold on, plot(time_subreplicate_min ,sound_subreplicate);
        hold on, plot(time_soundSynch_min,[0 0],'o');
        %title(['Starting at ' data(foldNam_ind).subrep(subrep_index).timeStart] );
        
        % datestr(time_hour,'HH:MM:SS.FFF)
        if subrep_index ~=Nsubrep
            set(axis_subp(subrep_index),'xticklabel',{[]})
        end
    end
    suplabel([data(foldNam_ind).sex ' ' data(foldNam_ind).date ' ' data(foldNam_ind).day] ,'t');
    suplabel('Time (mn)','x');
    suplabel('sound pressure','y');
    for subrep_index=1:Nsubrep
        if data(foldNam_ind).sex=='mal'
            xlim(axis_subp(subrep_index),[0 (2*DurBip_sec+Nstim_mal*(DurPause_sec+DurStim_sec))/60])
        else
            xlim(axis_subp(subrep_index),[0 (2*DurBip_sec+Nstim_fem*(DurPause_sec+DurStim_sec))/60])
        end
    end
    set(gcf,'Units','Inches');
    pos = get(gcf,'Position');
    set(gcf,'PaperPositionMode','Auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])
    print(gcf,strcat(folder_main,'../','_general_analysis','/2_subreplicates_check/','subreplicates_check_',folderName(foldNam_ind).name,'.pdf'),'-dpdf','-r0')
   
    close
end

clear sound_subreplicate



%% Releasing memory: removing data().sound

disp('Releasing memory: removing data().sound');
data=rmfield(data,'sound');
%data=rmfield(data,'synchroSound');

 
%% 4) Importing tracked trajectories

disp('Importing tracked trajectories');
% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );    

for foldNam_ind=folderName_v
     %folderNameTrackit=keepOnlyFilesAndFolders(dir(strcat(folder_main,folderName(foldNam_ind).name,'/trackit/')),1); % remove special files

    disp(['   file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
     
     
    % We remove the folders without .csv files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );    
    
    for foldNamTrac_ind=1:length(folderNameTrackit) 
 
        files1 = dir(strcat(folder_main,...
                            folderName(foldNam_ind).name,...
                            '/trackit/',...
                            folderNameTrackit(foldNamTrac_ind).name,...
                            '/PostProc_Filtered_*Splined.csv'));
        files1_index=1;
        if isempty(files1)==1
            %error('No file. Check the path file and file name');
        end        
        
       data(foldNam_ind).subrep(foldNamTrac_ind).VidData_full = ...
           dlmread( strcat(folder_main,...
                            folderName(foldNam_ind).name,...
                            '/trackit/',...
                            folderNameTrackit(foldNamTrac_ind).name,...
                            '/',files1(files1_index).name) ...
                    ,';', 1, 0);     
       data(foldNam_ind).subrep(foldNamTrac_ind).date=folderNameTrackit(foldNamTrac_ind).name(1:10);    
       data(foldNam_ind).subrep(foldNamTrac_ind).time=folderNameTrackit(foldNamTrac_ind).name(12:19);
       
    end
end

%% Saving data
disp('Saving data to computer...');
save(strcat(folder_main,'_1_sounds-trackedFlights-soundTimeFlags_',date),'data','-v7.3' );

%%
load('/Users/lionel/Lionoil/Recherche/1703_IRD_anofeel/experiments/soundExperiments/type/soundProofChamber/dataAndExtractedFeatures/181000_exp1/data/_1_sounds-trackedFlights_soundTimeFlags_26-Nov-2019.mat');



%% 5) Remove of too short flight and immobile mosquitoes
disp('Removal of too short flight and immobile mosquitoes');

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );    
for foldNam_ind=folderName_v
    disp(['   file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
    
    % We remove the folders without .csv files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );    
    
    for foldNamTrac_ind=1:length(folderNameTrackit) 

        VidData_2 = data(foldNam_ind).subrep(foldNamTrac_ind).VidData_full;
        
        row_previous=0;
        VidData=[];
        row_tot=0;
        for object_ind=unique(VidData_2(:,1))'

            row=find(VidData_2(:,1)==object_ind);

            
            if max(VidData_2(row,2)) - min(VidData_2(row,2)) >= trackingDurMin_sec... % flight duration condition
                 ...   %&&  any(VidData_2(row(:),5) > Zmin)==1 ...
                 && all(nanstd(VidData_2(row,3:5))>stdXYZMin)==1 % to remove the landed mosquitoes

                row_tot =  row_tot+length(row_previous); 
                VidData( row_tot :...
                            row_tot+length(row)-1,1)=object_ind * ones(length(row),1) ;
                VidData(  row_tot:...
                            row_tot+length(row)-1,2:size(VidData_2,2))=VidData_2(row,2:end);
               row_previous=row;
            end    
        end

        if isempty(VidData)==1
            warning( 'No data: try decreasing trackingDurMinForPlot value');
            data(foldNam_ind).subrep(foldNamTrac_ind).VidData_washed=NaN;

        end

        data(foldNam_ind).subrep(foldNamTrac_ind).VidData_washed = VidData;
        data(foldNam_ind).subrep(foldNamTrac_ind).washedParam.trackingDurMin_sec=trackingDurMin_sec;
        data(foldNam_ind).subrep(foldNamTrac_ind).washedParam.stdXYZMin=stdXYZMin;

        %color_map=rand(length(unique(VidData(:,1))),3);
    end
end

clear VidData_2
clear VidData


%% 6) Trackit position Interpolation on same objects (in order to have a fixed sample frequency) + filling with NaN value i order to have a commun time vector for each subreplicate
disp('Trackit position Interpolation');

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );    
for foldNam_ind=folderName_v
    disp(['   replicate ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
     
    % We remove the folders without .csv files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );    
                        
                        
    for foldNamTrac_ind=1:length(folderNameTrackit) 
        disp(['     subreplicate ' num2str( foldNamTrac_ind) '/' num2str(length(folderNameTrackit))]);

        VidData_int_temp=[];
        warning('off');
        VidData =      data(foldNam_ind).subrep(foldNamTrac_ind).VidData_washed;
        VidData_full = data(foldNam_ind).subrep(foldNamTrac_ind).VidData_full;

        if isempty(VidData)==0
            % Building a commun time vector for each subreplicate for all
            % object. The time-value without data will be filled by NaN
            % values
            % We work from VidData_full and not VidData because we want the LEDoff detection included in the time vector
            Tdeb_allObj = round( min(VidData_full(:,2)) / (1/fs_trackit) ) * (1/fs_trackit) ; 
            Tfin_allObj = round( max(VidData_full(:,2)) / (1/fs_trackit) ) * (1/fs_trackit)  ;        
            timeTrack_sec=Tdeb_allObj:1/fs_trackit:Tfin_allObj;
            data(foldNam_ind).subrep(foldNamTrac_ind).timeTrack_sec=timeTrack_sec; 

            object_ind_new=0;
            for object_ind=unique(VidData(:,1))' % Now we work back from VidData
                % only the row of the object object_ind
                row=find(VidData(:,1)==object_ind); 
                    object_ind_new=object_ind_new+1;

                if length(row)>1 % otherwise the interpolation can not work (requires at least 2 sample point)
                    VidData_object_int = [ floor(ones(length(timeTrack_sec),1)*object_ind_new),...
                                 timeTrack_sec',...
                                 interp1(VidData(row,2),VidData(row,3), timeTrack_sec',interp_method ) ,... % interpolated X
                                 interp1(VidData(row,2),VidData(row,4), timeTrack_sec',interp_method ) ,... % interpolated Y
                                 interp1(VidData(row,2),VidData(row,5), timeTrack_sec',interp_method ) ,...      % interpolated Z
                                 interp1(VidData(row,2),VidData(row,6), timeTrack_sec',interp_method ) ,... % interpolated X'
                                 interp1(VidData(row,2),VidData(row,7), timeTrack_sec',interp_method ) ,... % interpolated Y'
                                 interp1(VidData(row,2),VidData(row,8), timeTrack_sec',interp_method )];      % interpolated Z'
                    VidData_int_temp=[VidData_int_temp ; VidData_object_int];
                end

            end
            warning('on')

            data(foldNam_ind).subrep(foldNamTrac_ind).VideoData_w_i =  VidData_int_temp;
        else
            data(foldNam_ind).subrep(foldNamTrac_ind).VideoData_w_i =  [];
        end
    end
end

clear VidData
clear VidData_int_temp
clear VidData_full
clear VidData_object_int
clear row
clear timeTrack_sec


%% Releasing memory: removing data().subrep().VidData_washed

disp(['Releasing memory: removing data().subrep().VidData_washed']);

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );
for foldNam_ind=folderName_v
         data(foldNam_ind).subrep=rmfield(data(foldNam_ind).subrep,'VidData_washed');
end

%% Saving data
disp('Saving data to computer...');
save(strcat(folder_main,'_2_withPostProcessedTrackit_',date),'data','-v7.3' );


%%
disp('Loading data...')
load('/Users/lionel/Lionoil/Recherche/1703_IRD_anofeel/experiments/soundExperiments/type/soundProofChamber/dataAndExtractedFeatures/181000_exp1/data/_2_withPostProcessedTrackit_.mat')



%% 7) Isolating Tracked Synchronization light indexes  ==> use non-interpolated data ".subrep"
% Detecting both onset and offset
disp('Extracting synch light');

synchIR_xyz_extrema=[0.69 -0.46 -0.46]; % minX, maxY, maxZ
timeIntOnsetOffset_min= 5/fs_trackit; % Minimal value for the Synchro ojects ; 5 times the image time period

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );    
                    
for foldNam_ind=folderName_v
    disp(['   Looking for synch light' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);

    % We remove the folders without .csv files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );    
    
    if strcmp(data(foldNam_ind).sex,'mal')==1 
        Dur_2bipOffset_sec=Dur_2bipOffset_mal_sec;
        %check_duration_sec=check_duration_sec_mal;
    elseif strcmp(data(foldNam_ind).sex,'fem')==1
        Dur_2bipOffset_sec=Dur_2bipOffset_fem_sec;
        %check_duration_sec=check_duration_sec_fem;
    end        
    
    % Checking that the number of subreplicate for the sound and for Trackit are the same
    if length(folderNameTrackit)~=length(data(foldNam_ind).subrep)
        error('Check the Trackit file: 1 folder is likely to be extra')
    end
    
                        
    for foldNamTrac_ind=1:length(folderNameTrackit) 
        
        % We assume only the IR light can be found in synchIR_xyz_extrema area :
        row=(  data(foldNam_ind).subrep(foldNamTrac_ind).VidData_full(:,3)>synchIR_xyz_extrema(1) ...
            & data(foldNam_ind).subrep(foldNamTrac_ind).VidData_full(:,4)<synchIR_xyz_extrema(2) ...
            & data(foldNam_ind).subrep(foldNamTrac_ind).VidData_full(:,5)<synchIR_xyz_extrema(3));
        % The indexes in seconds where the synch-IR is tracked:
        trackedLEDoff_sec = data(foldNam_ind).subrep(foldNamTrac_ind).VidData_full(row,2);
        % Is is supposed to be composed of two ensembles of indexes
        % separated by approximately Dur_2bipOffset_sec, then we llok for
        % the second ensemble :
         if isempty(trackedLEDoff_sec)==1 % If no LEDoff were tracked
            trackedLEDOff_1stSwitchOFF_onset_sec=NaN;
            trackedLEDOff_2ndSwitchOFF_onset_sec=NaN;
            trackedLEDOff_1stSwitchOFF_offset_sec=NaN;
            trackedLEDOff_2ndSwitchOFF_offset_sec=NaN;
            disp(['      none synch light for subreplicate '  num2str(foldNamTrac_ind)]);
         else % If at least 1 LEDoff was tracked
            trackedLEDOff_1stSwitchOFF_sec = trackedLEDoff_sec(trackedLEDoff_sec <  Dur_2bipOffset_sec-DurBip_sec); % we look at the next onset
            trackedLEDOff_2ndSwitchOFF_sec = trackedLEDoff_sec(trackedLEDoff_sec >  Dur_2bipOffset_sec-DurBip_sec); % we look at the next onset
            % If only the first LEDoff was tracked:
            if ~isempty(trackedLEDOff_1stSwitchOFF_sec)  && isempty(trackedLEDOff_2ndSwitchOFF_sec)
                % onsets:
                trackedLEDOff_1stSwitchOFF_onset_sec=trackedLEDOff_1stSwitchOFF_sec(1);
                trackedLEDOff_2ndSwitchOFF_onset_sec=NaN;
                % offsets:           
                temp1= (diff(trackedLEDOff_1stSwitchOFF_sec) > timeIntOnsetOffset_min); % time value indexes which changes more than timeIntOnsetOffset_min
                if any(temp1)==1
                    temp2=trackedLEDOff_1stSwitchOFF_sec(temp1); % index to seconds
                    trackedLEDOff_1stSwitchOFF_offset_sec=temp2(1); % first value (in case there are several)
                else
                    trackedLEDOff_1stSwitchOFF_offset_sec=trackedLEDOff_1stSwitchOFF_sec(end);
                end
                trackedLEDOff_2ndSwitchOFF_offset_sec=NaN;
                disp(['      missing the 2nd synch light for subreplicate '  num2str(foldNamTrac_ind) ' -- 1st LEDoff: ' num2str(trackedLEDOff_1stSwitchOFF_onset_sec) 'sec']);
            % If the first LEDoff was tracked only
            elseif isempty(trackedLEDOff_1stSwitchOFF_sec)  && ~isempty(trackedLEDOff_2ndSwitchOFF_sec)
                % onsets
                trackedLEDOff_1stSwitchOFF_onset_sec=NaN;
                trackedLEDOff_2ndSwitchOFF_onset_sec=trackedLEDOff_2ndSwitchOFF_sec(1);
                % offsets:
                trackedLEDOff_1stSwitchOFF_offset_sec=NaN;                                
                temp1= (diff(trackedLEDOff_2ndSwitchOFF_sec) > timeIntOnsetOffset_min); % time value indexes which changes more than timeIntOnsetOffset_min
                if any(temp1)==1
                    temp2=trackedLEDOff_2ndSwitchOFF_sec(temp1); % index to seconds
                    trackedLEDOff_2ndSwitchOFF_offset_sec=temp2(1); % first value (in case there are several)
                else
                    trackedLEDOff_2ndSwitchOFF_offset_sec=trackedLEDOff_2ndSwitchOFF_sec(end);
                end
                disp(['      missing the 1st synch light for subreplicate '  num2str(foldNamTrac_ind) ' -- 2nd LEDoff: ' num2str(trackedLEDOff_2ndSwitchOFF_onset_sec) 'sec']);
            % If both were tracked
            else
                % onsets
                trackedLEDOff_1stSwitchOFF_onset_sec=trackedLEDOff_1stSwitchOFF_sec(1);
                trackedLEDOff_2ndSwitchOFF_onset_sec=trackedLEDOff_2ndSwitchOFF_sec(1);
                % offsets:
                temp1= (diff(trackedLEDOff_1stSwitchOFF_sec) > timeIntOnsetOffset_min); % time value indexes which changes more than timeIntOnsetOffset_min
                if any(temp1)==1
                    temp2=trackedLEDOff_1stSwitchOFF_sec(temp1); % index to seconds
                    trackedLEDOff_1stSwitchOFF_offset_sec=temp2(1); % first value (in case there are several)
                else
                    trackedLEDOff_1stSwitchOFF_offset_sec=trackedLEDOff_1stSwitchOFF_sec(end);
                end
                temp1= (diff(trackedLEDOff_2ndSwitchOFF_sec) > timeIntOnsetOffset_min); % time value indexes which changes more than timeIntOnsetOffset_min
                if any(temp1)==1
                    temp2=trackedLEDOff_2ndSwitchOFF_sec(temp1); % index to seconds
                    trackedLEDOff_2ndSwitchOFF_offset_sec=temp2(1); % first value (in case there are several)                
                else
                    trackedLEDOff_2ndSwitchOFF_offset_sec=trackedLEDOff_2ndSwitchOFF_sec(end); % first value (in case there are several)                
                end
            end
         end
        % Wee keep the middle of the onset-offset for the two synch objects. These two synch indexes are saved (here in sec)
        data(foldNam_ind).subrep(foldNamTrac_ind).trackitSynchIndex_sec =...
            [trackedLEDOff_1stSwitchOFF_onset_sec + (trackedLEDOff_1stSwitchOFF_offset_sec - trackedLEDOff_1stSwitchOFF_onset_sec)/2, ...
             trackedLEDOff_2ndSwitchOFF_onset_sec + (trackedLEDOff_2ndSwitchOFF_offset_sec - trackedLEDOff_2ndSwitchOFF_onset_sec)/2];
        %data(foldNam_ind).subrep(foldNamTrac_ind).Video_
         
    end    
        
end


figure
for foldNam_ind=folderName_v
    % We remove the folders without .csv files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );          
                 
    for foldNamTrac_ind=1:length(folderNameTrackit) 
   
      hold on, plot(foldNam_ind,  data(foldNam_ind).subrep(foldNamTrac_ind).trackitSynchIndex_sec(1),...
                    foldNam_ind,  data(foldNam_ind).subrep(foldNamTrac_ind).trackitSynchIndex_sec(2),'.')
        
    end
end
xlabel('Replicate index')
ylabel('Time (sec)')
title('Trackit sync flag time for each subreplicate of each replicate')
print(gcf,strcat(folder_main,'../','_general_analysis','/3_synchronizedAudioTraj_check/','_TrackitSyncFlagLookForOutliers_',date,'.pdf'),'-dpdf','-r0')   
        

%% Manual checking led  removal of some tracked synch LEDoff 
%(col1: replicate number, col2: subreplicate number, col3: 1st-LED-off to be removed?, col4: 2nd-LED-off to be removed? :
% !!!!! should be updated if the trackit deteection changed for whatever change of parameters
trackitSynchIndex_toBeRemoved = [ 1 3 1 1; ... removed as LEDoff flikers
                                  1 4 1 0; ... removed as 1st bip lasts 12sec (?!)
                                  10 5 1 1; ... LEDoff continously detected
                                  10 6 1 1;... LEDoff continously detected
                                  10 7 1 1;... LEDoff continously detected
                                  11 9 1 1; ... LEDoff continously detected . %%TO BE CHECKED% 
                                  11 10 1 1; ... the unic LEDoff is too long %%TO BE CHECKED
                                  14 1 1 1;...LEDoff continously detected
                                  14 2 1 1;...LEDoff continously detected
                                  18 6 1 1;...LEDoff continously detected
                                  18 7 1 1;...LEDoff continously detected
                                  19 1 1 1;...LEDoff continously detected
                                  20 5 1 0];% LEDoff continously detected
%                                  22 6 1 1]; % LEDoff too long to be possible
                              
for tstbr_index=1:size(trackitSynchIndex_toBeRemoved,1)
    if trackitSynchIndex_toBeRemoved(tstbr_index,3)==1
        data( trackitSynchIndex_toBeRemoved(tstbr_index,1)).subrep(trackitSynchIndex_toBeRemoved(tstbr_index,2)).trackitSynchIndex_sec(1) = NaN;
    end
    if trackitSynchIndex_toBeRemoved(tstbr_index,4)==1
        data( trackitSynchIndex_toBeRemoved(tstbr_index,1)).subrep(trackitSynchIndex_toBeRemoved(tstbr_index,2)).trackitSynchIndex_sec(2) = NaN;
    end
end
disp('   Manual correction done')



%% Releasing memory: removing data().subrep().VidData_full

disp(['Releasing memory: removing data().subrep().VidData_full']);

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );   

for foldNam_ind=folderName_v
         data(foldNam_ind).subrep=rmfield(data(foldNam_ind).subrep,'VidData_full');
end




%% 8) Changing the TRackit time origin to 10-sec before the first stimuli onset (same as sound subreplicate)
% Sound: 
%   Sound was splitted into subreplicate (starting 10sec before the fisrt stimuli onset) 
% TRackit:
%   The time vector is modified by using a new time origine (10-sec before the first stimuli onset)
%   Note that the trackit data time indexes that occurs before the {10-sec before the first stimuli onset} are negative
disp('Changing the TRackit time origin to the synch flag position');

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );    
for foldNam_ind=folderName_v
    disp(['   Synchronizing TRackit data with the sound ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);

    % We remove the folders without .csv files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );    
                        
    for foldNamTrac_ind=1:length(folderNameTrackit)  
        
        trackitSynchIndex_sec = data(foldNam_ind).subrep(foldNamTrac_ind).trackitSynchIndex_sec;
        soundSynchIndex = data(foldNam_ind).subrep(foldNamTrac_ind).soundSynchIndex;
        
        data(foldNam_ind).subrep(foldNamTrac_ind).VidData_sync=data(foldNam_ind).subrep(foldNamTrac_ind).VideoData_w_i;
        
        if all(isnan(trackitSynchIndex_sec)) || all(isnan(soundSynchIndex)) % "all(isnan(soundSynchIndex))==1" = no mosquito swarming
           data(foldNam_ind).subrep(foldNamTrac_ind).timeTrackSynch_sec = NaN;
           data(foldNam_ind).subrep(foldNamTrac_ind).VidData_sync=[];
        else
            % if we only have the 2nd LEDoff to synchronize trackit with sound, we use the 2nd synch sound flag
            if isnan(trackitSynchIndex_sec(1))
                synchTrackit_sec = trackitSynchIndex_sec(2);
                synchSound_sec =   soundSynchIndex(2)/fs ;
                data(foldNam_ind).subrep(foldNamTrac_ind).synchFlag='2ndLED';        
            % if we only have the 1st LEDoff to synchronize trackit with sound, we use the 2nd synch sound flag
            elseif isnan(trackitSynchIndex_sec(2))
                synchTrackit_sec = trackitSynchIndex_sec(1);
                synchSound_sec =   soundSynchIndex(1)/fs ;
                data(foldNam_ind).subrep(foldNamTrac_ind).synchFlag='1stLED';                        
            % if we only both LEDoff to synchronize trackit with sound 
            else % none are NaN
                % diff between first bip/LED diff and 2nd bip/LED diff avoid a potential accumulation of synchro error due to sampling):
                diff_2synchFlags_sec= (	trackitSynchIndex_sec(1)-soundSynchIndex(1)/fs) - (trackitSynchIndex_sec(2)-soundSynchIndex(2)/fs);
                % we take half of the 2 diff to have a mean estimation and use the first flag:
                synchTrackit_sec = trackitSynchIndex_sec(1) + diff_2synchFlags_sec/2;  
                synchSound_sec =   soundSynchIndex(1)/fs  ;
                data(foldNam_ind).subrep(foldNamTrac_ind).synchFlag='bothLED';        
                
            end
            % Saving the synch flag index of the sound vector
            % data(foldNam_ind).subrep(foldNamTrac_ind).soundSynchFlagIndex=synchSound_sec*fs;
                      
            % changing the time origin of TRackit data to 10-sec before the first stimuli onset
            data(foldNam_ind).subrep(foldNamTrac_ind).timeTrackSynch_sec = ... % used later
                data(foldNam_ind).subrep(foldNamTrac_ind).timeTrack_sec... initial Trackit time (sec) vector
                - (synchTrackit_sec - synchSound_sec) ; % diff betw the two synch flag   
            if isempty(data(foldNam_ind).subrep(foldNamTrac_ind).VidData_sync)==0
                data(foldNam_ind).subrep(foldNamTrac_ind).VidData_sync(:,2) = ...
                  data(foldNam_ind).subrep(foldNamTrac_ind).VideoData_w_i(:,2) ...
                  - (synchTrackit_sec - synchSound_sec) ; % diff betw the sound and trackit synch flag
            end
        end
    end
end





%% Plot Trackit and subreplicate in synchrony  

disp('Plotting synchronized audio and trajectories...')
fig_print=1;
fig_close=0;
figFolderPath=strcat(folder_main,'../','_general_analysis','/3_synchronizedAudioTraj_check/');
title_mess=['Object>' num2str(trackingDurMin_sec) 'sec'];
plotSoundStimShapeAndXYZpos(data,'VidData_sync',...
                            fig_print,...
                            figFolderPath,...
                            title_mess,...
                            fig_close,...
                            folderName_v,...
                            folder_main);




%% 9) importing the CSV file and marking if none swarming for each subreplicate

data_tbl = readtable(strcat(folder_main,'data_181208.csv')); %,'Format','%s  %{dd/MM/uu}D %f %{dd/MM/uu}D %s %s %s %f %{dd/MM/uu HH:mm}D %f %f %f %f %{HH:mm:ss}D %f %s %q %q %f %s %f %s %s %s %f', 'Delimiter', '\t');



% data_tbl(:,19)    subreplicate number
% data_tbl(:,20)    stim type
% data_tbl(:,21)    Number of mosquitoes swarming

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );      
for foldNam_ind=folderName_v
    disp(['   Replicate from file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);

    sex=data(foldNam_ind).sex;
    d=data(foldNam_ind).day;
    
    % We remove the folders without .csv Trackit files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );    
                        
    for foldNamTrac_ind=1:length(folderNameTrackit) 
    disp(['      Subreplicate ' num2str( foldNamTrac_ind) '/' num2str(length(folderNameTrackit) ) ]);
       
        % Each subreplicate is marked as 0 (none swarming on all stimuli) or 1 (at least 1 swarming on 1 stimuli)     
        if any( data_tbl.numbSwarming(   cell2mat(data_tbl.sex)==sex(1)  ... same sex
                         &           data_tbl.d== str2double(d(2:3)) ... same replicate
                         &           data_tbl.sr==foldNamTrac_ind ... same replicate                         
                         )) ==0 % none swarming over all the stimulus of the subreplicate
            data(foldNam_ind).subrep(foldNamTrac_ind).swarming=0; % i.e. No need of processing that subreplicate
        else
            data(foldNam_ind).subrep(foldNamTrac_ind).swarming=1;
        end
    end
end
    




%% 10) Filter the trackit data according to the positions of stimuli + minimal swarming arena (applied on the whole subreplicate)
% Removing the mosquitoes which does not fly inside the control area and which does not fly long enough before each stimulus onset
% The parameters used are durAfterStimOnsetMin_sec and durBeforeStimOnsetMin_sec (before and after the stimulus onset, for each stimulus).
%   The object is deleted if it is on none stimulus onset zone (no NaN on at least 1 stimulus zone). Then if it is only 1 stimulus zone, it is kept for all the stimuli (because 1 same object can be good for one stimulus but not for the others).
disp('Removing the mosquitoes which does not fly inside the control area and which does not fly long enough before each stimulus onset');

n_del=0; % to count the . umber of removed objects due to not being on the stimulus temporal zone
n_notdel=0; % total number of obects
n_del2=0; % number of deleted object due to swarm arena size
% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );    
for foldNam_ind=folderName_v
    disp(['   file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
    
    % We remove the folders without .csv files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );    
    
    data(foldNam_ind).durBeforeStimOnsetMin_sec=durBeforeStimOnsetMin_sec;
    data(foldNam_ind).durAfterStimOnsetMin_sec=durAfterStimOnsetMin_sec;
    data(foldNam_ind).swarmingArenaDim=swarmingArenaDim;
                        
                        
    stim_v=data(foldNam_ind).stim_v; %  stim index  in subreplicate time frame                      
    for foldNamTrac_ind=1:length(folderNameTrackit) 
        disp(['      subreplicate ' num2str( foldNamTrac_ind) '/' num2str(length(folderNameTrackit))])  ;

        % Time vector of locations around the stimulus onset:
        time_v_aroundStim=[];
        for stim_v_ind=1:size(stim_v,1)
            time_v_aroundStim = [time_v_aroundStim, ...
                                 stim_v(stim_v_ind,1) - durBeforeStimOnsetMin_sec :1/fs_trackit: stim_v(stim_v_ind,1) + durAfterStimOnsetMin_sec];
        end
        
        %%% Removing objects that are on none zones of stimuli
        VidData_sync=data(foldNam_ind).subrep(foldNamTrac_ind).VidData_sync;
        VidData_justAroundStimOnset=VidData_sync; % around stim onset but for all of them from the subreplicates (not only 1 stim)
        if isempty(VidData_sync)==0
            object_v=unique(VidData_sync(:,1))';
            for object_ind=object_v
                % Object object_v
                VidData_obj = VidData_sync(    VidData_sync(:,1)==object_ind,:);
                VidData_obj_aroundStim = VidData_obj( ismembertol(VidData_obj(:,2),time_v_aroundStim',1/fs_trackit),:);
                row=VidData_justAroundStimOnset(:,1)==object_ind;
                if all(all(isnan(VidData_obj_aroundStim(:,3:5))))==1 ... if all values around the stimuli onset are NaN, then whole object removed
                        && isempty(VidData_obj_aroundStim)==0
                    VidData_justAroundStimOnset( row,:)  = [];
                    n_del=n_del+1;
                else
                    n_notdel=n_notdel+1;
                end
            end
        end
        
        %%% Romoving objects that are outside the swarming zone
        VidData_JASO_swarmArena=VidData_justAroundStimOnset ;       
        
        if isempty(VidData_JASO_swarmArena)==0
            object_v=unique(VidData_JASO_swarmArena(:,1))';
            for object_ind=object_v
                
                row_woNaN= (VidData_JASO_swarmArena(:,1)==object_ind ... update of the row indexes as we remove some row every loop
                    & any(isnan(VidData_JASO_swarmArena(:,3:5)),2)==0); % The condition with isnan is very important, otherwise it is not possble to make ">" comparaison (results will be False alll the time)                
                if          all(abs(VidData_JASO_swarmArena(row_woNaN,3))>swarmingArenaDim(1))==1 ... % IF object always aoutside criterion boundary
                         || all(abs(VidData_JASO_swarmArena(row_woNaN,4))>swarmingArenaDim(2))==1 ...
                         || all(abs(VidData_JASO_swarmArena(row_woNaN,5))>swarmingArenaDim(3))==1
                 
                	VidData_JASO_swarmArena(row_woNaN,:)=[]; 
                    n_del2=n_del2+1;
                end
            end
            data(foldNam_ind).subrep(foldNamTrac_ind).VidData_JASO_swarmArena=VidData_JASO_swarmArena;
        end
    end
end

disp(['Number of removed objects due to stimulus temporal zone: ' num2str(n_del) '/' num2str(n_notdel+n_del) ]);
disp(['Number of removed objects due to swarm arena: ' num2str(n_del2) '/' num2str(n_notdel) ]); 



%% Plot Trackit and subreplicate in synchrony  
disp('Plotting synchronized audio and trajectories (filtered around the stimuli onsets...')
fig_print=1;
fig_close=1;
figFolderPath=strcat(folder_main,'../','_general_analysis','/3_synchronizedAudioTraj_check/');
title_mess=[', durBefStimOnset=' num2str(durBeforeStimOnsetMin_sec) 's, DurAftStimOnset=' num2str(durAfterStimOnsetMin_sec)...
    's, MaxArenaDim=[' num2str(swarmingArenaDim(1)) ',' num2str(swarmingArenaDim(2)) ',' num2str(swarmingArenaDim(3)) ']m' ];
plotSoundStimShapeAndXYZpos(data,'VidData_JASO_swarmArena',...
                            fig_print,...
                            figFolderPath,...
                            title_mess,...
                            fig_close,...
                            folderName_v,...
                            folder_main);




 %% Releasing memory: removing data().subrep(). ... & saving data

disp(['Releasing memory: removing data().subrep().VidData_sync/VideoData_w_i/trackitSynchIndex_sec/timeTrack_sec ...']);

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );   
for foldNam_ind=folderName_v
         data(foldNam_ind).subrep=rmfield(data(foldNam_ind).subrep,'VidData_sync');
         data(foldNam_ind).subrep=rmfield(data(foldNam_ind).subrep,'VideoData_w_i');
         data(foldNam_ind).subrep=rmfield(data(foldNam_ind).subrep,'trackitSynchIndex_sec');
         data(foldNam_ind).subrep=rmfield(data(foldNam_ind).subrep,'timeTrack_sec');
end

%% Saving data
disp('Saving data to computer...');
save(strcat(folder_main,'_3_withStimDependentTrackitFilt_',date),'data','-v7.3' );

%%
disp('Loading data...')

load('/Users/lionel/Lionoil/Recherche/2017-2019_NRIRD_anofeel/experiments/soundExperiments/type/soundProofChamber/dataAndExtractedFeatures/181000_exp1/data/_3_withStimDependentTrackitFilt_26-Nov-2019.mat')
 



%% 11) Subreplicates split into stimuli sequences + mosquito filtering 
% Split the subreplicates into stimuli sequences (10sec before the stim onset and 10sec after the stim offset) 
% Removing the mosquitoes which does not fly inside the control area and which does not fly long enough before each stimulus onset
disp('Subreplicates split into stimuli sequences + mosquito filtering') 
disp('Removing the mosquitoes which does not fly inside the control area and which does not fly long enough before each stimulus onset');

nObjetsDelNotAroundStimOns=0; % to count the number of deleted objects that not around the stimulus onset zone
nObjetsDelNotAroundStimOns_not=0;
nObjetsDelOutsSwarmArena=0; % to count the number of deleted objects that are outside the swarming arena or immobile on the stimus interval
nObjetsDelOutsSwarmArena_not=0;

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );    
for foldNam_ind=folderName_v
    disp(['   file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
    
    % We remove the folders without .csv files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );    
    
    data(foldNam_ind).durBeforeStimOnsetMin_sec=durBeforeStimOnsetMin_sec;
    data(foldNam_ind).durAfterStimOnsetMin_sec=durAfterStimOnsetMin_sec;
    data(foldNam_ind).swarmingArenaDim=swarmingArenaDim;                        
                        
    stim_v=data(foldNam_ind).stim_v; %  stim index  in subreplicate time frame                      
                        
    for foldNamTrac_ind=1:length(folderNameTrackit) 
        disp(['      subreplicate ' num2str( foldNamTrac_ind) '/' num2str(length(folderNameTrackit))])  ;
 
        %%% Splitting into stimulus zone + temporal criterion on tracking during around the stimulus period
        
        % Stim codes of the subreplicate (in order of playback):
        stimCodes_subrep= data_tbl.stim( cell2mat(data_tbl.sex)==data(foldNam_ind).sex(1) ...
                                & data_tbl.d==str2double(data(foldNam_ind).day(2:3)) ...
                                & data_tbl.sr==foldNamTrac_ind );  
        for stim_v_ind=1:size(stim_v,1)
            
            % The stimulus code is stocked
            data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode=stimCodes_subrep(stim_v_ind);
            
            % Number of swqrming mosquitoes by eyes:
            Nobjects_fromEye=data_tbl.numbSwarming( ...
                    data_tbl.d==str2double(data(foldNam_ind).day(2:3)) ... same replicate
                  & data_tbl.sr==foldNamTrac_ind ... same subreplicate
                  & strcmp( cellstr(data_tbl.stim) , cellstr(stimCodes_subrep(stim_v_ind)))==1 );            
            if Nobjects_fromEye==0 % No mosquito (from eye during the experiment) => neither sound  nor trackit to be processed
                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim=[];
                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).sound= [];
            else
                disp(['         stimulus ' num2str( stim_v_ind) '/' num2str(size(stim_v,1))])  ;
                
                %%% Sound splited into stimuli sequences
                % Sound stimuli with assocaited time vector in subreplicate temporal reference
                if DurPause_sec~=DurBip_sec
                    error('The following lines assume that DurPause_sec=DurStim_sec')
                end
                timeStimZone_Start=     (stim_v_ind-1)*(DurPause_sec+DurStim_sec) ;
                timeStimZone_end=min(   (stim_v_ind  )*(DurPause_sec+DurStim_sec) +DurPause_sec ,length(data(foldNam_ind).subrep(foldNamTrac_ind).sound)/fs ); % % onset time + 10sec                
                time_v_fs_stim = (floor((1+timeStimZone_Start*fs)):floor(timeStimZone_end*fs))';
                sound_stim=data(foldNam_ind).subrep(foldNamTrac_ind).sound(time_v_fs_stim );
                % Saving sound from subreplicate's stimulus zone
                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).sound= sound_stim;

                
                %%% Trackit data splitted into stimuli sequences
                VidData=data(foldNam_ind).subrep(foldNamTrac_ind).VidData_JASO_swarmArena;
                if isempty(VidData)==1 % => no trackit to be processed
                    data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim=[];
                else
                    timeTrackSynch_sec=VidData(:,2); % t=0 corresponds to 10-sec before the first stimulus onset
                    row= ((timeTrackSynch_sec >= timeStimZone_Start) & (timeTrackSynch_sec <= timeStimZone_end));                
                    VidData_stim=VidData(row,:);  % t=0 corresponds to 10-sec before the first stimulus onset
                    % Moving time origin at 10sec before the stimulus offset (instead of the 1st stimulus onset of the subreplicate)
                    VidData_stim(:,2)=VidData_stim(:,2)-timeStimZone_Start;                    
                    
                    
                    %%% Removing object which features NaN values in the stimuli zone
                    for object_ind=unique(VidData_stim(:,1))'
                        % synch time indexes of trackit data for which we force to have a tracking to be analyzed
                        row_timeCrite=(VidData_stim(:,1)==object_ind... for eah object, change at each loop
                                    & VidData_stim(:,2) >= DurPause_sec-durBeforeStimOnsetMin_sec...
                                    & VidData_stim(:,2) <= DurPause_sec+durAfterStimOnsetMin_sec);                                    
                        %%% If the tracking is not done (i.e. NaN value)  on any of the index around the stim onset (durBeforeStimOnsetMin_sec before and durAfterStimOnsetMin_sec after)
                        if any(any((isnan(VidData_stim(row_timeCrite,3:5)))))==1 
                            VidData_stim(VidData_stim(:,1)==object_ind,:) = []; %
                            %disp(['           object ' num2str( object_ind) ' removed (not around the stimulus onset)'])  ;
                            nObjetsDelNotAroundStimOns=nObjetsDelNotAroundStimOns+1;
                        else
                            nObjetsDelNotAroundStimOns_not=nObjetsDelNotAroundStimOns_not+1;
                        end     
                    end
                    %%% Removing object which are outside the swarming area for all the duration of interested stimulus zone + removing immobile mossies
                    object_v=unique(VidData_stim(:,1))';
                    for object_ind=object_v
                        row_woNaN= (VidData_stim(:,1)==object_ind ... update of the row indexes as we remove some row every loop
                            & any(isnan(VidData_stim(:,3:5)),2)==0 ... The condition with isnan is very important, otherwise it is not possble to make ">" comparaison (results will be False alll the time)                
                            & VidData_stim(:,2) >= DurPause_sec-durBeforeStimOnsetMin_sec... on the stim zone
                            & VidData_stim(:,2) <= DurPause_sec+durAfterStimOnsetMin_sec);  %on the stim zone
                        if          all(abs(VidData_stim(row_woNaN,3))>swarmingArenaDim(1))==1 ... % IF object always aoutside criterion boundary
                                 || all(abs(VidData_stim(row_woNaN,4))>swarmingArenaDim(2))==1 ...
                                 || all(abs(VidData_stim(row_woNaN,5))>swarmingArenaDim(3))==1 ...
                                 || any(std(VidData_stim(row_woNaN,3:5))<stdXYZMin) % to remove the landed mosquitoes                             
                            VidData_stim(VidData_stim(:,1)==object_ind,:)=[];
                            nObjetsDelOutsSwarmArena=nObjetsDelOutsSwarmArena+1;
                        else
                            nObjetsDelOutsSwarmArena_not=nObjetsDelOutsSwarmArena_not+1;                            
                        end
                    end  
                    
                    
                    if isempty(VidData_stim)==1
                        warning( '          No data anymore for this subreplicate''s stimulus');
                    end
                    %if all(all(isnan(VidData_stim(:,3:5))))==1
                    %    VidData_stim=[]; % remove all the useless lines
                    %    warning( '          No data anymore for this subreplicate''s stimulus');
                    %end
                    

                    % Saving Trajectories from subreplicate's stimulus zone
                    data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim=VidData_stim;
                end
            end
        end
    end
end

disp(['Number of deleted objects that are not exclusively not-NaN on stimus time interval: '...
    num2str(nObjetsDelNotAroundStimOns) '/' num2str(nObjetsDelNotAroundStimOns+nObjetsDelNotAroundStimOns_not)]);
disp(['Number of deleted objects that are outside the swarming arena or immobile on the stimulus interval: '...
    num2str(nObjetsDelOutsSwarmArena) '/' num2str(nObjetsDelOutsSwarmArena+nObjetsDelOutsSwarmArena_not)]);

clear sound_stim
clear timeTrackSynch_sec
clear row
clear row_timeCrite
clear  VidData_stim
clear TimeVid_stim



%% Plotting each stimulus feature on a different figure

sex_v=1:2; % 1 = male, 2=female
Nfeatures=4;

stimCode_mal={'fcn220';'fcn222';'fcn213';'fcn223';'fcn224';   'fgn220';'fgn222';'fgn223';'fgn224';   'fcn121';'fcn122';'fcn113';'fcn123';'fcn124';   'fcs113';'fcs213'};
stimCode_fem={'mgn2a0';'mgn2a2';'mgn2a3';'mgn2a4';   'mcn2a0';'mcn2a2';'mcn2a3';'mcn2a4'};
stimCode={stimCode_mal,stimCode_fem};

for sex_ind=sex_v
    for stimCode_ind=1:length(stimCode{sex_ind})
    
        
        f=figure;
        set(f,'visible','off');
        for subplot_ind=1:Nfeatures
            axis_subp(subplot_ind)=subtightplot(Nfeatures,1,subplot_ind,0.01,0.1,0.1);
        end
        legend_name=[];


        %%%%%
        % We remove the folders without data (i.e. without folder inside)
        folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );    
        for foldNam_ind=folderName_v
            %disp(['   file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
            % We remove the folders without .csv files (i.e. with the video only):
            folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                                    strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                                    '/PostProc_Filtered_*Splined.csv' );    
            stim_v=data(foldNam_ind).stim_v; %  stim index
                                
            for foldNamTrac_ind=1:length(folderNameTrackit) 
                %disp(['      subreplicate ' num2str( foldNamTrac_ind) '/' num2str(length(folderNameTrackit))])  ;
                                
                for stim_v_ind=1:size(stim_v,1)
                    
                    % We look only for the current Stimulus code:
                    if data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode == ...
                            string( stimCode{sex_ind}{stimCode_ind})

                        if isempty(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim)==0
                            VidData_stim=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim;
                            %if all(all(isnan(VidData_stim(:,3:5))))==0
                                
                                object_v=unique(VidData_stim(:,1))';
                                for object_ind=object_v
                                    row=(VidData_stim(:,1)==object_ind );
                                    time_v=VidData_stim(row,2);
                                    
                                    % We only plot the tracked trajectories which features the two bip snch LED
                                    if strcmp(data(foldNam_ind).subrep(foldNamTrac_ind).synchFlag,'bothLED')==1
                                        for subplot_ind=1:3
                                            hold(axis_subp(subplot_ind),'on')

                                            plot(axis_subp(subplot_ind),...
                                                time_v,... % to have all stimuli zone on same time vector %                                                VidData_stim( time_v==row, 2 )-(stim_v(stim_v_ind,1)-DurPause_sec),... % to have all stimuli zone on same time vector
                                                VidData_stim(  row, 2+subplot_ind ));                                
                                            
                                            xlim(axis_subp(subplot_ind),[0 DurPause_sec*2+DurStim_sec   ]);
                                            if  subplot_ind==1
                                                legend_name=[legend_name ; ...
                                                    [data(foldNam_ind).day ' ' num2str(foldNam_ind,'%02.0f') '/' num2str(length(folderName_v)),...
                                                    ' subrep' num2str(foldNamTrac_ind,'%02.0f') ' stim' num2str(stim_v_ind,'%02.0f') ' obj' num2str(object_ind,'%03.0f') ] ];
                                            end
                                        end
                                        
                                        
                                        %%% Velocity 
                                        if isempty(VidData_stim(row,6:8))==0
                                            subplot_ind=4;
                                            %velocity_xyz= [VidData_stim( time_v==row,6)) , VidData_stim( time_v==row,7),diff(VidData_stim( time_v==row,5))];
                                            %velocity_y=VidData_stim( time_v==row,7);
                                            linVel =sqrt(sum( VidData_stim(row,6:8).^2,2));
                                            hold(axis_subp(subplot_ind),'on')                                        
                                            plot(axis_subp(subplot_ind),...
                                                time_v,...%VidData_stim( time_v==row, 2 )-(stim_v(stim_v_ind,1)-DurPause_sec),... % to have all stimuli zone on same time vector
                                                linVel );                                
                                            xlim(axis_subp(subplot_ind),[0 DurPause_sec*2+DurStim_sec   ]);  
                                            ylim([0 2]);
                                        end

%                                         %%% XYZ Envelop
%                                         for subplot_ind=5:7                                        
%                                             hold(axis_subp(subplot_ind),'on') ;  
%                                             plot(axis_subp(subplot_ind),...
%                                                 data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).XYZ_env(:,subplot_ind-4));
%                                         end
                                 
                                                                    
                                    end
                                end
                            %end
                        end
                    end
                end                       
            end
        end 
        for subplot_ind=1:3
            if subplot_ind==2
               ylim(axis_subp(subplot_ind),[-0.7 0.7]);
            else
                ylim(axis_subp(subplot_ind),[-0.5 0.5]);
            end
        end       

            
        if isempty(legend_name)==0
            legend(axis_subp(2),{legend_name},'fontSize',4);
            disp(['sex' num2str(sex_ind) ' Stim' num2str(stimCode_ind) ' Numb of replicates: ' num2str(length(unique(legend_name(:,2:3),'rows')))]);
        end
        xlabel(axis_subp(Nfeatures),'Time (sec)');
        ylablFSize=6;
        ylabel(axis_subp(1),'X (m)','fontSize',ylablFSize);
        ylabel(axis_subp(2),'Y (m)','fontSize',ylablFSize);
        ylabel(axis_subp(3),'Z (m)','fontSize',ylablFSize);
        ylabel(axis_subp(4),'Lin vel (m, speaker pos ref)','fontSize',ylablFSize);

        try  
            title(axis_subp(1),{['Stim ' stimCode{sex_ind}{stimCode_ind}],...
                                        ['durBeforeStimOnsetMin_sec=' num2str(durBeforeStimOnsetMin_sec)],...
                                        ['durAfterStimOnsetMin_sec=' num2str(durAfterStimOnsetMin_sec) ]},...
                                        'interpreter','none');
        catch 
            title(axis_subp(1),{['Stim ' stimCode{sex_ind}{stimCode_ind}],...
                                        },...
                                        'interpreter','none');                            
        end
        

        
        set(gcf,'Units','Inches');
        pos = get(gcf,'Position');
        set(gcf,'PaperPositionMode','Auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])
        %set(gcf,'PaperPositionMode','Auto','PaperUnits','Inches','Position',[0 0.8 0.8 0.8])
        print(gcf,strcat(folder_main,'../','_general_analysis','/4_XYZfeaturesPerStim/','featurePerStim_',stimCode{sex_ind}{stimCode_ind},'_XYZ_',date,'.pdf'),'-dpdf','-r0')   
        close
        %set(gcf, 'PaperSize', [4 2]);
    end
end












%% Releasing memory: removing data().subrep(). ... & saving data

disp(['Releasing memory: removing data().subrep().timeTrack_sec ...']);
for foldNam_ind=folderName_v
         data(foldNam_ind).subrep=rmfield(data(foldNam_ind).subrep,'timeTrackSynch_sec');
end

% Saving data
disp('Saving data to computer...');
save(strcat(folder_main,'_4_withResponseForEachStim_',date),'data','-v7.3' );

%% 

disp('Loading data...')
load('/Users/lionel/Lionoil/Recherche/1703_IRD_anofeel/experiments/soundExperiments/type/soundProofChamber/dataAndExtractedFeatures/181000_exp1/data/_4_withResponseForEachStim_26-Nov-2019.mat')
load('/Users/lionel/Lionoil/Recherche/1703_IRD_anofeel/experiments/soundExperiments/type/soundProofChamber/dataAndExtractedFeatures/181000_exp1/data/_data_tbl_17-Nov-2019.mat')


%% Releasing memory: removing data().subrep(). ... & saving data

disp(['Releasing memory: removing data().subrep().sound/VidData_JASO_swarmArena ...']); 
for foldNam_ind=folderName_v
     data(foldNam_ind).subrep=rmfield(data(foldNam_ind).subrep,'sound');
     data(foldNam_ind).subrep=rmfield(data(foldNam_ind).subrep,'VidData_JASO_swarmArena');
end





%% 12) Computing angular velocity

%%% Debug using plots
figure_eachWind=0; 
    % 0: computing features, no figure displayed
    % 1: to display the angular velocity  (limited to 100 figures, otherwise MAtlab does not respond anymore)
figure_start={1,1,1:16}; % {file number, first subreplicate number: last subreplicate number (typically 1:10), first stim index: last stim index (1:16), window index)}
figure_eachWind_ind_start=1000; %  change this value in order to run several plot programs without removing previous figures
figure_eachWind_ind=0; % used to count the number of figure of each run (condition: if figure_eachWind_ind>100, figures are stopped displaying to avoid MAtlab slowdown
figure_Nmax=10; 

Nfeatures=5;% X Y Z vel angVel

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );   
% if debug mode, we do't compute everything, but only the data from figure_start parameter (see above):
if figure_eachWind==1
    folderName_v=figure_start{1}; % 1:length(folderName);
else
    folderName_v=1:length(folderName); % day
end  

% if debug mode, we do't compute everything, but only the data from figure_start parameter (see above):
if figure_eachWind==1
    folderName_v=figure_start{1}; % 1:length(folderName);
else
    folderName_v=1:length(folderName); % day
end 

for foldNam_ind=folderName_v % each day
    disp(['   file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
    if strcmp(data(foldNam_ind).sex,'mal'), sex_ind=1; 
    elseif  strcmp(data(foldNam_ind).sex,'fem'), sex_ind=2; 
    else, error(['should be mal or female. Check data(' num2str(foldNam_ind) ').sex']);
    end
    % We remove the TRackit folders without .csv files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );
    
    % if debug mode, we do't compute everything, but only the data from figure_start parameter (see above):
    if figure_eachWind ==1
        subrep_v=figure_start{2}; % user-defined subreplicate
    else
        subrep_v=1:length(folderNameTrackit); % subrep
    end
        
	for foldNamTrac_ind=subrep_v %1:length(folderNameTrackit) % each trackit folder with CSV file inside (i.e. each subreplicate)
        disp(['      subreplicate ' num2str( foldNamTrac_ind) '/' num2str(length(folderNameTrackit))])  ;
        if foldNamTrac_ind>length(folderNameTrackit) % in case the manual vlaues we entered is more than the max nuhmber of subreplicate for this day
            break
        end
        for stim_v_ind=1:length(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp) % each stimulus of subreplicate foldNamTrac_ind
            disp(['         stim ' num2str( stim_v_ind) '/' num2str(length(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp))])  ;            

            fig_on= figure_eachWind==3 || (figure_eachWind==1 && figure_eachWind_ind<figure_Nmax && ...
                     any(foldNam_ind==figure_start{1})  && ...
                     any(foldNamTrac_ind==figure_start{2}) && ...
                     any(stim_v_ind==figure_start{3})) ;
            if fig_on
                figure_eachWind_ind=figure_eachWind_ind+1;
                figure(figure_eachWind_ind_start+figure_eachWind_ind);

                for subplot_ind=1:Nfeatures
                    sb{figure_eachWind_ind}(subplot_ind)=subtightplot(Nfeatures,1,subplot_ind,0.01,0.1,0.1);
                end    
                stimcode=char(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode);
                title_name={['file',num2str(foldNam_ind) '(' data(foldNam_ind).day ') subrep' num2str(foldNamTrac_ind)  ' stim' num2str(stim_v_ind) ...
                            '('  stimcode  ')'],['Nobject=' num2str(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).Nobjects)  ] };
                title(sb{figure_eachWind_ind}(1),title_name,'fontSize',8,'interpreter','none');                    
            end
                
            VidData_stim=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim;                    
            if ~isempty(VidData_stim)
                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim(:,9)= NaN(size(VidData_stim,1),1); % allocating
                object_v=unique(VidData_stim(:,1))';
                for object_ind=object_v
                    row=(VidData_stim(:,1)==object_ind );                                                                             
 
                    % Absolute velocity
                    linVel =sqrt(sum( VidData_stim(row,6:8).^2,2)); % ref: speaker position

                    % Angular velocity
                    vel=VidData_stim(row,6:8);
                    v_t1=vel(1:end-1,1:3);
                    v_t2=vel(2:end,1:3); 
                    cosdteta=(  v_t1(:,1).*v_t2(:,1)...
                                 + v_t1(:,2).*v_t2(:,2)... 
                                 + v_t1(:,3).*v_t2(:,3) )...
                                 ./ (linVel(1:end-1) .* linVel(2:end) );  % formula: cos(teta) = dot(vector1,vector2) / (norm(vector1)*norm(vector2))
                    if any(imag(cosdteta)> 0.0001) % arbitrary
                        warning(['teta is imaginary (' num2str(foldNam_ind) '/' num2str(foldNamTrac_ind) '/' num2str(stim_v_ind) '(']);
                    end
                        
                    dteta=  real(acos(real(cosdteta) ));
                    data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim(row,9) =...
                        [dteta ./ diff(VidData_stim( row,2)) ; NaN] ; % angular velocity
                    
                    %%% Plot
                    if fig_on
                            
                        % X Y Z
                        time_v=VidData_stim(row,2);                            
                        for subplot_ind=1:3
                            hold(sb{figure_eachWind_ind}(subplot_ind),'on');
                            plot(sb{figure_eachWind_ind}(subplot_ind),...
                                time_v,... % to have all stimuli zone on same time vector %
                                VidData_stim( row, 2+subplot_ind ));                                
                        end    
                        % abs vel
                        subplot_ind=4;                    
                        hold(sb{figure_eachWind_ind}(subplot_ind),'on');
                        plot(sb{figure_eachWind_ind}(subplot_ind),...
                              time_v,...
                              linVel); 
                        % ang vel
                        subplot_ind=5;                    
                        hold(sb{figure_eachWind_ind}(subplot_ind),'on');                    
                            plot(sb{figure_eachWind_ind}(subplot_ind),...
                                time_v(1:end)+[diff(time_v)/2;NaN] ,...
                                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim(row,9));  
                    end
                end
                if fig_on 
                    xlabel(sb{figure_eachWind_ind}(Nfeatures),'Time (sec)');
                    ylablFSize=6;
                    ylabel(sb{figure_eachWind_ind}(1),'X (m)','fontSize',ylablFSize);
                    ylabel(sb{figure_eachWind_ind}(2),'Y (m)','fontSize',ylablFSize);
                    ylabel(sb{figure_eachWind_ind}(3),'Z (m)','fontSize',ylablFSize);
                    ylabel(sb{figure_eachWind_ind}(4),'Lin vel from speaker position (m/s)','fontSize',ylablFSize);    
                    ylabel(sb{figure_eachWind_ind}(5),'Ang vel (rad/s) ','fontSize',ylablFSize);  
                    for subplot_ind=1:Nfeatures   
                        xlim(sb{figure_eachWind_ind}(subplot_ind),...
                                [0 DurPause_sec*2+DurStim_sec   ]);
                    end                       
                end                                         
            end
        end
	end
end







%% 13) Computing frequency peak amplitude and Number of swarming mosquitoes (Nobjects, saved in the structure and in the table data_tbl.Nobjects) 
          
%%% Debug using plots
figure_eachWind=0; 
    % 0: computing features, no figure displayed
    % 1: to display the peak detection on each time window (limited to 100 figures, otherwise MAtlab does not respond anymore)
    % 2: to dispaly X/Y/Z/vel/.../peakDetection over time, 1 figure per played -back sound
    % 3: computing features and saving both figure type (1 and 2) without displaying them (very long processing, several hours)
figure_start={1,1,1:16,1+10/wind_t_wbf_sec}; % {file number, first subreplicate number: last subreplicate number (typically 1:10), first stim index: last stim index (1:16), window index)}
figure_eachWind_ind_start=1000; %  change this value in order to run several plot programs without removing previous figures
figure_eachWind_ind=0; % used to count the number of figure of each run (condition: if figure_eachWind_ind>100, figures are stopped displaying to avoid MAtlab slowdown
figure_Nmax=max(10,  2 /wind_t_wbf_sec); 
    
% Nfft size
Nfft=2^(2+nextpow2(floor(wind_t_wbf_sec*fs)));
fen=hann(floor(wind_t_wbf_sec*fs)); % window to be multiplied by signal before doinf fft
    % don't use rectalgular or Hamming (too high amplitude secondary lobs)

% MEth 0: we take the mean of all peaked detected; Meth 1: we take the mean of the biggest Nobjects peaks (Nobjects being the number of swarming mosquitoes (got by eye or from trackit))
meth_Npeaks=0;
fact_ampl_Npeak = 0.7   ; % for meth_Npeaks=0, we mean all the peaks above the amplitude threshold, providing the peak amplitude is more than fact_ampl_N times the biggest peak amplitude

% Median filter lenght over time (aftfer having detected peak on each time window)
medfilt_length=[3 3]; % in sample ; 3 will remove outlier points
    
% 
Nfeatures=6; % trackit feature X, Y, Z, vel, ang vel, ..., WBF
ylim_v={[0 0.009] ,[0 0.07] }; % plot ylim

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );   
% if debug mode, we do't compute everything, but only the data from figure_start parameter (see above):
if figure_eachWind==1 
    folderName_v=figure_start{1}; % 1:length(folderName);
else
    folderName_v=1:length(folderName); % day
end  

for foldNam_ind=folderName_v
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );                      
    % if debug mode, we do't compute everything, but only the data from figure_start parameter (see above):
    if figure_eachWind ==1
        subrep_v=figure_start{2}; % user-defined subreplicate
    else
        subrep_v=1:length(folderNameTrackit); % subrep
    end

    for foldNamTrac_ind=subrep_v
         for stim_v_ind=1:length(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp)
             try
                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak=rmfield(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak,'pks');
                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak=rmfield(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak,'locs');
                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak=rmfield(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak,'width');
                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak=rmfield(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak,'time_pks'); 
                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak=rmfield(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak,'wind_t_wbf_sec');
             catch
                 %warning(['rep' num2str(foldNam_ind) ' subrep' num2str(foldNamTrac_ind) ' stim' num2str(stim_v_ind)  ': No field ".soundPeak"' ])
            end
         end
    end
end


% if debug mode, we do't compute everything, but only the data from figure_start parameter (see above):
if figure_eachWind ==1
    folderName_v=figure_start{1}; % 1:length(folderName);
else
    folderName_v=1:length(folderName); % day
end 

for foldNam_ind=folderName_v % each day
    disp(['   file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
    if strcmp(data(foldNam_ind).sex,'mal'), sex_ind=1; 
    elseif  strcmp(data(foldNam_ind).sex,'fem'), sex_ind=2; 
    else, error(['should be mal or female. Check data(' num2str(foldNam_ind) ').sex']);
    end
    % We remove the TRackit folders without .csv files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );

    % if debug mode, we do't compute everything, but only the data from figure_start parameter (see above):
    if figure_eachWind ==1
        subrep_v=figure_start{2}; % user-defined subreplicate
    else
        subrep_v=1:length(folderNameTrackit); % subrep
    end
        
	for foldNamTrac_ind=subrep_v  % each trackit folder with CSV file inside (i.e. each subreplicate)
        disp(['      subreplicate ' num2str( foldNamTrac_ind) '/' num2str(length(folderNameTrackit))])  ;
        if foldNamTrac_ind>length(folderNameTrackit) % in case the manual vlaues we entered is more than the max nuhmber of subreplicate for this day
            break
        end
        for stim_v_ind=1:length(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp)  % each stimulus of subreplicate foldNamTrac_ind
            disp(['         stim ' num2str( stim_v_ind) '/' num2str(length(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp))])  ;            
            Lsound=size(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).sound,1);
            Nwind=floor( Lsound / (wind_t_wbf_sec*fs));                     
            
           color_m=copper(Nwind);
            
            Ysmooth=zeros(Nfft/2+1,Nwind); 
            warning_nopeak=0; %index to know how many missed peak detection they were

            fs_spectr=1/((Nfft/2+1)/(fs/2)); % Spectrum sample period (Hz)    
%             % Filter coeff:
%             smoothingLength_kk=floor(smoothingLength_Hz*Numharm_mal_fem(sex_ind) / fs_spectr);
%             b_filt=(1/smoothingLength_kk) * ones(1,smoothingLength_kk);
%             a_filt=1;            
            
            % We will use the number of object to know how many peak to look for in the spectrum
            % First Computed from my observation during the experiemnt:
            Nobjects_fromEye=data_tbl.numbSwarming( data_tbl.d==str2double(data(foldNam_ind).day(2:3)) ... same subreplicate
                                           & data_tbl.sr==foldNamTrac_ind ... same subreplicate
                                           & strcmp( cellstr(data_tbl.stim) , cellstr(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode))==1 );
            % But sometimes I was not able to write it down, so we can count the objects from Trackit:
            % Criterion: number of tracked object between DurPause_sec-durBeforeStimOnsetMin_sec and DurPause_sec+durAfterOnsetMin_sec
            if isnan(Nobjects_fromEye)==1
                if isempty(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim)
                   Nobjects=0; % in case of no manual writing of the number of swarming mosquitoes and no Trackit data
                else    % Number of tracked mosquitoes is computed
                    Nobjects=length(unique(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim(...
                                                ~isnan(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim(:,3))...
                                                & data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim(:,2) < DurPause_sec+durAfterStimOnsetMin_sec ...
                                                & data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim(:,2) > DurPause_sec-durBeforeStimOnsetMin_sec ...
                                            ,1)));                      
                end
            else
                Nobjects=Nobjects_fromEye;
            end
            data_tbl.Nobjects( data_tbl.d==str2double(data(foldNam_ind).day(2:3)) ... same replicate
                                           & data_tbl.sr==foldNamTrac_ind ... same subreplicate
                                           & strcmp( cellstr(data_tbl.stim) , cellstr(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode))==1 )... % same stimuli
                             = Nobjects;

            data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).Nobjects=Nobjects;            
            
            if Nobjects~=0 % otherwise no need to look for peaks
                if figure_eachWind==3 || figure_eachWind==2
                    parentFold=strcat(folder_main,'../','_general_analysis','/5b_features_perStimPerSubrep/');
                    folderNameTBCreated=strcat('featurePerStim_',...
                                        char(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode),...
                                        '_subrep', num2str(foldNamTrac_ind,'%02.0f'),'_stim', num2str(stim_v_ind) );
                    mkdir(strcat(parentFold,folderNameTBCreated))
                end

                % FFT is commputed on each window:
                for wind_index=0:Nwind-1 
                    ky_start=floor(1+ wind_index/Nwind*Lsound);
                    ky_end=  floor(   wind_index/Nwind*Lsound) + wind_t_wbf_sec*fs;
                    y=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).sound(ky_start :ky_end,1) ;
                    Yfull=abs(fft(fen.*y(1:floor(wind_t_wbf_sec*fs)),Nfft));
                    %Yfull=abs(fft(y(1:floor(wind_t_wbf_sec*fs)),floor(wind_t_wbf_sec*fs)));
                    Y=Yfull(1:Nfft/2+1); % pwelch(y,wind_t_wbf_sec*fs,0,Nfft,fs)
                    %Ysmooth(:,wind_index+1)=smoothdata(Y,smoothMethod,smoothingLength_Hz *(wind_t_wbf_sec*fs/2+1)/(fs/2));  % the window length is in Hz*wind_t_wbf_sec*fs/fs 
                    %Ysmooth(:,wind_index+1)= filtfilt( b_filt,a_filt , Y);      
                    Ysmooth(:,wind_index+1)=Y;

                   %%% peak detection
                   Ys=Ysmooth(:,wind_index+1);
                    freq_v=(0:length(Ys)-1)/(length(Ys)-1)*fs/2 ; %- (smoothingLength_kk*fs_spectr)/2; % smoothingLength_Hz/2;
                    fminmax_kk=find(freq_v > peak_fminfmax(sex_ind,1) & ...
                        freq_v < peak_fminfmax(sex_ind,2));
                    %MinPeakHeight=	coef_threshold_peak * mean(Ysmooth(fminmax_kk,wind_index+1) );

                    %%% Peak detection
                    try
                        warning('off')
                        [pks_temp, locs_temp, w_temp]=findpeaks(Ysmooth(fminmax_kk,wind_index+1) ...
                            ,'MinPeakHeight',MinPeakHeight(sex_ind), ...
                            'MinPeakWidth',MinPeakWidth*Numharm_mal_fem(sex_ind)/fs_spectr,... used to be MinPeakWidth*fs_spectr but i think it is wrong as it shouldbe expressed in unit of samples
                            'SortStr','descend',... % peaks from the largest to the smallest
                            'WidthReference','halfprom'); 
                        warning('on')
                        if meth_Npeaks % We consider the number of swarming mosquito (by eye or from trackit)
                            Nobjects_pks=min(Nobjects,length(pks_temp)); % in case that the number of peak detected is less than Nobjects (otherwise the TRY wont be runned)
                                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.pks(wind_index+1)=   mean(pks_temp(1:Nobjects_pks)) ;   
                            data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs(wind_index+1)=mean(freq_v(locs_temp(1:Nobjects_pks)...
                                + min(fminmax_kk)-1))/  Numharm_mal_fem(sex_ind);% Taking account freq Offset % Hz
                            data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.width(wind_index+1)= mean(w_temp(1:Nobjects_pks)*fs_spectr);
                            data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.Npeaks_sec=NaN;
                        else % we just mean all the peaks above the amplitude threshold (providing the peak amplitude is more than 0.5 times the biggest peak amplitude)
                            Npeak = length( pks_temp( pks_temp > fact_ampl_Npeak*max(pks_temp)));
                            data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.pks(wind_index+1)=   mean(pks_temp(1:Npeak)) ;   
                            data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs(wind_index+1)=mean(freq_v(locs_temp(1:Npeak)...
                                + min(fminmax_kk)-1))/  Numharm_mal_fem(sex_ind);% Taking account freq Offset % Hz
                            data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.width(wind_index+1)= mean(w_temp(1:Npeak)*fs_spectr);
                            data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.Npeaks_sec=Npeak;
                        end
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.time_pks(wind_index+1)= wind_index*wind_t_wbf_sec + (2*DurPause_sec+DurStim_sec)-Lsound/fs ; %sec ; the "(2*DurPause_sec+DurStim_sec)-Lsound/fs" is for the sound around the first stimuli which usually starts less than 10s (DurPause_sec) before the 1st stim sound after the
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.wind_t_wbf_sec=wind_t_wbf_sec;
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.coef_threshold_peak=coef_threshold_peak;
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.MinPeakWidth=MinPeakWidth; % Hz
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.smoothingLength_Hz=smoothingLength_Hz;
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.peak_fminfmax=peak_fminfmax(sex_ind,:);
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.Nfft_sec=Nfft/fs;
                    catch % No peak detected. Decrease coef_threshold_peak or MinPeakWidth, or increase smoothingLength_Hz ;

                        warning_nopeak=warning_nopeak+1;
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.pks(wind_index+1)=NaN;
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs(wind_index+1)=NaN;
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.width(wind_index+1)= NaN;     
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.wind_t_wbf_sec=NaN;
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.coef_threshold_peak=NaN;
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.MinPeakWidth=NaN; % Hz
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.smoothingLength_Hz=NaN;
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.peak_fminfmax=NaN;                        
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.time_pks(wind_index+1)= wind_index*wind_t_wbf_sec  + (2*DurPause_sec+DurStim_sec)-Lsound/fs ;%sec ; the "(2*DurPause_sec+DurStim_sec)-Lsound/fs" is for the sound around the first stimuli which usually starts less than 10s (DurPause_sec) before the 1st stim sound (due to Bip sound which was late)
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.Npeaks_sec=NaN;                        
                    end 
                    if any(abs(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs(wind_index+1)...
                            -peak_fminfmax(sex_ind,:)/Numharm_mal_fem(sex_ind) )<=1)
                            % If the peak is on a side of [fmin_peak fmax_peak](not a
                            % extrema), i.e. locs=fmin or fmax ± 1Hz
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak=[];%.pks(wind_index+1)=NaN;
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs(wind_index+1)=NaN;
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.width(wind_index+1)= NaN;     
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.wind_t_wbf_sec=NaN;
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.coef_threshold_peak=NaN;
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.MinPeakWidth=NaN; % Hz
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.smoothingLength_Hz=NaN;
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.peak_fminfmax=NaN;   
                        %data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.time_pks(wind_index+1)= NaN;
                    end
                    if figure_eachWind==3 || (figure_eachWind==1 && figure_eachWind_ind<figure_Nmax && ...
                         any(foldNam_ind==figure_start{1})  && ...
                         any(foldNamTrac_ind==figure_start{2}) && ...
                         any(stim_v_ind==figure_start{3}) && ...
                         wind_index>=figure_start{4} )
                        figure_eachWind_ind=figure_eachWind_ind+1;
                        f=figure(figure_eachWind_ind_start+figure_eachWind_ind);
                        if figure_eachWind==3, set(f,'visible','off'); end % figure not displayed
                        set(gca, 'ColorOrder', color_m, 'NextPlot', 'replacechildren'); % Change to new colors.
                        hold on, plot(freq_v,Ysmooth(:,wind_index+1));
                        hold on, plot(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs(wind_index+1)*Numharm_mal_fem(sex_ind),...
                                      data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.pks(wind_index+1),'o')
                        hold on, plot(freq_v,MinPeakHeight(sex_ind)*ones(length(freq_v),1),'--r');
                        for kiki=1:2 % each line showing tracking frequency-limit
                            hold on, line([peak_fminfmax(sex_ind,kiki) peak_fminfmax(sex_ind,kiki)],...
                                [0 max(MinPeakHeight(sex_ind),max(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.pks(wind_index+1)))],...
                                'color','r','linestyle','--')
                        end
                        xlim([0.5*peak_fminfmax(sex_ind,1) 1.3*peak_fminfmax(sex_ind,2)]) 
                        ylim(ylim_v{sex_ind});
                        title_name={['Nobjects=' num2str(Nobjects)],...
                                    ['file',num2str(foldNam_ind) '(' data(foldNam_ind).day ') subrep' num2str(foldNamTrac_ind)  ' stim' num2str(stim_v_ind) ...
                                         '('  char(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode)  ') ' num2str(wind_index*wind_t_wbf_sec) 'th s (before median filter)' ],...
                                    ['wind=', num2str(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.wind_t_wbf_sec), 'sec',...
                                    ', peakFminmax=[', num2str(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.peak_fminfmax(1)), ...
                                         '-',num2str(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.peak_fminfmax(2)), ']Hz',...
                                    ', Nfft=', num2str(Nfft/fs), 's',...
                                    ', Npeak_fact=',num2str(fact_ampl_Npeak)]};
                        title(title_name,'fontSize',8,'interpreter','none');                        
                        if figure_eachWind==3
                            figure_eachWind_ind=0; % in order the figures are not stopped to be plotted after the max number of fig (since they are closed after each plot) 
                            set(gcf,'Units','Inches');
                            pos = get(gcf,'Position');
                            set(gcf,'PaperPositionMode','Auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])
                            print(gcf,strcat(parentFold,folderNameTBCreated,'/wind',num2str(1+wind_index),'over',num2str(Nwind),'_',date,'.pdf'),'-dpdf','-r0')   
                            close                            
                        end
                    end
                end
                if ~isempty(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.pks) || ...
                        all(isnan(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.pks(wind_index+1)))
                    data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs=...
                        medfilt1( data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs, medfilt_length(sex_ind) );
                    if all(isnan(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs)) % since medfilter may remove points if they are not continuous
                        data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak=[];
                    end
                end
                if figure_eachWind==3 || (figure_eachWind==2 && figure_eachWind_ind<figure_Nmax && ...
                     any(foldNam_ind==figure_start{1})  && ...
                     any(foldNamTrac_ind==figure_start{2}) && ...
                     any(stim_v_ind==figure_start{3}) &&...
                     ~isempty(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak))
                 
                    figure_eachWind_ind=figure_eachWind_ind+1;
                    f=figure(figure_eachWind_ind_start+figure_eachWind_ind);
                    if figure_eachWind==3, set(f,'visible','off'); end % figure not displayed
                    for subplot_ind=1:Nfeatures
                        sb{figure_eachWind_ind}(subplot_ind)=subtightplot(Nfeatures,1,subplot_ind,0.01,0.1,0.1);
                    end    
                    title_name={['Nobjects=' num2str(Nobjects)],...
                                ['file',num2str(foldNam_ind) '(' data(foldNam_ind).day ') subrep' num2str(foldNamTrac_ind)  ' stim' num2str(stim_v_ind) ...
                                '('  char(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode)  ')'],...
                                ['wind=', num2str(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.wind_t_wbf_sec), 'sec',...
                                ', peakFminmax=[', num2str(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.peak_fminfmax(1)), ...
                                     '-',num2str(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.peak_fminfmax(2)), ']Hz',...
                                ', Nfft=', num2str(Nfft/fs), 's',...
                                ', Npeak_fact=',num2str(fact_ampl_Npeak),...
                                ', MedFiltN=',num2str(medfilt_length(sex_ind))]};
                    title(sb{figure_eachWind_ind}(1),title_name,'fontSize',8,'interpreter','none');                    
                    
                    % Velocity plot:                       
                    VidData_stim=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim;
                    if ~isempty(VidData_stim)
                        object_v=unique(VidData_stim(:,1))';
                        for object_ind=object_v
                            row=(VidData_stim(:,1)==object_ind );
                            time_v=VidData_stim(row,2);
                            
                            for subplot_ind=1:3
                                hold(sb{figure_eachWind_ind}(subplot_ind),'on');
                                plot(sb{figure_eachWind_ind}(subplot_ind),...
                                    time_v,... % to have all stimuli zone on same time vector %
                                    VidData_stim( row, 2+subplot_ind ));                                
                            end                            
                            
                            % Absolute velocity
                            subplot_ind=4;
                            linVel =sqrt(sum( VidData_stim(row,6:8).^2,2));                            
                            hold(sb{figure_eachWind_ind}(subplot_ind),'on');
                            plot(sb{figure_eachWind_ind}(subplot_ind),...
                                time_v,...
                                linVel); 
                            % Angular velocity
                            subplot_ind=5;

                            hold(sb{figure_eachWind_ind}(subplot_ind),'on');
                            plot(sb{figure_eachWind_ind}(subplot_ind),...
                                time_v+[diff(time_v)/2; NaN] ,...
                                VidData_stim(row,9));                            
                        end

                        xlabel(sb{figure_eachWind_ind}(Nfeatures),'Time (sec)');
                        ylablFSize=6;
                        ylabel(sb{figure_eachWind_ind}(1),'X (m)','fontSize',ylablFSize);
                        ylabel(sb{figure_eachWind_ind}(2),'Y (m)','fontSize',ylablFSize);
                        ylabel(sb{figure_eachWind_ind}(3),'Z (m)','fontSize',ylablFSize);
                        ylabel(sb{figure_eachWind_ind}(4),'Lin vel (m/s)','fontSize',ylablFSize);    
                        ylabel(sb{figure_eachWind_ind}(5),'Ang vel (rad/s)','fontSize',ylablFSize);    

                        
                        for subplot_ind=1:Nfeatures   
                            xlim(sb{figure_eachWind_ind}(subplot_ind),...
                                    [0 DurPause_sec*2+DurStim_sec   ]);
                        end
                        %time_pks=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.time_pks;                    
                        %xlim([min(time_pks) max(time_pks)]);
                    end

                    % Sound Peak plot:
                    set(sb{figure_eachWind_ind}(Nfeatures), 'ColorOrder', color_m, 'NextPlot', 'replacechildren'); % Change to new colors.
                    y_locs=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs;
                    time_pks=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.time_pks;
                    hold(sb{figure_eachWind_ind}(Nfeatures),'on');
                    plot(sb{figure_eachWind_ind}(Nfeatures),time_pks,y_locs,'r');
                    xlim([min(time_pks) max(time_pks)]);                    
                    ylim([peak_fminfmax(sex_ind,1) peak_fminfmax(sex_ind,2)]/Numharm_mal_fem(sex_ind))     
                    ylabel('WB Peak frequency','fontSize',ylablFSize)
                    %y=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).sound; 
                    %Nfft=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.Nfft_sec * fs;
                    %spectrogram(y,hann(wind_t_wbf_sec*fs),0,Nfft,fs,'yaxis');
                    %colorbar off
                    %colormap bone                                    
                    %hold on, zmax = get(gca, 'ZLim'); plot(time_pks,locs/Numharm_mal_fem(sex_ind) ,'r','lineWidth',20);                                    
                    
                    if figure_eachWind==3
                        figure_eachWind_ind=0; % in order the figures are not stopped to be plotted after the max number of fig (since they are closed after each plot)
                        set(gcf,'Units','Inches');
                        pos = get(gcf,'Position');
                        set(gcf,'PaperPositionMode','Auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])
                        print(gcf,strcat(parentFold,folderNameTBCreated,'_',date,'.pdf'),'-dpdf','-r0')   
                        close   
                            
                    end
                end

            else
                data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak=[];
            end
              if warning_nopeak>0
                disp(['            They were ',num2str(warning_nopeak), ' missed detected peaks out of ',num2str( length(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp  )*Nwind ), '. Decrease coef_threshold_peak or MinPeakWidth, or increase smoothingLength_Hz ']);  ;            
            end
        end
    end
end



%% Saving data
disp('Saving data to computer...');
save(strcat(folder_main,'_5_withAngVelo_withWBFdetection_',date),'data','-v7.3' )
save(strcat(folder_main,'_data_tbl_',date),'data_tbl','-v7.3' )

%% 
disp('Loading data...')
load('/Users/lionel/Lionoil/Recherche/1703_IRD_anofeel/experiments/soundExperiments/type/soundProofChamber/dataAndExtractedFeatures/181000_exp1/data/_5_withAngVelo_withWBFdetection_26-Nov-2019.mat')
load('/Users/lionel/Lionoil/Recherche/1703_IRD_anofeel/experiments/soundExperiments/type/soundProofChamber/dataAndExtractedFeatures/181000_exp1/data/_data_tbl_26-Nov-2019.mat')



%% Plotting 1 figure per {stim, subreplicate}

ylim_v={[0 0.009] ,[0 0.07] }; % plot ylim
       
Nfeatures=6; % trackit feature X, Y, Z, vel, ang vel, ..., WBF


%%% Debug using plots
figure_eachWind=0; 
    % 0: computing features, no figure displayed
    % 1: to display the peak detection on each time window (limited to 100 figures, otherwise MAtlab does not respond anymore)
    % 2: to dispaly X/Y/Z/vel/.../peakDetection over time, 1 figure per played -back sound
    % 3: computing features and saving both figure type (1 and 2) without displaying them (very long processing, several hours)
figure_start={1,1,1:16,1+10/wind_t_wbf_sec}; % {file number, first subreplicate number: last subreplicate number (typically 1:10), first stim index: last stim index (1:16), window index)}
figure_eachWind_ind_start=1000; %  change this value in order to run several plot programs without removing previous figures
figure_eachWind_ind=0; % used to count the number of figure of each run (condition: if figure_eachWind_ind>100, figures are stopped displaying to avoid MAtlab slowdown
figure_Nmax=max(10,  2 /wind_t_wbf_sec); 

% We remove the folders without data (i.e. without folder inside)
folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );   

                    
folderName_v=1:length(folderName); % day

for foldNam_ind=1 %folderName_v % each day
    disp(['   file ' num2str( foldNam_ind) '/' num2str(length(folderName)) ' ' folderName(foldNam_ind).name]);
    if strcmp(data(foldNam_ind).sex,'mal'), sex_ind=1; 
    elseif  strcmp(data(foldNam_ind).sex,'fem'), sex_ind=2; 
    else, error(['should be mal or female. Check data(' num2str(foldNam_ind) ').sex']);
    end
    % We remove the TRackit folders without .csv files (i.e. with the video only)
    folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                            strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                            '/PostProc_Filtered_*Splined.csv' );


    subrep_v=1:length(folderNameTrackit); % subrep       
	for foldNamTrac_ind=1%subrep_v  % each trackit folder with CSV file inside (i.e. each subreplicate)
        disp(['      subreplicate ' num2str( foldNamTrac_ind) '/' num2str(length(folderNameTrackit))])  ;

        for stim_v_ind=1:length(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp)  % each stimulus of subreplicate foldNamTrac_ind
            disp(['         stim ' num2str( stim_v_ind) '/' num2str(length(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp))])  ;            
            %color_m=copper(Nwind);
            

            Nobjects=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).Nobjects;            
            if Nobjects>0
                parentFold=strcat(folder_main,'../','_general_analysis','/5b_features_perStimPerSubrep/');
                folderNameTBCreated=strcat('featurePerStim_',...
                                    char(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode),...
                                    '_subrep', num2str(foldNamTrac_ind,'%02.0f'),'_stim', num2str(stim_v_ind,'%02.0f') );

                figure_eachWind_ind=figure_eachWind_ind+1;
                f=figure(figure_eachWind_ind_start+figure_eachWind_ind);
                set(f,'visible','off')
                for subplot_ind=1:Nfeatures
                    sb{figure_eachWind_ind}(subplot_ind)=subtightplot(Nfeatures,1,subplot_ind,0.01,0.1,0.1);
                end    
                title_name={['Nobjects=' num2str(Nobjects)],...
                            ['file',num2str(foldNam_ind) '(' data(foldNam_ind).day ') subrep' num2str(foldNamTrac_ind)  ' stim' num2str(stim_v_ind) ...
                            '('  char(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode)  ')'],...
                            ['wind=', num2str(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.wind_t_wbf_sec), 'sec',...
                            ', peakFminmax=[', num2str(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.peak_fminfmax(1)), ...
                                 '-',num2str(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.peak_fminfmax(2)), ']Hz',... ', Nfft=', num2str(Nfft/fs), 's',...', Npeak_fact=',num2str(fact_ampl_Npeak),...', MedFiltN=',num2str(medfilt_length(sex_ind))
                                 ]};
                title(sb{figure_eachWind_ind}(1),title_name,'fontSize',8,'interpreter','none');                    

                % Velocity plot:                       
                VidData_stim=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim;
                if ~isempty(VidData_stim)
                    object_v=unique(VidData_stim(:,1))';
                    for object_ind=object_v
                        row=(VidData_stim(:,1)==object_ind );
                        time_v=VidData_stim(row,2);

                        for subplot_ind=1:3
                            hold(sb{figure_eachWind_ind}(subplot_ind),'on');
                            plot(sb{figure_eachWind_ind}(subplot_ind),...
                                time_v,... % to have all stimuli zone on same time vector %
                                VidData_stim( row, 2+subplot_ind ));                                
                        end                            

                        % Absolute velocity
                        subplot_ind=4;
                        linVel =sqrt(sum( VidData_stim(row,6:8).^2,2));                          
                        hold(sb{figure_eachWind_ind}(subplot_ind),'on');
                        plot(sb{figure_eachWind_ind}(subplot_ind),...
                            time_v,...
                            linVel); 
                        % Angular velocity
                        subplot_ind=5;

                        hold(sb{figure_eachWind_ind}(subplot_ind),'on');
                        plot(sb{figure_eachWind_ind}(subplot_ind),...
                            time_v+[diff(time_v)/2; NaN] ,...
                            VidData_stim(row,9));                            
                    end

                    xlabel(sb{figure_eachWind_ind}(Nfeatures),'Time (sec)');
                    ylablFSize=6;
                    ylabel(sb{figure_eachWind_ind}(1),'X (m)','fontSize',ylablFSize);
                    ylabel(sb{figure_eachWind_ind}(2),'Y (m)','fontSize',ylablFSize);
                    ylabel(sb{figure_eachWind_ind}(3),'Z (m)','fontSize',ylablFSize);
                    ylabel(sb{figure_eachWind_ind}(4),'Lin vel (m/s)','fontSize',ylablFSize);    
                    ylabel(sb{figure_eachWind_ind}(5),'Ang vel (rad/s)','fontSize',ylablFSize);    


                    for subplot_ind=1:Nfeatures   
                        xlim(sb{figure_eachWind_ind}(subplot_ind),...
                                [0 DurPause_sec*2+DurStim_sec   ]);
                    end

                    % Sound Peak plot:
                    %set(sb{figure_eachWind_ind}(Nfeatures), 'ColorOrder', color_m, 'NextPlot', 'replacechildren'); % Change to new colors.
                    y_locs=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs;
                    time_pks=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.time_pks;
                    hold(sb{figure_eachWind_ind}(Nfeatures),'on');
                    plot(sb{figure_eachWind_ind}(Nfeatures),time_pks,y_locs,'r');
                    xlim([min(time_pks) max(time_pks)]);                    
                    ylim([peak_fminfmax(sex_ind,1) peak_fminfmax(sex_ind,2)]/Numharm_mal_fem(sex_ind))     
                    ylabel('WB Peak frequency','fontSize',ylablFSize)
                    %y=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).sound; 
                    %Nfft=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.Nfft_sec * fs;
                    %spectrogram(y,hann(wind_t_wbf_sec*fs),0,Nfft,fs,'yaxis');
                    %colorbar off
                    %colormap bone                                    
                    %hold on, zmax = get(gca, 'ZLim'); plot(time_pks,locs/Numharm_mal_fem(sex_ind) ,'r','lineWidth',20);                                    
                    
                    figure_eachWind_ind=0; % in order the figures are not stopped to be plotted after the max number of fig (since they are closed after each plot)
                    set(gcf,'Units','Inches');
                    pos = get(gcf,'Position');
                    set(gcf,'PaperPositionMode','Auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])
                    print(gcf,strcat(parentFold,folderNameTBCreated,'_',date,'.pdf'),'-dpdf','-r0')   
                    close                        
                end
            end
        end
    end
end



%% 14) Moving selected features to table (each feature(t) in a different row)
% + add temperature

sex_v=1:2; % 1 = male, 2=female

%%% Window duration for the stat (averaged over that window)
% Should be greater than 1/fs_trackit or data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.wind_t_wbf_sec:
t_step=wind_t_wbf_sec; %sec, new time window   ; should be big enough in order that when objects are averaged, they dont cancel each other

% start time for each feature
t_start=DurPause_sec -DurPause_sec; %DurPause_sec-DurStim_sec ;

% End time for each feature
t_end=DurPause_sec+DurStim_sec+ DurPause_sec; %twbf_start + 3*DurStim_sec  ; 2*DurPause_sec+DurStim_sec

%%%

% Number of steps for the newly samled data (averaged in the "step" interval if the initial step was smaller
%Nstep=(DurPause_sec*2+DurStim_sec)/t_step; 
Nstep=floor((t_end-t_start)/t_step);  % to be tested


try
    data_tbl.X=[];
end
try
    data_tbl.Y=[];
end
try
    data_tbl.Z=[];
end
try
    data_tbl.wbf=[];
end
try
    data_tbl.lVel=[];
end
try
    data_tbl.aVel=[];
end
try
    data_tbl.srTmprt_30cmHigh=[];
end
try
    data_tbl.srTmprt_85cmHigh=[];
end
time_v=[];
data_tbl2=[];



for sex_ind=sex_v
    disp(['Sex ' num2str(sex_ind)])
    for stimCode_ind=1:length(stimCode{sex_ind})
        disp([ '  Stim ' stimCode{sex_ind}{stimCode_ind}]);
        % We remove the folders without data (i.e. without folder inside)
        folderName  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                        folder_main,...
                        '*/' );    
        for foldNam_ind=folderName_v
            disp([ '    File ' num2str(foldNam_ind) '/' num2str(length(folderName_v)) ]);
            
            sex=data(foldNam_ind).sex;
            d=data(foldNam_ind).day;
            
            %%% Importing temperature
            temperature_name = dir(strcat(folder_main,folderName(foldNam_ind).name,'/*.txt'));
            if isempty(temperature_name)==0
                temperature = readtable(strcat(folder_main,folderName(foldNam_ind).name,'/',temperature_name(1).name ),...
                    'Format','%{MM/dd/uuuu HH:mm:ss}D %f %s %f %s %s %s','Delimiter', '\t');
                tmprt_high = temperature.Var2;
                tmprt_low = temperature.Var4;
                tmprt_date = temperature.Var1;
            else
                temperature=NaN;
            end        
            
            tmprt_tbl=table( tmprt_date,tmprt_low,tmprt_high,'VariableNames', {'date','T_30cmHigh','T_85cmHigh'});
            
            % We remove the folders without .csv files (i.e. with the video only, no tracked data):
            folderNameTrackit  = ListOfFoldersWhichDoNotIncludeParticularFileOrSubFolder( ...
                                    strcat(folder_main,folderName(foldNam_ind).name,'/trackit/'),...
                                    '/PostProc_Filtered_*Splined.csv' );    
            stim_v=data(foldNam_ind).stim_v; %  stim index
            for foldNamTrac_ind=1:length(folderNameTrackit)   
                
                %%% Subreplicate Temperature saved in table
                
                if isnan(stimOnset_sec{foldNam_ind}(foldNamTrac_ind))
                    data_tbl.srTmprt_30cmHigh(row_temp,1) = NaN ;
                    data_tbl.srTmprt_85cmHigh(row_temp,1)=  NaN  ;    
                else
                    time_start_absolute_mn = - str2double(sunset_start_time(1:2)) ...
                                             - str2double(sunset_start_time(4:5)) ...
                                             + str2double(data(foldNam_ind).timeSoundRec_start(1:2))...
                                             + str2double(data(foldNam_ind).timeSoundRec_start(4:5)) ;
                                                 % in general 15h30, but sometimes 15h45
                    time_read_offset_mn = read_start_mn - time_start_absolute_mn;                
                    % Absolute Time at the begining of the subreplicate
                    t_abs_sr_min=16*60 ... % origin
                        + round(stimOnset_sec{foldNam_ind}(foldNamTrac_ind)/60) ... % audacity time (from 16h or 15h45)
                        -time_read_offset_mn; % to make the diff between full-sound coordinate aand 16h-origin coordinate
                    % Row of 1 subreplicate
                    row_temp =   data_tbl.sr==foldNamTrac_ind... % same sr
                                 & data_tbl.d==str2double(data(foldNam_ind).day(2:3))...  % same day
                                 & strcmp(data_tbl.sex,sex(1))==1; % same sex
                    % Absolute Time vector of the subreplicate for each measured temperature
                     t_abs_tmprt_min = (tmprt_tbl.date.Hour)*60 + tmprt_tbl.date.Minute; % in min
                     index_tmprt_v = find( ismember(t_abs_tmprt_min , t_abs_sr_min));
                     index_tmprt=index_tmprt_v(1); % we choose arbitrary one (they should be neighbours)
                     % Temperature of the SR saved
                     data_tbl.srTmprt_30cmHigh(row_temp,1) = tmprt_tbl.T_30cmHigh(index_tmprt) ;
                     data_tbl.srTmprt_85cmHigh(row_temp,1)=  tmprt_tbl.T_85cmHigh(index_tmprt)  ;
                end
                    
                    
                
                for stim_v_ind=1:size(stim_v,1)                 
                    
                    VidData_stim=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).VidData_stim    ;                         
                    
                    %%% Only the rows we are interested in:
                    if  data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode == ...        
                            string( stimCode{sex_ind}{stimCode_ind})... % We look only for the current Stimulus code                
                        && (data_tbl.numbSwarming(data_tbl.stim==string( stimCode{sex_ind}{stimCode_ind})...
                                              & data_tbl.sr==foldNamTrac_ind...
                                              & data_tbl.d==str2double(data(foldNam_ind).day(2:3))...
                                              ) >0 ... % At least 1 mosq is swarming
                            || isnan(data_tbl.numbSwarming(data_tbl.stim==string( stimCode{sex_ind}{stimCode_ind})...
                                              & data_tbl.sr==foldNamTrac_ind...
                                              & data_tbl.d==str2double(data(foldNam_ind).day(2:3))))...
                                              ) ...  % we keep the NaN value
                        && any(   isempty(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak)==0 ...
                                & isempty(VidData_stim)==0) % to have at least either sound or trackit
                        
                        %disp('       stim_ stim_v_ind=1:size(stim_v,1)      
                            
                        % data_tbl rows
                        tblRow_day=    data_tbl.d==str2double(data(foldNam_ind).day(2:3)); % same day
                        tblRow_subr=    data_tbl.sr==foldNamTrac_ind; % same subreplicate
                        tblRow_stim = strcmp( cellstr(data_tbl.stim) , ...
                                              cellstr(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode)...
                                             )==1; % same stimulus
                        tbl_row=tblRow_day & tblRow_subr & tblRow_stim;
                        
                        % Rows of same day, same subreplicate and same stimulus are repeated Nstep time (the length of the features)                        
                        data_sr = repmat(data_tbl(tbl_row,:),Nstep,1); 

                        % data_sr rows
                        srRow_day=    data_sr.d==str2double(data(foldNam_ind).day(2:3)); % same day
                        srRow_subr=    data_sr.sr==foldNamTrac_ind; % same subreplicate
                        srRow_stim = strcmp( cellstr(data_sr.stim) , ...
                                          cellstr(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode)...
                                         )==1; % same stimulus
                        sr_row=srRow_day & srRow_subr & srRow_stim;
                        
                        % time index
                        data_sr.location(sr_row,1) = (t_start:t_step:t_end-t_step)'; % time location (sec)
                        data_sr.locationStim(sr_row,1) = 1*(ismemberf(data_sr.location(sr_row,1),DurPause_sec:t_step:(DurPause_sec+DurStim_sec-t_step),'tol',t_step/2)) ...
                                                       + 2*(ismemberf(data_sr.location(sr_row,1),DurPause_sec+DurStim_sec:t_step:(2*DurPause_sec+DurStim_sec-t_step),'tol',t_step/2)); % sound stimulus presence; % sound stimulus presence
                        
                        % Sound wbf
                        data_sr.wbf(sr_row,1) = NaN(Nstep,1); 
                        
                        %Synch flag
                        synchFlag=data(foldNam_ind).subrep(foldNamTrac_ind).synchFlag;
                        if isempty(synchFlag)
                            data_sr.synchFlag=NaN      * ones(size(data_sr,1),1);
                        else
                            data_sr.synchFlag=string(repmat(synchFlag,size(data_sr,1),1));
                        end
                        
                        % In case there is peak information available for that stimulus but no trackit data
                        if isempty(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak)==0 ...
                                && isempty(VidData_stim)

                            %%% Sound                            
                            wind_t_wbf_sec=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.wind_t_wbf_sec;
                            locs=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs;
                            time_pks=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.time_pks;

                            o_t_wbf=[ ones(length(time_pks),1) time_pks'  locs' ]; % the first column is just in order to use the "averagingOverEachObject" function (used with Trackit format data with the fiest column as a unique object)
                            data_sr.wbf( sr_row,1)=...
                                averagingOverEachObject(o_t_wbf,wind_t_wbf_sec,t_start,t_step,t_end-t_step);  % mean over the objects (here considering "1" object for the sound)                                
                            
                            %%% TRackit
                            % No trackit data: table is filled with NaN value
                            data_sr.obj(sr_row,1) = NaN;
                            data_sr.X(sr_row,1) = NaN;
                            data_sr.Y(sr_row,1) = NaN;
                            data_sr.Z(sr_row,1) = NaN;
                            data_sr.vel(sr_row,1) = NaN;
                            data_sr.avel(sr_row,1) = NaN;                            
                        
                        elseif ~isempty(VidData_stim) % in case there is Trackit data and sound peak information
                           %%% Sound                            
                            wind_t_wbf_sec=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.wind_t_wbf_sec;
                            locs=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.locs;
                            time_pks=data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).soundPeak.time_pks;

                            o_t_wbf=[ ones(length(time_pks),1) time_pks'  locs' ]; % the first column is just in order to use the "averagingOverEachObject" function (used with Trackit format data with the first column as a unique object)
                            data_sr.wbf( sr_row,1)=...
                                averagingOverEachObject(o_t_wbf,wind_t_wbf_sec,t_start,t_step,t_end-t_step);  % mean over the objects (here considering "1" object for the sound)                                
                       
                            
                            
                            % Rows are duplicate by the number of objects
                            
                            object_v=unique(unique(VidData_stim(:,1)))';                            
                            Nobject=length(object_v);
                            % Rows of same day, same subreplicate and same stimulus are repeated Nobject times
                            data_sr = repmat(data_sr(sr_row,:),Nobject,1); 
                            data_sr.obj=repelem((1:Nobject)',Nstep,1); % The object indexes are inserted
                            objRow_day=    data_sr.d==str2double(data(foldNam_ind).day(2:3)); % same day
                            objRow_subr=    data_sr.sr==foldNamTrac_ind; % same subreplicate
                            objRow_stim = strcmp( cellstr(data_sr.stim) , ...
                                      cellstr(data(foldNam_ind).subrep(foldNamTrac_ind).stimResp(stim_v_ind).stimCode)...
                                     )==1; % same stimulus
                            for object_ind=1:length(object_v)  % MaJ corr bug 1/03/2020: I had object_v instead of 1:length(object_v)
                                        % We transform the object index so that it starts from 1 and is incremented by 1
                                objRow_obj= data_sr.obj(:,1)==object_ind; % same object
                                obj_row=objRow_day & objRow_subr & objRow_stim & objRow_obj; 
                                % MaJ corr bugs 1/03/2020: 
                                    %1)  I had sr_row instead of obj_row in the data_sr.{X,Y,Z,etc} rows
                                    %1)  I had object_ind instead object_v(object_ind)
                                data_sr.X(obj_row,1) = averagingOverEachObject(...
                                                            [VidData_stim(VidData_stim(:,1)==object_v(object_ind),1:2) ...
                                                             VidData_stim(VidData_stim(:,1)==object_v(object_ind),3)],...
                                                            1/fs_trackit,t_start,t_step,t_end-t_step);                                
                                data_sr.Y(obj_row,1) = averagingOverEachObject(...
                                                            [VidData_stim(VidData_stim(:,1)==object_v(object_ind),1:2) ...
                                                             VidData_stim(VidData_stim(:,1)==object_v(object_ind),4)],...
                                                            1/fs_trackit,t_start,t_step,t_end-t_step);                                                            
                                data_sr.Z(obj_row,1) = averagingOverEachObject(...
                                                            [VidData_stim(VidData_stim(:,1)==object_v(object_ind),1:2) ...                                    
                                                            VidData_stim(VidData_stim(:,1)==object_v(object_ind),5)],...
                                                            1/fs_trackit,t_start,t_step,t_end-t_step);  
                                data_sr.vel(obj_row,1) = averagingOverEachObject(...
                                                            [VidData_stim(VidData_stim(:,1)==object_v(object_ind),1:2) ...                                    
                                                            sqrt(sum(VidData_stim(VidData_stim(:,1)==object_v(object_ind),6:8).^2,2))],...
                                                            1/fs_trackit,t_start,t_step,t_end-t_step);
                                data_sr.avel(obj_row,1) = averagingOverEachObject(...
                                                            [VidData_stim(VidData_stim(:,1)==object_v(object_ind),1:2) ...                                    
                                                            VidData_stim(VidData_stim(:,1)==object_v(object_ind),9)],...
                                                            1/fs_trackit,t_start,t_step,t_end-t_step); 
                            end
                            
                        end    
                        data_tbl2=[data_tbl2 ;data_sr ]; % adding the subreplicates rows together
                    end
                end
            end
        end
    end
end








%% 15) %%%%%%%%%%%%%%%%%%%%%%%%%%% GEneration of the table file

folder_tbl='/Users/lionel/Lionoil/Recherche/1703_IRD_anofeel/experiments/soundExperiments/type/soundProofChamber/dataAndExtractedFeatures/181000_exp1/data/';

t_start=0;
t_step=0.04;
t_end=27;

% File with SPL mena and extreme error for each stimulus (from SPL-stimuli_calculation.ods)
spl_stimdata_tbl = readtable(strcat('SPL_stim_mean_error.csv'));%,'Format','%c %D %d %D %q %c %q %d %D %f %c %f %f %q %f %q %D %D %d %q %d %d %q'  );


%%% Addition of new variables
stim_var={'stim_sex','stim_species','stim_type','stim_1VSswarm','stim_NumbHarmonics','stim_soundLevel'};%,...
disp('1/2: Adding of new variables...')
% needed for comparaison (des arrondis font que les valeurs sont un tout petit peu plus tpetite en vrai (10^-15) que ce que affiché par matlab)
press=cell2mat(data_tbl2.PressureAthmos_15h_18h);
%data_tbl2.PressureAthmos_15h= str2num(press(:,1:4));
%data_tbl2.PressureAthmos_18h= str2num(press(:,6:9)); 
data_tbl2.PressureAthmosDiff_15h18h= str2num(press(:,6:9))-str2num(press(:,1:4)); 
data_tbl2.motherAgeMin= extractBefore(data_tbl2.MotherAge_day_min_max,'-');
data_tbl2.motherAgeMax= extractAfter(data_tbl2.MotherAge_day_min_max,'-');
data_tbl2.mother_BF= datestr(data_tbl2.mother_BF,'dd/mm/yyyy');
% Changing loudness labels of the 1-male sound stimuli as they don't fit with the loudness label swarm-male sound stimulis
    % We add each stim codes individually in the table as a variable instad of the whole ' global code' variable
    stimCode_cell= char(table2cell(data_tbl2(:,'stim')));
    valueset={{'f' 'm'}; {'c' 'g'} ; {'n' 's'} ;{ '1' '2'} ;{ '1' '2' 'a'};{ '1b' '2b' '3b' '4b' '0' '1' '2' '3' '4'} };
    for kk=1:length(stim_var)
        disp(['  ' stim_var{kk} '...'])
        data_tbl2.(stim_var{kk})=categorical(cellstr(stimCode_cell(:,kk)),valueset{kk}); 
        if strcmp(stim_var{kk},'stim_soundLevel') % soundLevel
           temp=cellstr(stimCode_cell(:,6)); 
            for jj=1:4
                temp ( data_tbl2.stim_1VSswarm=='1' & strcmp(temp,num2str(jj))) = cellstr(strcat(num2str(jj),'b')); %the sound level is translated of 10 units to create a different sound level for the 1-male sound stimuli
            end
            data_tbl2.(stim_var{kk}) = categorical( temp,valueset{6});
        end
    end
% We put the exact SPL and SPL error into the table
disp('2/3: Writing SPL and SPL error into table...')
stim_SPL=zeros(size(data_tbl2,1),2);
kk_step_end=num2str(floor(size(data_tbl2,1)/1000));
stimdata_NS= strcmp(  spl_stimdata_tbl{:,1}  ,  'NS') ; % No Sound (i.e. locationStim=0,2)
for kk=1:size(data_tbl2,1)        
    %if rem(kk,1000)==0, disp(['  ' strcat(num2str(kk/1000),"/",kk_step_end)]); end;
    if data_tbl2{kk,'locationStim'}==0 || data_tbl2{kk,'locationStim'}==2
               stim_SPL(kk,1:3)=spl_stimdata_tbl{stimdata_NS,2:4};
    elseif data_tbl2{kk,'locationStim'}==1 % Sound stimulus
        stimdata_ind= strcmp(  spl_stimdata_tbl{:,1}  ,  data_tbl2.('stim'){kk}) ;
        stim_SPL(kk,1:3)=spl_stimdata_tbl{stimdata_ind,2:4};
    else
        error('locationStim should be 0, 1 or 2, shouldn''t it?')
    end
end
data_tbl2.('stim_SPL')=stim_SPL(:,1);
data_tbl2.('stim_SPL_err')=stim_SPL(:,2);
data_tbl2.('stim_SPL_cat')=stim_SPL(:,3);
        

if t_step>=0.1
	data_tbl2.location=single(round(data_tbl2.location,1)); 
elseif t_step >=0.01
	data_tbl2.location=single(round(data_tbl2.location,2)); 
elseif t_step >=0.001
	data_tbl2.location=single(round(data_tbl2.location,3));
else
    error("write the case when t <0.001"); % 1 for t_step=0.1, 2 for t_step=0.01, 3 for t_step=0.001 for t etc
end

                
%%% Saving data
disp('3/3: Saving data to computer...');
save(strcat(folder_main,'_data_tbl2_tstart-',num2str(t_start),'s_tstep-', num2str(t_step),'s_tend-',num2str(t_end),'s_',date,'.mat'),'data_tbl2','-v7.3' );

disp('Finished')


