
############################################################################################
################### RESPONSE TO OPPOSITE-SEX SOUND / Figure used in paper  (R code) ########
# Author: Lionel Feugère lionel.feugere@riseup.net
# Institutions: MIVEGEC - Institut de Recherche pour le Développement, France
#               NRI - University of Greenwhich, UK
############################################################################################

library(lme4) # mixed model lmer()
library(blme) # to face with singularity issue with lmer(), by using blmer instead
library(forcats) # to use interaction()
library(ggpubr) # ggplots
library(scales) # to change color manually from ggplots
library(patchwork) # To combine plots from different data with ggplot

data <-read.table("data_tbl_sex=both_removeGamb0_removeSplB0_Tns=9-9.96_Ts=10-10.96_Nobj=NaN_norm1_quant=0.75_20-Jan-2021_reduced-param-number.txt",header=TRUE,sep = ",")

# We append the window duration to the parameter column names and remove the "mean_" string from the parameter column names:
firstCol_parameter_i <- 14 # first column with an extracted parameter from sound or tracking
for (kk in seq(firstCol_parameter_i, length(data))){
	colnames(data)[colnames(data)==colnames(data[kk])] <- paste(substr(colnames(data[kk]),6,nchar(colnames(data[kk]))),"_1s",sep="") # "_1s" append, and removing the "mean_" string
	}
	
data$d<- as.factor(data$d) # as d are numbers otherwise
data$ds<- interaction(data$d,data$sex) # random variable for LMER model if using both sex
data$stim_1VSswarm[data$stim_1VSswarm==1] <- 'sgl' # single mosq in stim
data$stim_1VSswarm[data$stim_1VSswarm==2] <- 'grp' # group mosq in stim
data$stim_1VSswarm <- factor(data$stim_1VSswarm, levels = c("sgl", "grp")) # to have sgl as first factor

# make character string as factor
data$locationStim <- as.factor(data$locationStim)
data$sex <- as.factor(data$sex)
data$stim <- as.factor(data$stim)
data$stim_sex <- as.factor(data$stim_sex)
data$stim_species <- as.factor(data$stim_species)
data$stim_type <- as.factor(data$stim_type)
data$stim_NumbHarmonics <- as.factor(data$stim_NumbHarmonics)
data$stim_soundLevel <- as.factor(data$stim_soundLevel)

# Initial SPL values (without inter-harmonics noise correction -- see paper Method)
# Will be used only for Subset A
data$stim_SPL_notCorr <- data$stim_SPL
data$stim_SPL_cat_notCorr <- data$stim_SPL_cat

# Corrected SPL values with inter-harmonic noise correction for two-harmonic single-female sounds (-8dB)
rows <- data$stim_1VSswarm=='sgl' & data$stim_NumbHarmonics=='2' 
data$stim_SPL[rows] <- data$stim_SPL[rows] - 8
data$stim_SPL_cat[rows] <- data$stim_SPL_cat[rows] -8
# correection  valid only when the background noise level is much smaller than the sound stimulus, then we removed the smallest sound level:
data[rows & data$stim_SPL< min(data$stim_SPL_notCorr),] <- NA
data <- na.omit(data) # needed for Predict / bootMer, otherwise error witg bootMer "missing value where TRUE/FALSE needed" (for angular velo, not with wbf)

# SPL_cat as factors
data$stim_SPL_cat <- as.factor(data$stim_SPL_cat)
data$stim_SPL_cat_notCorr <- as.factor(data$stim_SPL_cat_notCorr)
ordered(data$stim_SPL_cat)
ordered(data$stim_SPL_cat_notCorr)

attach(data)

# User parameters
var_nam <- c("avel_QuantH_diff_1s","wbf_QuantH_diff_1s")

# Plot size settings
ylim_v <- array(c(c(min(data[,var_nam[1]]),max(data[,var_nam[1]])),c(min(data[,var_nam[2]]),max(data[,var_nam[2]]))),dim = c(2,2)) # Y-axis limit
outliersShape=23
size_mean<-4 # mean-symbol size
shape_mean<-20 # Number of mean-symbol shape
axis_fontSize<-10 # font size on axis
sd_w<-0.2 # error horizontal-bar width
legend_font=9
legend_pos <- c(0.8, 0.15)
plot_margin <- array( c( c(0.05,0,0,0),c(-0.05,0,0,0) ),dim = c(4,2)) 
	# row: first subplot row, second subplot row 
	# col: top, right bottom left
	# +0.05 in order that column labels looks like a be column label and not just sublot label
	# -0.1 ro remove extra space
plot_margin_unit <- "npc"
kk_i<- -1 # initialization for the subplot index
title1<-""
title2<-""
title3<-""
title4<-""
title5<-""
title6<-""
title7<-""
title8<-""
title9<-""
title10<-""


# colors of boxplots
color_A<- hue_pal()(4)[c(3,2)]
color_B<- hue_pal()(4)[c(3,4)]
color_C<- hue_pal()(4)[c(2,1)]
 		
		
			
	
	


######## Subset A: With coluzzii single/group 1harm/2harm female stim, same 1st harm amplitude (but different SPL_cat for 1-fem 1-harm because low Signal-to-noise ratio between the 2 harmonics; cf paper method)

# Selecting rows for Subset A 
row<- locationStim==1 & stim_type=='n' & stim_sex=='f'  & stim_species=='c' & (stim_soundLevel =='3' | stim_soundLevel =='3b') & stim_1VSswarm=='sgl'


xlabel_v<-c("","Number of harmonic")
x2label_v<-"Sound level\n(dB SVL)"	
ylab_v <- c("Increase of upper-quartile ang-speed (rad/s)","Increase of upper-quartile WBF (Hz)")	
x_ticks <-	c(1,2)	

dp11<- ggplot(data[row,],aes(y= avel_QuantH_diff_1s,x= stim_NumbHarmonics,color= stim_SPL_cat_notCorr))+
		geom_boxplot(outlier.shape= outliersShape)+
		labs(color=x2label_v)+
		ylim(ylim_v[,1])+
		stat_summary(fun.y=mean, geom="point",shape=shape_mean, size= size_mean, aes(color = stim_SPL_cat_notCorr), position = position_dodge(width = .75)) + # position = position_dodge(width = .75) needed to make them aligned with boxplot (?!)
		stat_summary(fun.data=mean_se, geom="errorbar", aes(color = stim_SPL_cat_notCorr), position = position_dodge(width = .75),width=sd_w)+
		ggtitle(title1)+
		theme_classic()+				
		theme(axis.text.x=element_text(angle=0,hjust=0.5,vjust=0.5),
						legend.title = element_text(size = legend_font),
				        legend.text = element_text(size = legend_font),
				        legend.key.size =unit(.01, "cm"),
				        legend.box = "horizontal",
						legend.position=legend_pos,
						axis.text  = element_text(size=axis_fontSize), # axis text		
						plot.margin=unit(plot_margin[,1], plot_margin_unit) )+
		geom_hline(yintercept=0, linetype="dashed", color = "black")+
		scale_x_discrete(labels= x_ticks)+ 
		ylab(ylab_v[1])+
		xlab(xlabel_v[1])+
		scale_colour_manual(values = color_A)	+
		theme(legend.position = "none")
	
	
dp21<- ggplot(data[row,],aes(y= wbf_QuantH_diff_1s,x= stim_NumbHarmonics,color= stim_SPL_cat_notCorr))+
		geom_boxplot(outlier.shape= outliersShape)+
		labs(color=x2label_v)+
		ylim(ylim_v[,2])+
		stat_summary(fun.y=mean, geom="point",shape=shape_mean, size= size_mean, aes(color = stim_SPL_cat_notCorr), position = position_dodge(width = .75)) + # position = position_dodge(width = .75) needed to make them aligned with boxplot (?!)
		stat_summary(fun.data=mean_se, geom="errorbar", aes(color = stim_SPL_cat_notCorr), position = position_dodge(width = .75),width=sd_w)+
		ggtitle(title1)+
		theme_classic()+				
		theme(axis.text.x=element_text(angle=0,hjust=0.5,vjust=0.5),
						legend.title = element_text(size = legend_font),
				        legend.text = element_text(size = legend_font),
				        legend.key.size =unit(.01, "cm"),
				        legend.box = "horizontal",
						legend.position=legend_pos,
						axis.text  = element_text(size=axis_fontSize), # axis text		
						plot.margin=unit(plot_margin[,2], plot_margin_unit) )+
		geom_hline(yintercept=0, linetype="dashed", color = "black")+
		scale_x_discrete(labels= x_ticks)+ 
		ylab(ylab_v[2])+
		xlab(xlabel_v[2])+
		scale_colour_manual(values = color_A)		+
		theme(legend.position = "none")





######## Subset B //  coluzzii female stim, testing syntetic versus natural sound , single vers group

# Selecting rows for Subset B
row<- locationStim==1 & stim_NumbHarmonics==1 &  stim_sex=='f'  & stim_species=='c' & stim_1VSswarm=='sgl'


xlabel_v<-c("","Stimulus type")
x2label_v<-"Sound level\n(dB SVL)"	
ylab_v <- c("","")
x_ticks <-	c("Record","Synthetic")

dp12<- ggplot(data[row,],aes(y= avel_QuantH_diff_1s,x= stim_type,color= stim_SPL_cat))+
		geom_boxplot(outlier.shape= outliersShape)+
		labs(color=x2label_v)+
		ylim(ylim_v[,1])+
		stat_summary(fun.y=mean, geom="point",shape=shape_mean, size= size_mean, aes(color = stim_SPL_cat), position = position_dodge(width = .75)) + # position = position_dodge(width = .75) needed to make them aligned with boxplot (?!)
		stat_summary(fun.data=mean_se, geom="errorbar", aes(color = stim_SPL_cat), position = position_dodge(width = .75),width=sd_w)+
		ggtitle(title1)+
		theme_classic()+		
		theme(axis.text.x=element_text(angle=0,hjust=0.5,vjust=0.5),
						legend.title = element_text(size = legend_font),
				        legend.text = element_text(size = legend_font),
				        legend.key.size =unit(.01, "cm"),
				        legend.box = "horizontal",
						legend.position=legend_pos,
						axis.text  = element_text(size=axis_fontSize), # axis text		
						plot.margin=unit(plot_margin[,1], plot_margin_unit) )+
		geom_hline(yintercept=0, linetype="dashed", color = "black")+
		scale_x_discrete(labels= x_ticks)+ 
		ylab(ylab_v[1])+
		xlab(xlabel_v[1])+
		scale_colour_manual(values = color_B)		+
		theme(legend.position = "none")
	
	
dp22<- ggplot(data[row,],aes(y= wbf_QuantH_diff_1s,x= stim_type,color= stim_SPL_cat))+
		geom_boxplot(outlier.shape= outliersShape)+
		labs(color=x2label_v)+
		ylim(ylim_v[,2])+
		stat_summary(fun.y=mean, geom="point",shape=shape_mean, size= size_mean, aes(color = stim_SPL_cat), position = position_dodge(width = .75)) + # position = position_dodge(width = .75) needed to make them aligned with boxplot (?!)
		stat_summary(fun.data=mean_se, geom="errorbar", aes(color = stim_SPL_cat), position = position_dodge(width = .75),width=sd_w)+
		ggtitle(title1)+
		theme_classic()+		
		theme(axis.text.x=element_text(angle=0,hjust=0.5,vjust=0.5),
						legend.title = element_text(size = legend_font),
				        legend.text = element_text(size = legend_font),
				        legend.key.size =unit(.01, "cm"),
				        legend.box = "horizontal",
						legend.position=legend_pos,
						axis.text  = element_text(size=axis_fontSize), # axis text			
						plot.margin=unit(plot_margin[,2], plot_margin_unit) )+
		geom_hline(yintercept=0, linetype="dashed", color = "black")+
		scale_x_discrete(labels= x_ticks)+ 
		ylab(ylab_v[2])+
		xlab(xlabel_v[2])+
		scale_colour_manual(values = color_B)		+
		theme(legend.position = "none")



		
		
		


	
######## subset C // coluzzii single/grp female stim, SPL (continuous) 

# Selecting rows for Subset C
row<- locationStim==1 & stim_type=='n' & stim_NumbHarmonics!='1'   & stim_sex=='f' & stim_species=='c' # & stim_1VSswarm=='sgl'  

xlabel_v<-c("","Corrected sound level (dB SVL)")
x2label_v<-"Number of female(s)"	
ylab_v <- c("","")

### For the 95%-CI interval modelled from blmer // Modelled for an unspecified day with using bootMer (nsim=500)
## variables commun to ang speed adn WBF
X_abscissa_start<- 9 # dB
# Variables (we add two NA in order to have two more lines for each stim_type for the additional SPL value (X_abscissa_start) in the model )
SPL <- c(rep(X_abscissa_start,2),data$stim_SPL[row])  # Sound Pressure LEvelday<- c(NA,data$ds[row_wbf]) # random component
day<- as.factor(c(rep(NA,2),data$ds[row])) # random component
Nfem<- factor( c('sgl','grp',as.character(data$stim_1VSswarm[row])),levels = c("sgl", "grp")) # the additional 'sgl' and 'grp' are there for the 2 additional same SPL values I added (X_abscissa_start) , i.e. one for each stim_1VSswarm
SPL_thresh_avel <- c(20) # empirical 95%-confident hearing threshold for single fem stimulus, from the graph
SPL_thresh_wbf <- c(20) # empirical 95%-confident hearing threshold for single fem stimulus, from the graph


### Angular speed
mod_avel<-blmer(avel_QuantH_diff_1s ~ stim_SPL* stim_1VSswarm + (1|ds), data=data[row,],REML='false')
mod1<-update(mod_avel,~.-stim_SPL: stim_1VSswarm); anova(mod_avel,mod1) # p=0.070

## Fixed-effect component mean and 95%-CI // Modelled for an unspecified day with using bootMer (nsim=500)
maxAvelDiff<- c(rep(NA,2),data$avel_QuantH_diff_1s[row]) # Maximum WBF difference (Hz)
# Fit an LMM to the observations:
mod_pred_avel<-blmer(maxAvelDiff ~ SPL*Nfem + (1| day),REML='false')		 
# Fixed Effects: 
#              (Intercept)                   stim_SPL  
#                 -1.87972                    0.12162  
#         stim_1VSswarmgrp  stim_SPL:stim_1VSswarmgrp  
#                  0.32502                   -0.04839  
# mean value for grp and single:
mean(maxAvelDiff[Nfem=='grp' & is.na(maxAvelDiff)==0 ]) # 0.570 rad/s
mean(maxAvelDiff[Nfem=='sgl' & is.na(maxAvelDiff)==0 ]) # 1.21 rad/s
# Make predictions for maxWbfDiff  = a*SPL  + b for an unspecified day (Method from https://www.rdocumentation.org/packages/lme4/versions/1.1-21/topics/predict.merMod)
predicted_avel <- 0
predicted_avel <- data.frame(day = NA, Nfem=Nfem, spl = SPL)
predict_avel.fun <- function(my.lmm) { # Need to be redefined (was already above) because predicted2 cannot be called as a 2nd argument for the function to be used in bootMer 
  predict(my.lmm, newdata = predicted_avel, re.form = NA)   # This is predict.merMod 
}
predicted_avel$ml.value <- predict_avel.fun(mod_pred_avel)
# Make predictions in 100 bootstraps of the LMM. Use these to get confidence intervals.
mod_pred_avel.boots <- bootMer(mod_pred_avel, predict_avel.fun, nsim = 500)
predicted_avel <- cbind(predicted_avel, confint(mod_pred_avel.boots,level = 0.95))
##

### WBF
mod_wbf<-blmer(wbf_QuantH_diff_1s ~ stim_SPL* stim_1VSswarm + (1|ds), data=data[row,],REML='false')
mod1<-update(mod_wbf,~.-stim_SPL: stim_1VSswarm); anova(mod_avel,mod1) # p<0.001
## Fixed-effect component mean and 95%-CI // Modelled for an unspecified day with using bootMer (nsim=500)
maxWbfDiff <- c(rep(NA,2),data$wbf_QuantH_diff_1s[row]) # Maximum WBF difference (Hz)
# Fit an LMM to the observations:
mod_pred_wbf<-blmer(maxWbfDiff ~ SPL*Nfem + (1| day),REML='false')		 
# Fixed Effects:
#              (Intercept)                   stim_SPL  
#                  -38.679                      2.294  
#         stim_1VSswarmgrp  stim_SPL:stim_1VSswarmgrp  
#                   21.653                     -1.341  
# mean value for grp and single:
mean(maxWbfDiff[Nfem=='grp' & is.na(maxAvelDiff)==0 ]) # 10.5 Hz
mean(maxWbfDiff[Nfem=='sgl' & is.na(maxAvelDiff)==0 ]) # 19.6 Hz
# Make predictions for maxWbfDiff  = a1*SPL + a2*Nfem + a3*SPL*Nfem  + b for an unspecified day (Method from https://www.rdocumentation.org/packages/lme4/versions/1.1-21/topics/predict.merMod)
predicted_wbf <- 0
predicted_wbf <- data.frame(day = NA, Nfem=Nfem, spl = SPL)
predict_avel.fun <- function(my.lmm) { 
 # Need to be redefined (was already above) because predicted2 cannot be called as a 2nd argument for the function to be used in bootMer 
  predict(my.lmm, newdata = predicted_wbf, re.form = NA)   # This is predict.merMod 
}
predicted_wbf$ml.value <- predict_avel.fun(mod_pred_wbf)
# Make predictions in 100 bootstraps of the LMM. Use these to get confidence intervals.
mod_pred_wbf.boots <- bootMer(mod_pred_wbf, predict_avel.fun, nsim = 500)
predicted_wbf <- cbind(predicted_wbf, confint(mod_pred_wbf.boots,level = 0.95))
##


### Put all data together
data_subsetC <- data.frame(SPL=SPL, Nfem=Nfem, avel=maxAvelDiff, maxAvelDiff_pred= predicted_avel$ml.value, maxAvelDiff_2p5= predicted_avel$'2.5 %', maxAvelDiff_97p5= predicted_avel$'97.5 %', maxWbfDiff=maxWbfDiff, maxWbfDiff_pred= predicted_wbf$ml.value, maxWbfDiff_2p5= predicted_wbf$'2.5 %',maxWbfDiff_97p5= predicted_wbf$'97.5 %')

### plot

dp13<- ggplot(data_subsetC)+
		geom_point(aes(y= maxAvelDiff,x= SPL,colour= Nfem))+	
		geom_ribbon(aes(x= SPL, 
  						ymin= maxAvelDiff_2p5,
                        ymax= maxAvelDiff_97p5,
                        fill=Nfem),
                     color=NA,alpha=0.3)+
		scale_fill_manual(values= c("sgl"=color_C[1],"grp"=color_C[2]), labels = c("1", "30"),name= x2label_v)+                
		scale_colour_manual(values= c("sgl"=color_C[1],"grp"=color_C[2]), labels = c("1", "30"),name= x2label_v) +
		geom_line(aes(y= maxAvelDiff_pred,x= SPL,colour= Nfem))+
		geom_vline(aes(xintercept= SPL_thresh_avel), linetype="dashed", color = color_A[2],size=0.5)+
		theme_classic()+# base_size = 16
		theme(axis.text.x=element_text(angle=0,hjust=0.5,vjust=0.5),
			legend.title = element_text(size = legend_font),
			legend.text = element_text(size = legend_font),
			legend.key.size =unit(.01, "cm"),
			legend.box = "horizontal",
			legend.position=legend_pos,
			axis.text  = element_text(size=axis_fontSize), # axis text
			plot.margin=unit(plot_margin[,1], plot_margin_unit) )+
		geom_hline(yintercept=0, linetype="dashed", color = "black")+
		ylab(ylab_v[1])+
		xlab(xlabel_v[1])+
		scale_x_continuous( breaks=c(SPL_thresh_avel,round(unique(SPL),digits = 0)))+
		ylim(ylim_v[,1])+
		ggtitle(title1)
		

dp23<- ggplot(data_subsetC)+
		geom_point(aes(y= maxWbfDiff,x= SPL,colour= Nfem))+	
		geom_ribbon(aes(x= SPL, 
  						ymin= maxWbfDiff_2p5,
                        ymax= maxWbfDiff_97p5,
                        fill=Nfem),
                     color=NA,alpha=0.3)+
		scale_fill_manual(values= c("sgl"=color_C[1],"grp"=color_C[2]), labels = c("1", "30"),name= x2label_v)+                
		scale_colour_manual(values= c("sgl"=color_C[1],"grp"=color_C[2]), labels = c("1", "30"),name= x2label_v) +
		geom_line(aes(y= maxWbfDiff_pred,x= SPL,colour= Nfem))+
		geom_vline(aes(xintercept= SPL_thresh_wbf), linetype="dashed", color = color_A[2],size=0.5)+
		theme_classic()+# base_size = 16
		theme(axis.text.x=element_text(angle=0,hjust=0.5,vjust=0.5),
			legend.title = element_text(size = legend_font),
			legend.text = element_text(size = legend_font),
			legend.key.size =unit(.01, "cm"),
			legend.box = "horizontal",
			legend.position=legend_pos,
			axis.text  = element_text(size=axis_fontSize), # axis text
			plot.margin=unit(plot_margin[,2], plot_margin_unit) )+
		geom_hline(yintercept=0, linetype="dashed", color = "black")+
		ylab(ylab_v[2])+
		xlab(xlabel_v[2])+
		scale_x_continuous( breaks=c(SPL_thresh_wbf,round(unique(SPL),digits = 0)))+
		ylim(ylim_v[,2])+
		ggtitle(title1)
		
		
		
		
		

## Plot all in a single window	with windows in multi-subplots
library("cowplot")
ggdraw() +
  draw_plot(dp11, x = 0, y = .5, width = .25, height = .5) + 
  # x, y: The x/y location of the lower left corner of the plot.
     #width, height: the width and the height of the plot
  draw_plot(dp12, x = .25, y = .5, width = .25, height = .5) +
  draw_plot(dp21, x = 0, y = 0, width = 0.25, height = 0.5) +
  draw_plot(dp22, x = 0.25, y = 0, width = 0.25, height = 0.5) +  
  draw_plot(dp13, x = 0.5, y = .5, width = 0.5, height = 0.5) +  
  draw_plot(dp23, x = 0.5, y = 0, width = 0.5, height = 0.5) +    
  draw_plot_label(label = c("A", "B", "C","","","","",""), size = 15,
                  x = c(0.05, 0.30, 0.55,NA,NA,NA,NA,NA), y = c(1.01, 1.01, 1.01,NA,NA,NA,NA,NA)) 
                  # x, y: Vector containing the x and y position of the labels, respectively.




#ggarrange(dp11,dp12,dp13,dp21,dp22,dp23,
#	          labels = c("",
#	          			"",
#	          			"",
#	          			" "," "," "), 
#	          vjust=rep(2, 6), # movel the labels along the vertical axis
#	          hjust=rep(-0.2, 6) , 	# Move the label along the right-left axis          
#	          ncol = 4, nrow = 2,
#	          layout_matrix = rbind(c(1,1), c(2,3))

subDir1="fig/"
ggsave(paste( subDir1,'paper_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))






