##########################################################################################################
################### RESPONSE TO FEMALE SOUND 
#					Effect of SPL, number of harmonics, type of sound, number of mosquitoes  #############
# 					(R code)
# Author: Lionel Feugère lionel.feugere@riseup.net
# institutions: MIVEGEC - Institut de Recherche pour le Développement, France
#               NRI - University of Greenwhich, UK
##########################################################################################################
	
library(lme4) # mixed model lmer()
library(blme) # to face with singularity issue with lmer(), by using blmer instead
library(forcats) # to use interaction()
library(ggpubr) # ggplots
library(car)

data <-read.table("data_tbl_sex=both_removeGamb0_removeSplB0_Tns=9-9.96_Ts=10-10.96_Nobj=NaN_norm1_quant=0.75_20-Jan-2021_reduced-param-number.txt",header=TRUE,sep = ",")

# We append the window duration to the parameter column names and remove the "mean_" string from the parameter column names:
firstCol_parameter_i <- 14 # first column with an extracted parameter from sound or tracking
for (kk in seq(firstCol_parameter_i, length(data))){
	colnames(data)[colnames(data)==colnames(data[kk])] <- paste(substr(colnames(data[kk]),6,nchar(colnames(data[kk]))),"_1s",sep="") # "_1s" append, and removing the "mean_" string
	}

data$d<- as.factor(data$d) # as d are numbers otherwise
data$ds<- interaction(data$d,data$sex) # random variable for LMER model if using both sex
data$stim_NumbHarmonics <- as.factor(data$stim_NumbHarmonics) 
data$locationStim <- as.factor(data$locationStim)
data$stim_1VSswarm[data$stim_1VSswarm==1] <- 'sgl' # single mosq in stim
data$stim_1VSswarm[data$stim_1VSswarm==2] <- 'grp' # group mosq in stim
data$stim_1VSswarm <- as.factor(data$stim_1VSswarm)

# make character string as factor
data$sex <- as.factor(data$sex)
data$stim <- as.factor(data$stim)
data$stim_sex <- as.factor(data$stim_sex)
data$stim_species <- as.factor(data$stim_species)
data$stim_type <- as.factor(data$stim_type)
data$stim_NumbHarmonics <- as.factor(data$stim_NumbHarmonics)
data$stim_soundLevel <- as.factor(data$stim_soundLevel)

# Initial SPL values (without inter-harmonics noise correction -- see paper Method)
# Will be used only for Subset B
data$stim_SPL_notCorr <- data$stim_SPL
data$stim_SPL_cat_notCorr <- data$stim_SPL_cat

# Corrected SPL values with inter-harmonic noise correction for two-harmonic single-female sounds (-8dB)
rows <- data$stim_1VSswarm=='sgl' & data$stim_NumbHarmonics=='2'
data$stim_SPL[rows] <- data$stim_SPL[rows] - 8
data$stim_SPL_cat[rows] <- data$stim_SPL_cat[rows] -8
# correection  valid only when the background noise level is much smaller than the sound stimulus, then we removed the smallest sound level:
data[rows & data$stim_SPL< min(data$stim_SPL_notCorr),] <- NA
data <- na.omit(data) # needed for Predict / bootMer, otherwise error witg bootMer "missing value where TRUE/FALSE needed" (for angular velo, not with wbf)

# SPL_cat as factors
data$stim_SPL_cat <- as.factor(data$stim_SPL_cat)
data$stim_SPL_cat_notCorr <- as.factor(data$stim_SPL_cat_notCorr)
ordered(data$stim_SPL_cat)
ordered(data$stim_SPL_cat_notCorr)

# Interaction variable for multicomparison
data$stim_SPL1vsSwam <- interaction(  list(as.factor(data$stim_SPL),data$stim_1VSswarm))

attach(data)

# Rows for diff parameter and coluzzii female stimuli
row_fc_diff <- locationStim==1 & stim_sex=='f' & stim_species=='c' 
		




################ Statistical analysis ###########################




######## Subset A: 1-female stim, 1 or 2 harmonics, female sound-recording ############## 
row<- row_fc_diff & stim_type=='n' & stim_1VSswarm=='sgl' & (stim_soundLevel =='3' | stim_soundLevel =='3b')

# Response variable to be selected:
var_name="avel_QuantH_diff_1s"
	# stim_NumbHarmonics	chisq(1)=2.61, p=0.11
	# 1 harm: BH-corr one-sample t(9)=5.67 p<0.001 mean=1.55" ***
	# 2 harm: BH-corr one-sample t(9)=4.98 p<0.001 mean=1.03"***
var_name="wbf_QuantH_diff_1s"
	# stim_NumbHarmonics	chisq(1)=1.13, p=0.29
	# 1 harm: BH-corr one-sample t(9)=5.17 p<0.001 mean=16.356" ***
	# 2 harm: BH-corr one-sample t(9)=4.60 p=0.0013 mean=13.1"**

# Model reduction
	mod<-blmer(eval(parse(text = var_name)) ~ stim_NumbHarmonics + (1|ds), data=data[row,],REML='false')
	mod1<-update(mod,~.-stim_NumbHarmonics); anova(mod,mod1) 
	# if significant, Model assumption check:
	qqPlot(resid(mod),distribution="norm", stim_NumbHarmonics[row])  # Checking model residual normality
	fligner.test(eval(parse(text = var_name))[row], stim_NumbHarmonics[row]) # Deviation homogeinety

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_NumbHarmonics",color="stim_SPL",notch =TRUE,ylab= var_name,xlab="N harm",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))

# Commpare each distribution to 0
dd<- unique(stim_NumbHarmonics[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_NumbHarmonics ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
	print(paste("one-sample t(",round(tt$parameter,5),")=",round(tt$statistic,5)," p=",round(tt$p.value,5)," mean=",round(tt$estimate,3),sep=""))		
}
dd
p.adjust(pp,method="BH") # Adjust p-values considering the number of distributions




######## Subset B: 1-female 1-harmonic stim, recording or pure sound ############## 
row<- row_fc_diff & stim_NumbHarmonics=='1' & stim_1VSswarm=='sgl'

# Response variable to be selected:
var_name="avel_QuantH_diff_1s"
	# stim_type	chisq(1)=0.052, p=0.82
	# recorded: BH-corr one-sample t(9)=5.17 p<0.001 mean=1.55" ***
	# synthetic: BH-corr one-sample t(38)=5.44 p<0.001 mean=1.63"***
var_name="wbf_QuantH_diff_1s"
	# stim_type	chisq(1)=4.54, p=0.033 *
	# recorded: BH-corr one-sample t(9)=5.17 p<0.001 mean=16.4" ***
	# synthetic: BH-corr one-sample t(38)=5.11 p<0.001 mean=29.8"***

# Model reduction
	mod<-blmer(eval(parse(text = var_name)) ~ stim_type + (1|ds), data=data[row,],REML='false')
	mod1<-update(mod,~.-stim_type); anova(mod,mod1) 
	# if significant, Model assumption check:
	qqPlot(resid(mod),distribution="norm", stim_NumbHarmonics[row])  # Checking model residual normality
	fligner.test(eval(parse(text = var_name))[row], stim_NumbHarmonics[row]) # Deviation homogeinety

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_type",color="stim_SPL",notch =TRUE,ylab= var_name,xlab="N harm",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))

# Commpare each distribution to 0
dd<- unique(stim_type[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_type ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
	print(paste("one-sample t(",round(tt$parameter,5),")=",round(tt$statistic,5)," p=",round(tt$p.value,5)," mean=",round(tt$estimate,3),sep=""))		
}
dd
p.adjust(pp,method="BH") # Adjust p-values considering the number of distributions



######## Subset C: 2-harmonic stim, recording, 1-female and 30-female ############## 
sex_i <- 'm'; row<- row_fc_diff & stim_type=='n' & stim_NumbHarmonics!='1' & stim_SPL > 11 # we removed the lowest-SPL single-stimulus because the correction was not possible for this low-level stimulus (see paper method)

# Response variable to be selected:
var_name="avel_QuantH_diff_1s"
	# Fixed Effects of avel_QuantH_diff_1s ~ stim_SPL * stim_1VSswarm + (1 |ds):
    #          (Intercept)	stim_SPL		stim_1VSswarmsgl		stim_SPL:stim_1VSswarmsgl  
    #          -1.55469		0.07323		-0.32502				0.04839 
	# spl:type 	chisq(1)=3.28, p=0.070
	# type		 	chisq(1)=12.6, p<0.001 ***. --> not reliable because depends on how SPLs were spread
	# spl			chisq(1)=36.8, p<0.001 ***
var_name="wbf_QuantH_diff_1s"
	# Fixed Effects of wbf_QuantH_diff_1s ~ stim_SPL * stim_1VSswarm + (1 |ds):
    #          (Intercept)		stim_SPL	stim_1VSswarmsgl		stim_SPL:stim_1VSswarmsgl  
    #            -0.021216		0.001187	-0.026982			0.001671  
	# spl:type 	chisq(1)=12.7, 	p<0.001 ***
	# type		chisq(1)=4.66,	p=0.031 *	--> not reliable because depends on how SPLs were spread
	# spl		chisq(1)=20.7, 	p<0.001 ***
	
#### Model reduction (with stim_SPL continuous)
	mod<-blmer(eval(parse(text = var_name)) ~ stim_SPL* stim_1VSswarm + (1|ds),data=data[row,],REML='false')
	mod1<-update(mod,~.-stim_SPL: stim_1VSswarm); anova(mod,mod1) 
	# if significant, Model assumption check:
	qqPlot(resid(mod),distribution="norm")  # Checking model residual normality
	fligner.test(eval(parse(text = var_name))[row], stim_SPLcatSpp[row]) # Deviation homogeinety

	# If interaction is significant:
	library(car)
	Anova(mod,type=3)
	
	# If interaction not significant, then model reduction
	mod2test<-update(mod1,~.-stim_SPL); 	anova(mod1,mod2test)
	mod2test<-update(mod1,~.-stim_1VSswarm); 	anova(mod1,mod2test)
	# if significant, Model assumption check:
	qqPlot(resid(mod1),distribution="norm")   # Checking model residual normality 
	fligner.test(eval(parse(text = var_name))[row], stim_SPLcatSpp[row]) # Deviation homogeinety	

#### Plots and BH-corrected one-sample t-test

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_SPL",notch =TRUE,color="stim_1VSswarm",ylab= var_name,xlab="stim_SPL",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))

# Commpare each distribution to 0
dd<- unique(stim_SPL1vsSwam[row])[is.na(unique(stim_SPL1vsSwam[row])) ==0]
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_SPL1vsSwam ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
	print(paste("one-sample t(",round(tt$parameter,5),")=",round(tt$statistic,5)," p=",round(tt$p.value,5)," mean=",round(tt$estimate,3),sep=""))		
}
dd
p.adjust(pp,method="BH") # Adjust p-values considering the number of distributions








######################## Archive ##################

############ Additional paramters not used in th emain analysis (can be removed for paper archive)
# Number of parameters considered to adjust p-value
Nparam=10
############



# Interaction variable for multicomparison
data$stim_SPLsex <- interaction(  list(as.factor(data$stim_SPL), data$stim_sex))
data$stim_SPLsexSpp <- interaction(  list(as.factor(data$stim_SPL), data$stim_sex,data$stim_species))
data$stim_SPLspp <- interaction(  list(as.factor(data$stim_SPL),data$stim_species))
data$stim_SPLcatSpp <- interaction(  list(as.factor(data$stim_SPL_cat),data$stim_species))
data$stim_SPL1vsSwam <- interaction(  list(as.factor(data$stim_SPL),data$stim_1VSswarm))
data$stim_SPL_fact<-as.factor(data$stim_SPL)
ordered(data$stim_SPL_fact)
#data$stim_SPL_fact_grp <- fct_other(data$stim_SPL_fact, drop = c("20.4","25.8","36.2"),other_level="20.4-25.8-36.2")
#data$stim_SPL_fact_grp <- factor(data$stim_SPL_fact_grp,ordered=FALSE)
data$stim_SPLprediff <- interaction(  list(as.factor(data$stim_SPL), as.factor(data$pressure_diff)))

# We use "ds" as a random component because there is some effect of dayly pressure diff (through interaction of SPL and pressure difference)

attach(data)

######## Statistical analysis: With coluzzii single/grp female stim, 1 or 2 harmonics, SPL_cat (continuous) ############## 


row<- locationStim==1 & stim_type=='n' & stim_species=='c' &  stim_sex=='f' & (stim_soundLevel =='3' | stim_soundLevel =='3b')
# Be careful, SPL(2 harmnonics) is far greater than SPL(1 harmonic) because of the strong noise between harmonic harminic 1 and 2 (cf spectrum and SPL measurments per octave thirds). But the peak of harmonics 1 is the same amplitude. 

# Selected
var_name="wbf_QuantH_diff_1s"
	# stim_NumbHarmonics	chisq(4)=1.10, p=0.29
	# 1 harm: BH-corr one-sample t(9)=5.17 p<0.001 mean=16.356" ***
	# 2 harm: BH-corr one-sample t(9)=4.60 p=0.0013 mean=13.1"**
var_name="avel_QuantH_diff_1s"
	# stim_NumbHarmonics*stim_soundLevel	 chisq(1)=3.9, p=0.047*
	# Anova(mod,type=3) Analysis of Deviance Table (Type III Wald chisquare tests)
	# Response: eval(parse(text = var_name))
	                                   # Chisq Df Pr(>Chisq)   
	# (Intercept)                       4.5828  1   0.032295 * 
	# stim_NumbHarmonics                1.7306  1   0.188339   
	# stim_1VSswarm                    10.2887  1   0.001338 **
	# stim_NumbHarmonics:stim_1VSswarm  4.3860  1   0.036235 * 

# Model reduction
	mod<-blmer(eval(parse(text = var_name)) ~ stim_NumbHarmonics* stim_1VSswarm + (1|ds), data=data[row,],REML='false')
	mod1<-update(mod,~.-stim_NumbHarmonics: stim_1VSswarm); anova(mod,mod1) 
	
	mod2test<-update(mod1,~.-stim_NumbHarmonics); 	anova(mod1,mod2test)
	mod2test<-update(mod1,~.-stim_1VSswarm); 	anova(mod1,mod2test)
	# if significant, Model assumption check:
	qqPlot(resid(mod1),distribution="norm", stim_SPLcatSpp[row])   # Checking model residual normality 
	fligner.test(eval(parse(text = var_name))[row], stim_SPLcatSpp[row]) # Deviation homogeinety
	
	mod2<-	  update(mod1,~.-stim_NumbHarmonics); 	anova(mod1,mod2)
	mod3<-	  update(mod2,~.-stim_1VSswarm);		anova(mod2,mod3)
	# if significant, Model assumption check:
	qqPlot(resid(mod2),distribution="norm", stim_SPL[row])   
	fligner.test(eval(parse(text = var_name))[row], stim_SPL[row]) # Deviation homogeinety
	
	library(car)
	Anova(mod,type=3)

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_NumbHarmonics",color="stim_1VSswarm",notch =TRUE,ylab= var_name,xlab="N harm",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fc_perNharm",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))


# Commpare each distribution to 0
dd<- unique(stim_NumbHarmonics[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_NumbHarmonics ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
	print(paste("one-sample t(",round(tt$parameter,5),")=",round(tt$statistic,5)," p=",round(tt$p.value,5)," mean=",round(tt$estimate,3),sep=""))		
}
dd
p.adjust(pp,method="BH") # Adjust p-values considering the number of distributions




##################### Males (ie synthetic female stimuli 1harm sgl/swarm)   

sex_i <- 'm'; row<- locationStim==1 & stim_type=='s' & stim_NumbHarmonics!='2'  & stim_sex=='f' & stim_species=='c' & stim_SPL > 11
# & stim_1VSswarm=='grp'

var_name="avel_QuantH_diff_1s"
	# type 	chisq(1)=4.44, p=0.035*

var_name="wbf_QuantH_diff_1s"
	# type		chisq(1)=7.26,	p=0.0071**
	
#### Model reduction (with stim_SPL continuous)
	mod<-blmer(eval(parse(text = var_name)) ~ stim_1VSswarm + (1|ds), data=data[row,],REML='false')
	mod1<-update(mod,~.- stim_1VSswarm); anova(mod,mod1) 
	# if significant, Model assumption check:
	qqPlot(resid(mod),distribution="norm")  # Checking model residual normality
	fligner.test(eval(parse(text = var_name))[row], stim_1VSswarm[row]) # Deviation homogeinety

#### Plots and BH-corrected one-sample t-test

## explanatory variables: SPL and type
# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_1VSswarm",notch =TRUE,ylab= var_name,xlab="stim_1VSswarm",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, var_name,"_perSPLtype_",sex_i,"_",format(Sys.time(), "%y%m%d" ),".png",sep="" ))
# Commpare each distribution to 0
dd<- unique(stim_1VSswarm[row])[is.na(unique(stim_1VSswarm[row])) ==0]
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_1VSswarm ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
	print(paste("one-sample t(",round(tt$parameter,5),")=",round(tt$statistic,5)," p=",round(tt$p.value,5)," mean=",round(tt$estimate,3),sep=""))		
}
dd
p.adjust(pp,method="BH") # Adjust p-values considering the number of distributions
p.adjust(p.adjust(pp,method="BH"),method="BH", Nparam) # Adjust p-values considering Nparam parameters











#################### FEMALES #############################


######## Statistical analysis: With coluzzii male stimulis only, continuous SPL  ############## 

row<- locationStim==1 & stim_type=='n' & stim_NumbHarmonics!='1' & stim_1VSswarm=='grp' & stim_species=='c' & stim_sex=='m'

# Seleceted parameters
var_name="Z_Max_diff_7s"	# NS
var_name="Z_Min_diff_7s"	# NS
var_name="Y_Max_diff_7s"	# NS
var_name="Y_Min_diff_7s"	# NS
var_name="vel_Max_diff_1s"	# NS
var_name="avel_Max_diff_1s"	# NS
var_name="wbf_Amax_diff_7s"	# NS

# Parameter which have a tendency by eye:
var_name="Y_Max_diff_1s"	# NS
var_name="Y_Max_diff_7s"	# NS
var_name="Y_Min_diff_7s"	# NS
var_name="Y_Quant_diff_7s"	# NS
var_name="Y_Min_diff_1s"	# NS (p=0.08)

var_name="Z_Max_diff_7s"	# NS
var_name="Z_Min_diff_7s"	# NS
var_name="Z_Med_diff_7s"	# NS
var_name="Z_Min_diff_1s"	# NS
var_name="X_Sd_diff_1s"		# NS

var_name="vel_Quant_diff_7s"# NS 
var_name="vel_Max_diff_1s"	# NS
var_name="vel_Sd_diff_7s"	# NS (p=0.07)
var_name="vel_Sd_diff_1s"	# NS ((p=0.08)
var_name="avel_Max_diff_1s"	# NS
var_name="avel_Quant_diff_7s"#NS
var_name="avel_Sd_diff_1s"	# NS 

var_name="wbf_Sd_diff_7s"	# NS
var_name="wbf_Sd_diff_1s"	# Anova p=0.013*, but all distrib not sign diff (p=0.08 for SPL4)
var_name="wbf_Quant_diff_7s"# Anova p=0.034*, SPL3 p=0.0498*, SPL4 p=0.24
var_name="wbf_Amax_diff_1s"	# NS
var_name="wbf_Amax_diff_7s"	# NS
var_name="wbf_Amin_diff_1s"	# Anova 0.035*, but none distrib signif diff from 0 
var_name="wbf_Med_diff_7s"	# NS
var_name="wbf_Tamin_diff_7s"# ANova p=0.023*, but none distrib signif diff from 0  

# Create folder
subDir1="fig/"
subDir2=paste("m-c-n-2-2a-X_",var_name,"/",sep="")
mainDir=getwd() 
dir.create(file.path(mainDir, subDir1))
dir.create(file.path(mainDir, subDir1,subDir2))

# Model redution
mod<-blmer(eval(parse(text = var_name)) ~ stim_SPL + (1|ds), data=data[row,],REML='false')
mod1<-update(mod,~.-stim_SPL, data=data[row,]); anova(mod,mod1) 


# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_SPL",color="sex",notch =TRUE,ylab= var_name,xlab="stim_SPL",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fc_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))


# Commpare each distribution to 0
dd<- unique(stim_SPL[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_SPL==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
p.adjust(pp,method="BH") # Adjust p-values



######## Statistical analysis: With col/gamb male stimuli, SPL (continuous) ############## 

row<- locationStim==1 & stim_type=='n' & stim_NumbHarmonics!='1' & stim_1VSswarm=='grp'  & stim_sex=='m'

# Selected parameters
var_name="avel_Max_diff_1s"	# stim_SPL:stim_species p =0.65, spp p=0.062, spl p=0.038*)
							# see SPL_cat one-sample t-test since spp is not significant and since SPLs similar for both species
var_name<-"wbf_Amax_diff_7s"# NS

var_name<-"Y_Max_diff_7s"	# 
var_name<-"Y_Min_diff_7s"	# 
var_name<-"Z_Max_diff_7s"	# 
var_name<-"Z_Min_diff_7s"	# 
var_name="vel_Max_diff_1s"	# 



# Create folder
subDir1="fig/"
subDir2=paste("m-c-n-2-2a-X_",var_name,"/",sep="")
mainDir=getwd() 
dir.create(file.path(mainDir, subDir1))
dir.create(file.path(mainDir, subDir1,subDir2))

# Model reduction
	mod<-blmer(eval(parse(text = var_name)) ~ stim_SPL*stim_species + (1|ds), data=data[row,],REML='false')
	mod1<-update(mod,~.-stim_SPL:stim_species); anova(mod,mod1) 
	# if significant, Model assumption check:
	qqPlot(resid(mod),distribution="norm", stim_SPLcatSpp[row])  # Checking model residual normality
	fligner.test(eval(parse(text = var_name))[row], stim_SPLcatSpp[row]) # Deviation homogeinety
	
	library(car)
	Anova(mod,type=3)
	
	mod2test<-update(mod1,~.-stim_species); 	anova(mod1,mod2test)
	mod2test<-update(mod1,~.-stim_SPL); 	anova(mod1,mod2test)
	# if significant, Model assumption check:
	qqPlot(resid(mod1),distribution="norm", stim_SPLcatSpp[row])   # Checking model residual normality 
	fligner.test(eval(parse(text = var_name))[row], stim_SPLcatSpp[row]) # Deviation homogeinety
	
	mod2<-	  update(mod1,~.-stim_species); 	anova(mod1,mod2)
	mod3<-	  update(mod2,~.-stim_SPL);		anova(mod2,mod3)
	# if significant, Model assumption check:
	qqPlot(resid(mod2),distribution="norm", stim_SPL_cat[row])   
	fligner.test(eval(parse(text = var_name))[row], stim_SPL_cat[row]) # Deviation homogeinety
	
	mod2<-	  update(mod1,~.-stim_SPL); 	anova(mod1,mod2)
	mod3<-	  update(mod2,~.-stim_species); 	anova(mod2,mod3)
	# Model assumption check:
	qqPlot(resid(mod2),distribution="norm", stim_species[row])  
	fligner.test(eval(parse(text = var_name))[row], stim_species[row]) # Deviation homogeinety 

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_SPL_cat",notch =TRUE,ylab= var_name,xlab="stim_SPL_cat",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fX_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))

# Commpare each distribution to 0
dd<- unique(stim_SPL[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_SPL==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
p.adjust(pp,method="BH") # Adjust p-values

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_SPL_cat",color="stim_species",notch =TRUE,ylab= var_name,xlab="stim_SPLspp",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fX_perSPLcat",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))


# Commpare each distribution to 0
dd<- unique(stim_SPLcatSpp[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_SPLcatSpp ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
p.adjust(pp,method="BH") # Adjust p-values



	
#################### MALES #############################


######## Statistical analysis: With coluzzii female swarm stimulis only, continuous SPL  ############## 

row<- locationStim==1 & stim_type=='n' & stim_NumbHarmonics!='1' & stim_1VSswarm=='grp' & stim_species=='c' & stim_sex=='f'

# Selected
var_name="Y_Max_diff_7s"	# NS
var_name="Y_Min_diff_7s"	# NS (anova spl p=0.08), SPL4 p=0.018*
var_name="Z_Max_diff_7s"	# NS
var_name="Z_Min_diff_7s"	# NS
var_name="vel_Max_diff_1s"	# NS
var_name="avel_Max_diff_1s"	# Anova SPL p=e-4***, but none distrib sign from 0
var_name="wbf_Amax_diff_7s"	# Anova simpl mod SPL p=0.035*, but but none distrib sign from 0

# Parameter which have a tendency by eye:
var_name="Y_Max_diff_1s"	# NS
var_name="Y_Max_diff_7s"	# NS
var_name="Y_Min_diff_7s"	# NS (anova spl p=0.08)
var_name="Y_Quant_diff_7s"	# NS
var_name="Y_Min_diff_1s"	# NS
var_name="Z_Max_diff_7s"	# NS
var_name="Z_Min_diff_7s"	# NS
var_name="Z_Med_diff_7s"	# NS
var_name="Z_Min_diff_1s"	# NS
var_name="X_Sd_diff_1s"		# NS

var_name="vel_Quant_diff_7s"# NS
var_name="vel_Max_diff_1s"	# NS
var_name="vel_Max_diff_1s"	# NS
var_name="vel_Sd_diff_7s"	# NS
var_name="vel_Sd_diff_1s"	# NS
var_name="avel_Max_diff_1s"	# Anova SPL p=e-4***, but none distrib sign from 0
var_name="avel_Max_diff_7s"	# NS (Anova SPL p=0.08) and none distrib sign from 0
var_name="avel_Quant_diff_7s"# Anova simpl mod SPL p=0.036*,  but but none distrib sign from 0
var_name="avel_Sd_diff_1s"	# Anova simpl mod SPL p=e-5***
							# but none distrib sig diff from 0 (SPL4 distrib p=0.06)
var_name="wbf_Sd_diff_7s"	# NS
var_name="wbf_Sd_diff_1s"	# ANova simpl mod SPL p=0.0026**
							# SPL4 sign diff from 0 (p=0.022*)
var_name="wbf_Quant_diff_7s"# NS
var_name="wbf_Amax_diff_1s"	# Anova simpl mod SPL p=0.0006***, SPL4 sign diff from 0 (p=0.018*)
var_name="wbf_Amax_diff_7s"	# Anova simpl mod SPL p=0.04*, but but none distrib sign from 0
var_name="wbf_Amin_diff_1s"	# Anova simpl mod SPL p=0.015*, but but none distrib sign from 0
var_name="wbf_Med_diff_7s"	# NS
var_name="wbf_Tamin_diff_7s"# NS
var_name="wbf_Tamax_diff_7s"# NS

# Create folder
subDir1="fig/"
subDir2=paste("f-c-n-2-2a-X_",var_name,"/",sep="")
mainDir=getwd() 
dir.create(file.path(mainDir, subDir1))
dir.create(file.path(mainDir, subDir1,subDir2))

# Model redution with stim_SPL
mod<-blmer(eval(parse(text = var_name)) ~ stim_SPL + (1|ds), data=data[row,],REML='false')
mod1<-update(mod,~.-stim_SPL, data=data[row,]); anova(mod,mod1) 

# Model redution with stim_SPL_fact
mod<-blmer(eval(parse(text = var_name)) ~ stim_SPL_fact + (1|ds), data=data[row,],REML='false')
mod1<-update(mod,~.-stim_SPL_fact, data=data[row,]); anova(mod,mod1) 

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_SPL",color="sex",notch =TRUE,ylab= var_name,xlab="stim_SPL",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fc_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))


# Commpare each distribution to 0
dd<- unique(stim_SPL[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_SPL==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
p.adjust(pp,method="BH") # Adjust p-values

# Commpare each distribution to 0
dd<- unique(stim_SPL_fact[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_SPL_fact==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
p.adjust(pp,method="BH") # Adjust p-values





######## Statistical analysis: With col/gamb female stim only, SPL (continuous, slightly different for coluzzii and gambiae) ############## 
# But females stim not so good


row<- locationStim==1 & stim_type=='n' & stim_NumbHarmonics!='1' & stim_1VSswarm=='grp' & stim_sex=='f'

# Selected
var_name="avel_Max_diff_1s"	# spl:spp p=0.0004***, spl p=e-5***, spp p=e-5***, 
							# but none distrib sign diff
							# qqplots for each looks normal
							# fligner.test on SPL:spp X²= 5.9, df = 7, p-value = 0.55
var_name="wbf_Amax_diff_7s"	# Anova SPL p=e-5***, chisq=18.87, df=1
							# SPL4-gamb p=0.0006***, SPL4-coluzii p=0.08
							# but as no spp effect, better to use SPL_cat for t-test to group close SPL
							# qqplots looks good 
							# fligner.test on SPL X²= 4.7, df = 7, p-value = 0.7


# Create folder
subDir1="fig/"
subDir2=paste("f-X-n-2-2a-X_",var_name,"/",sep="")
mainDir=getwd() 
dir.create(file.path(mainDir, subDir1))
dir.create(file.path(mainDir, subDir1,subDir2))

# Model reduction
	mod<-blmer(eval(parse(text = var_name)) ~ stim_SPL*stim_species + (1|ds), data=data[row,],REML='false')
	mod1<-update(mod,~.-stim_SPL:stim_species); anova(mod,mod1) 
	# if significant, Model assumption check:
	qqPlot(resid(mod),distribution="norm", stim_SPLcatSpp[row])  # Checking model residual normality
	fligner.test(eval(parse(text = var_name))[row], stim_SPLcatSpp[row]) # Deviation homogeinety
	
	library(car)
	Anova(mod,type=3)
	
	mod2test<-update(mod1,~.-stim_species); 	anova(mod1,mod2test)
	mod2test<-update(mod1,~.-stim_SPL); 	anova(mod1,mod2test)
	# if significant, Model assumption check:
	qqPlot(resid(mod1),distribution="norm", stim_SPLcatSpp[row])   # Checking model residual normality 
	fligner.test(eval(parse(text = var_name))[row], stim_SPLcatSpp[row]) # Deviation homogeinety
	
	mod2<-	  update(mod1,~.-stim_species); 	anova(mod1,mod2)
	mod3<-	  update(mod2,~.-stim_SPL);		anova(mod2,mod3)
	# if significant, Model assumption check:
	qqPlot(resid(mod2),distribution="norm", stim_SPL_cat[row])   
	fligner.test(eval(parse(text = var_name))[row], stim_SPL_cat[row]) # Deviation homogeinety
	
	mod2<-	  update(mod1,~.-stim_SPL_cat); 	anova(mod1,mod2)
	mod3<-	  update(mod2,~.-stim_species); 	anova(mod2,mod3)
	# Model assumption check:
	qqPlot(resid(mod2),distribution="norm", stim_species[row])  
	fligner.test(eval(parse(text = var_name))[row], stim_species[row]) # Deviation homogeinety 

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_SPL",notch =TRUE,ylab= var_name,xlab="stim_SPL",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fX_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_SPL",color="stim_species",notch =TRUE,ylab= var_name,xlab="stim_SPL",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fX_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))


# Commpare each distribution to 0
dd<- unique(stim_SPL[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_SPL==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
p.adjust(pp,method="BH") # Adjust p-values

# Commpare each distribution to 0
dd<- unique(stim_SPLspp[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_SPLspp ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
p.adjust(pp,method="BH") # Adjust p-values





######## Statistical analysis: With col/gamb female stim only, SPL_cat (continuous, commun to both coluzzii and gambiae) ############## 
# But females stim not so good


row<- locationStim==1 & stim_type=='n' & stim_NumbHarmonics!='1' & stim_1VSswarm=='grp' & stim_sex=='f'

# Selected
var_name="Y_Min_diff_7s"	# NS
var_name="Y_Max_diff_7s"	# NS
var_name="Z_Max_diff_7s"	# NS
var_name="Z_Min_diff_7s"	# spl p=0.021*, none distrib sign diff
var_name="vel_Max_diff_1s"	# NS
var_name="avel_Max_diff_1s"	# spl:spp p=0.0010**, spl p=0.0003***, spp p=0.03*, but none distrib sign diff
							# qqplots for each looks normal
							# fligner.test on SPL:spp X²= 5.9, df = 7, p-value = 0.55
var_name="wbf_Amax_diff_7s"	# Anova simpl mod SPL p=0.00018***, SPL4 p=0.00017***
							# qqplots looks good 
							# fligner.test on SPL X²= 5.2, df = 3, p-value = 0.15

## All:

# Parameter which have a tendency by eye:
var_name="Y_Max_diff_1s"	# NS (spl p=0.06)
var_name="Y_Max_diff_7s"	# NS
var_name="Y_Quant_diff_7s"	# NS (spl:spp p=0.08)
var_name="Y_Min_diff_1s"	# NS (spl p=0.07)
var_name="Z_Max_diff_7s"	# NS
var_name="Z_Min_diff_7s"	# spl p=0.021*, none distrib sign diff
var_name="Z_Med_diff_7s"	# NS
var_name="Z_Min_diff_1s"	# NS
var_name="X_Sd_diff_1s"		# NS

var_name="vel_Quant_diff_7s"# NS
var_name="vel_Max_diff_1s"	# NS
var_name="vel_Max_diff_7s"	# NS
var_name="vel_Sd_diff_7s"	# NS
var_name="vel_Sd_diff_1s"	# NS
var_name="avel_Max_diff_1s"	# spl:spp p=0.0010**, spl p=0.0003, spp p=0.03*, but none distrib sign diff
var_name="avel_Max_diff_7s"	# spl p=0.00051***, SPL3 p=0.0074**, but SPL4 not sign diff
var_name="avel_Quant_diff_7s"# SPL p=0.0066**,  SPL3 p=0.020*, SPL4 p=0.0013**
var_name="avel_Sd_diff_1s"	# spl:spp p=0.0014**, spl p=0.00057***, but none distrib sign diff
var_name="wbf_Sd_diff_7s"	# spl p=0.012*, SPL3 p=0.011*, SPL4 p=0.0012**
var_name="wbf_Sd_diff_1s"	# SPL p=e-5***
							# SPL4 sign diff from 0 (p=0.0003***)
var_name="wbf_Quant_diff_7s"# spl:spp p=0.0018**, spl p=0.0015**, SPL3gamb p=0.0011**, SPL4gamb p=0.022*
var_name="wbf_Amax_diff_1s"	# Anova simpl mod SPL p=e-8***, SPL4 sign diff from 0 (p=e-5***)
var_name="wbf_Amax_diff_7s"	# Anova simpl mod SPL p=0.00018***, SPL4 p=0.00017***
var_name="wbf_Amin_diff_1s"	# Anova simpl mod SPL p=e-5***, p=0.0011**
var_name="wbf_Med_diff_7s"	# spl:spp p=0.029*, spl p=0.011*, SPL3gamb p=0.0011**, SPL4gamb p=0.022*
var_name="wbf_Tamin_diff_7s"# NS
var_name="wbf_Tamax_diff_7s"# NS

# Create folder
subDir1="fig/"
subDir2=paste("f-X-n-2-2a-X_",var_name,"/",sep="")
mainDir=getwd() 
dir.create(file.path(mainDir, subDir1))
dir.create(file.path(mainDir, subDir1,subDir2))

# Model reduction
	mod<-blmer(eval(parse(text = var_name)) ~ stim_SPL_cat*stim_species + (1|ds), data=data[row,],REML='false')
	mod1<-update(mod,~.-stim_SPL_cat:stim_species); anova(mod,mod1) 
	# if significant, Model assumption check:
	qqPlot(resid(mod),distribution="norm", stim_SPLcatSpp[row])  # Checking model residual normality
	fligner.test(eval(parse(text = var_name))[row], stim_SPLcatSpp[row]) # Deviation homogeinety
	
	library(car)
	Anova(mod,type=3)
	
	mod2test<-update(mod1,~.-stim_species); 	anova(mod1,mod2test)
	mod2test<-update(mod1,~.-stim_SPL_cat); 	anova(mod1,mod2test)
	# if significant, Model assumption check:
	qqPlot(resid(mod1),distribution="norm", stim_SPLcatSpp[row])   # Checking model residual normality 
	fligner.test(eval(parse(text = var_name))[row], stim_SPLcatSpp[row]) # Deviation homogeinety
	
	mod2<-	  update(mod1,~.-stim_species); 	anova(mod1,mod2)
	mod3<-	  update(mod2,~.-stim_SPL_cat);		anova(mod2,mod3)
	# if significant, Model assumption check:
	qqPlot(resid(mod2),distribution="norm", stim_SPL_cat[row])   
	fligner.test(eval(parse(text = var_name))[row], stim_SPL_cat[row]) # Deviation homogeinety
	
	mod2<-	  update(mod1,~.-stim_SPL_cat); 	anova(mod1,mod2)
	mod3<-	  update(mod2,~.-stim_species); 	anova(mod2,mod3)
	# Model assumption check:
	qqPlot(resid(mod2),distribution="norm", stim_species[row])  
	fligner.test(eval(parse(text = var_name))[row], stim_species[row]) # Deviation homogeinety 

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_SPL_cat",notch =TRUE,ylab= var_name,xlab="stim_SPL",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fX_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_SPL_cat",color="stim_species",notch =TRUE,ylab= var_name,xlab="stim_SPL",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fX_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))


# Commpare each distribution to 0
dd<- unique(stim_SPL_cat[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_SPL_cat==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
p.adjust(pp,method="BH") # Adjust p-values

# Commpare each distribution to 0
dd<- unique(stim_SPLcatSpp[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_SPLcatSpp ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
p.adjust(pp,method="BH") # Adjust p-values













######## Statistical analysis: With coluzzii single female stim, SPL3, testing 1 versus 2 hmonics ############## 

row<- locationStim==1 & stim_type=='n' & stim_1VSswarm=='sgl'  & stim_sex=='f'  & stim_species=='c' & (stim_soundLevel =='3' | stim_soundLevel =='3b')
# Be careful, SPL(2 harmnonics) is far greater than SPL(1 harmonic) because of the strong noise between harmonic harminic 1 and 2 (cf spectrum and SPL measurments per octave thirds). But the peak of harmonics 1 is the same amplitude. 

# Selected parameters
var_name="Y_Max_diff_7s"	# NS (p=0.6, chisq=0.34)
var_name="Y_Min_diff_7s"	# NS (p =0.9, chisq=0.003)
var_name="Z_Min_diff_7s"	# NS (p=0.6, chisq=0.21)
var_name="vel_Max_diff_1s"	# NS (p=0.4, chisq=0.6)
var_name="avel_Max_diff_1s"	# NS (p=0.3, chisq=0.9)
var_name="wbf_Amax_diff_7s"	# Anova stim_NumbHarmonics (p=0.0026**), 
							# 1-harmonic distrib sign diff from 0 (p=0.0001***)
							# 2-harmoncic distrib sign diff from 0 (p=0.002**)

# ==> fem swarm stimuli: no diff between 1 and 2 harmonics, but there is a tendency for 1-harmonics eliciting a greaer response 

# Create folder
subDir1="fig/"
subDir2=paste("f-c-n-1-X-3_",var_name,"/",sep="")
mainDir=getwd() 
dir.create(file.path(mainDir, subDir1))
dir.create(file.path(mainDir, subDir1,subDir2))

# Model redution with stim_SPL
mod<-blmer(eval(parse(text = var_name)) ~ stim_NumbHarmonics + (1|ds), data=data[row,],REML='false')
mod1<-update(mod,~.-stim_NumbHarmonics, data=data[row,]); anova(mod,mod1) 

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_NumbHarmonics",notch =TRUE,ylab= var_name,xlab="stim_NumbHarmonics",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fc_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))

# Commpare each distribution to 0
dd<- unique(stim_NumbHarmonics[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_NumbHarmonics ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
p.adjust(pp,method="BH") # Adjust p-values


## Paper plot with selected parameters

	# Dependent of the analysis, to be reviewed:
	x_name<-"stim_NumbHarmonics" # Singificant varianle or at least tested variable
	xlabel_v<-"Numb harm"
	var_name_inter <- 0 # VAriable name for which we need an interaction plot (because the interaction or the second factor was found significant)
						# 0 if no other significant variable
		x2_name<-"stim_SPL_cat" # other significant variable
		x2label_v<-"SPL (dB)"	
	save_name<-"fcn1X3_Nharm-effect"
	
	# No need to change:
	var_nam <- c("Y_Min_diff_7s","Y_Max_diff_7s","Z_Min_diff_7s","Z_Max_diff_7s","vel_Max_diff_1s","avel_Max_diff_1s","wbf_Amax_diff_7s")
	ylab_v <- c("Diff of min height (m)","Diff of max height (m)", "Diff of min dist to speaker (m)","Diff of max dist to speaker (m)","Diff of max lin-vel (m/s)","Diff of max ang-vel (rad/s)","Diff of max WBF (Hz)")
	outliersShape=23
	meanSize=0.3
	for (kk in seq(1,length(var_nam))){
		if (kk %in% seq(1,4)){
			ylim_v<- c(-0.4,0.4)
			}
		else{
			ylim_v<- c(min(data[,var_nam[kk]]),max(data[,var_nam[kk]]))
			}		
		
		if (all(var_nam[kk] %in% var_name_inter)) {
				eval(parse(text = paste("dp",kk,"<- ggboxplot(data[row,],y=var_nam[kk],x=x_name,color= x2_name,ylab= ylab_v[kk],xlab= xlabel_v,ylim=ylim_v,add=c(\"mean\",\"mean_se\"),add.params=list(size= meanSize), showWarnings = 0,las=2,outlier.shape= outliersShape)	+
				theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5)) +
				theme(legend.title = element_text(size = 7),
				        legend.text = element_text(size = 7),
				        legend.key.size =unit(.01, \"cm\"),
				        legend.box = \"vertical\" )+
			scale_fill_discrete(name = x2label_v) "
				        ,sep="")))	
				}	
		else{
			eval(parse(text = paste("dp",kk,"<- ggboxplot(data[row,],y=var_nam[kk],x=x_name,ylab= ylab_v[kk],xlab=xlabel_v,ylim=ylim_v,add=c(\"mean\",\"mean_se\"),add.params=list(size= meanSize), showWarnings = 0,las=2,outlier.shape= outliersShape)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))",sep="")))
			}					
	}
	ggarrange(dp1,dp2,dp3,dp4,dp5,dp6,dp7,
	          labels = c("A", "B", "C","D","E","F","G"),
	          ncol = 4, nrow = 2)
	ggsave(paste( subDir1,save_name,'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))









######## Statistical analysis: With coluzzii female stim, testing single versus swarm and SPL ############## 

row<- locationStim==1 & stim_type=='n' &  stim_sex=='f' & stim_NumbHarmonics!='1' & stim_species=='c'


# Selected parameters
var_name="avel_Max_diff_1s"	# Anova stim_1VSswarm p=0.020*, stim_SPL p=e-9***
							# only 1-harmon SPL4 is sign diff from 0  (p=0.011)
var_name="wbf_Amax_diff_7s"	# Anova stim_1VSswarm p=0.0070**, stim_SPL p=e-7
							# 1-harm SPL3 sign diff from 0 (p=0.008**)
							# 1-harm SPL4 sign diff from 0 (p=0.0004***)
			# mod2test: eval(parse(text = var_name)) ~ stim_SPL + (1 | ds)
			# mod1: eval(parse(text = var_name)) ~ stim_SPL + stim_1VSswarm + (1 | 
			# mod1:     ds)
			         # Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)   
			# mod2test  4 727.20 736.57 -359.60   719.20                            
			# mod1      5 721.92 733.64 -355.96   711.92 7.2804      1   0.006971 **							

# Parameter which have a tendency by eye:
var_name="Y_Max_diff_7s"	# anova stim_1VSswarm NS p=0.5
var_name="Y_Min_diff_7s"	# anova stim_1VSswarm  NS(p=0.05)
var_name="Y_Quant_diff_7s"	# 
var_name="Y_Min_diff_1s"	# 
var_name="Z_Max_diff_7s"	# no effect of stim_1VSswarm (p=0.5, chisq=0.54)
var_name="Z_Min_diff_7s"	# anova spl p=0.037*, no effect of stim_1VSswarm (p=0.1, chisq=2.4)
var_name="Z_Med_diff_7s"	# 
var_name="Z_Min_diff_1s"	# no effect of stim_1VSswarm
var_name="X_Sd_diff_1s"		# 

var_name="vel_Quant_diff_7s"# 
var_name="vel_Max_diff_1s"	# Anova stim_1VSswarm:stim_SPL p=0.0027**
	# Analysis of Deviance Table (Type III Wald chisquare tests)
	# Response: eval(parse(text = var_name))
	                         # Chisq Df Pr(>Chisq)    
	# (Intercept)             6.4772  1   0.010927 *  
	# stim_SPL               22.4721  1  2.132e-06 ***
	# stim_1VSswarm           4.6298  1   0.031421 *  
	# stim_SPL:stim_1VSswarm  9.7338  1   0.001809 ** 
							# only 1-harmon SPL4 distrib is sign diff from 0 (p=0.002**, adj. p-value from t-test)
var_name="vel_Sd_diff_7s"	# Anova stim_1VSswarm:stim_SPL p=0.022*
var_name="vel_Sd_diff_1s"	# Anova stim_1VSswarm:stim_SPL p=0.026*
var_name="avel_Max_diff_1s"	# Anova stim_1VSswarm p=0.020*, stim_SPL p=e-9***
							# only 1-harmon SPL4 is sign diff from 0  (p=0.011)
var_name="avel_Quant_diff_7s"# 
var_name="avel_Sd_diff_1s"	# 
var_name="wbf_Sd_diff_7s"	# anov stim_1VSswarm p=0.032*, stim_SPL p=e-5***	
							# only 1-harmon SPL4 is sign diff from 0  (p=0.011)
var_name="wbf_Sd_diff_1s"	# no signi stim_1VSswarm effect
var_name="wbf_Quant_diff_7s"# NS (p=0.08)
var_name="wbf_Amax_diff_1s"	# 
var_name="wbf_Amax_diff_7s"	# Anova stim_1VSswarm p=0.0070**, stim_SPL p=e-7
							# 1-harm SPL3 sign diff from 0 (p=0.008**)
							# 1-harm SPL4 sign diff from 0 (p=0.0004***)
var_name="wbf_Amin_diff_1s"	# 
var_name="wbf_Med_diff_7s"	# 
var_name="wbf_Tamin_diff_7s"# 
var_name="wbf_Tamax_diff_7s"# Anova stim_1VSswarm p=0.012*, stim_SPL p=0.0042**

# ==> signif effect of stim_1VSswarm

# Create folder
subDir1="fig/"
subDir2=paste("f-c-n-X-2-3_",var_name,"/",sep="")
mainDir=getwd() 
dir.create(file.path(mainDir, subDir1))
dir.create(file.path(mainDir, subDir1,subDir2))

# Model redution with stim_SPL
mod<-blmer(eval(parse(text = var_name)) ~ stim_SPL*stim_1VSswarm + (1|ds), data=data[row,],REML='false')
mod1<-update(mod,~.-stim_SPL:stim_1VSswarm, data=data[row,]); anova(mod,mod1) 

library(car)
Anova(mod,type=3)

mod2test<-update(mod1,~.-stim_1VSswarm); 	anova(mod1,mod2test)
mod2test<-update(mod1,~.-stim_SPL); 	anova(mod1,mod2test)

mod2<-	  update(mod1,~.-stim_1VSswarm); anova(mod1,mod2)
mod3<-	  update(mod2,~.-stim_SPL);		anova(mod2,mod3)

mod2<-	  update(mod1,~.-stim_SPL); 	anova(mod1,mod2)
mod3<-	  update(mod2,~.-stim_1VSswarm); anova(mod2,mod3)



# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_SPL",color="stim_1VSswarm",notch =TRUE,ylab= var_name,xlab="stim_SPL",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fc_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))


# Commpare each distribution to 0
data$sti_SPLcat_1VSswarm <- interaction(stim_SPL_cat, stim_1VSswarm)
attach(data)
dd<- unique(sti_SPLcat_1VSswarm[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (sti_SPLcat_1VSswarm ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
dd
p.adjust(pp,method="BH") # Adjust p-values

# Commpare each distribution to 0
dd<- unique(stim_SPL[row])
pp<-0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_SPL==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
	print(paste("one-sample t(",round(tt$parameter,5),")=",round(tt$statistic,5)," p=",round(tt$p.value,5)," mean=",round(tt$estimate,2),sep=""))
}
p.adjust(pp,method="BH") # Adjust p-values

# Commpare each distribution to 0
dd<- unique(stim_1VSswarm[row])
pp<-0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_1VSswarm ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
	print(paste("one-sample t(",round(tt$parameter,5),")=",round(tt$statistic,5)," p=",round(tt$p.value,5)," mean=",round(tt$estimate,2),sep=""))
}
p.adjust(pp,method="BH") # Adjust p-values
	# [1] "one-sample t(38)=4.82511 p=2e-05 mean=21.12"   ---> 1 female
	# [1] "one-sample t(37)=1.52229 p=0.13644 mean=7.62". ---> group of females
	# > p.adjust(pp,method="BH") # Adjust p-values
	# [1] 0.0000457841 0.1364370898

## Paper plot with selected parameters

	# Dependent of the analysis, to be reviewed:
	x_name<-"stim_1VSswarm"# Singificant varianle or at least tested variable
	xlabel_v<-"stim: 1 vs 25 fem"	
	var_name_inter <- c("vel_Max_diff_1s","avel_Max_diff_1s","wbf_Amax_diff_7s") # VAriable name for which we need an interaction plot (because the interaction or the second factor was found significant)
						# 0 if no other significant variable
		x2_name<-"stim_SPL_cat" # other significant variable	
		x2label_v<-"SPL (dB)"
	save_name<-"fcnX23_1vsSwarm-spl-effect"
	
	# No need to change:
	var_nam <- c("Y_Min_diff_7s","Y_Max_diff_7s","Z_Min_diff_7s","Z_Max_diff_7s","vel_Max_diff_1s","avel_Max_diff_1s","wbf_Amax_diff_7s")
	ylab_v <- c("Diff of min height (m)","Diff of max height (m)", "Diff of min dist to speaker (m)","Diff of max dist to speaker (m)","Diff of max lin-vel (m/s)","Diff of max ang-vel (rad/s)","Diff of max WBF (Hz)")
	outliersShape=23
	meanSize=0.3
	for (kk in seq(1,length(var_nam))){
		if (kk %in% seq(1,4)){
			ylim_v<- c(-0.4,0.4)
			}
		else{
			ylim_v<- c(min(data[,var_nam[kk]]),max(data[,var_nam[kk]]))
			}		
		
		if (all(var_nam[kk] %in% var_name_inter)) {
				eval(parse(text = paste("dp",kk,"<- ggboxplot(data[row,],y=var_nam[kk],x=x_name,color= x2_name,ylab= ylab_v[kk],xlab= xlabel_v,ylim=ylim_v,add=c(\"mean\",\"mean_se\"),add.params=list(size= meanSize), showWarnings = 0,las=2,outlier.shape= outliersShape)	+
				theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5)) +
				theme(legend.title = element_text(size = 7),
				        legend.text = element_text(size = 7),
				        legend.key.size =unit(.01, \"cm\"),
				        legend.box = \"vertical\" )+
			scale_fill_discrete(name = x2label_v) "
				        ,sep="")))	
				}	
		else{
			eval(parse(text = paste("dp",kk,"<- ggboxplot(data[row,],y=var_nam[kk],x=x_name,ylab= ylab_v[kk],xlab=xlabel_v,ylim=ylim_v,add=c(\"mean\",\"mean_se\"),add.params=list(size= meanSize), showWarnings = 0,las=2,outlier.shape= outliersShape)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))",sep="")))
			}					
	}
	ggarrange(dp1,dp2,dp3,dp4,dp5,dp6,dp7,
	          labels = c("A", "B", "C","D","E","F","G"),
	          ncol = 4, nrow = 2)
	ggsave(paste( subDir1,save_name,'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))











######## Statistical analysis: With synthetic coluzzii female stim, testing single versus swarm ############## 

row<- locationStim==1 & stim_type=='s' &  stim_sex=='f'  & stim_species=='c' & ds!='6.m'
# d!6 because the swarm stimulus is missingfor day 6  and we want to keep the same number of swarm and single stimulus
# only 1 harmonics

# Selected parameters
var_name="Y_Min_diff_7s"	# anova NS (p=0.15)
var_name="Y_Max_diff_7s"	# anova stim_1VSswarm p=0.028*, but none distrib sign diff from 0
var_name="Z_Max_diff_7s"	# anova  NS (p=0.4, chisq=0.7)
var_name="Z_Min_diff_7s"	# anova NS (p=0.2 chisq=1.4)
var_name="vel_Max_diff_1s"	# Anova stim_1VSswarm p=0.0060**						
							# 1-harm sign diff from 0 (p=0.02*)
var_name="avel_Max_diff_1s"	# Anova stim_1VSswarm p=0.00051***
							# 1-harm sign diff from 0 (p=0.04*)							
var_name="wbf_Amax_diff_7s"	# NS (p=0.12), chisq=2.4
							# both distrib sign diff from 0 (p=0.0045** for 1-harm, p=0.0071 for 2-harmn)

# Parameter which have a tendency by eye:
var_name="Y_Max_diff_1s"	# anova NS
var_name="Y_Max_diff_7s"	# anova stim_1VSswarm p=0.028*, but none distrib sign diff from 0
var_name="Y_Quant_diff_7s"	# 
var_name="Y_Min_diff_1s"	# 
var_name="Y_Min_diff_7s"	# anova NS (p=0.15)
var_name="Z_Max_diff_7s"	# anova  NS (p=0.4, chisq=0.7)
var_name="Z_Min_diff_7s"	# anova NS (p=0.2 chisq=1.4)
var_name="Z_Med_diff_7s"	# 
var_name="Z_Min_diff_1s"	# anova NS (p=0.07)
var_name="X_Sd_diff_1s"		# 

var_name="vel_Quant_diff_7s"# 
var_name="vel_Max_diff_1s"	# Anova stim_1VSswarm p=0.0060**						
							# 1-harm sign diff from 0 (p=0.02*)
var_name="vel_Sd_diff_7s"	# Anova stim_1VSswarm p=0.023* 
var_name="vel_Sd_diff_1s"	# Anova stim_1VSswarm p=0.0092**
var_name="avel_Max_diff_1s"	# Anova stim_1VSswarm p=0.00051***
							# 1-harm sign diff from 0 (p=0.04*)
var_name="avel_Quant_diff_7s"# 
var_name="avel_Sd_diff_1s"	#  Anova stim_1VSswarm p=0.0064**
var_name="wbf_Sd_diff_7s"	# NS
var_name="wbf_Sd_diff_1s"	# anov 0.0067**
var_name="wbf_Quant_diff_7s"# NS
var_name="wbf_Amax_diff_1s"	# anov stim_1VSswarm p=0.023*
var_name="wbf_Amax_diff_7s"	# NS (p=0.12), chisq=2.4
							# both distrib sign diff from 0 (p=0.0045** for 1-harm, p=0.0071 for 2-harmn)
var_name="wbf_Amin_diff_1s"	# NS
var_name="wbf_Med_diff_7s"	# NS (p=0.08)
var_name="wbf_Tamin_diff_7s"# 
var_name="wbf_Tamax_diff_7s"# NS

# == >effect ** of stim_1VSswarm in synthetic sound stimuli

# Create folder
subDir1="fig/"
subDir2=paste("f-c-s-X-1-3_",var_name,"/",sep="")
mainDir=getwd() 
dir.create(file.path(mainDir, subDir1))
dir.create(file.path(mainDir, subDir1,subDir2))

# Model redution with stim_SPL
mod<-blmer(eval(parse(text = var_name)) ~ stim_1VSswarm + (1|ds), data=data[row,],REML='false')
mod1<-update(mod,~.-stim_1VSswarm, data=data[row,]); anova(mod,mod1) 

# Boxplot
ggboxplot(data[row,],y= var_name,x="sti_SPLcat_1VSswarm",notch =TRUE,ylab= var_name,xlab="stim_SPLcat_1VSswarm",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fc_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))


# Commpare each distribution to 0
dd<- unique(sti_SPLcat_1VSswarm[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (sti_SPLcat_1VSswarm ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
p.adjust(pp,method="BH") # Adjust p-values


## Paper plot with selected parameters

	# Dependent of the analysis, to be reviewed:
	x_name<-"stim_1VSswarm"# Singificant varianle or at least tested variable
	xlabel_v<-"stim: 1 vs 25 fem"	
	var_name_inter <- 0 # VAriable name for which we need an interaction plot (because the interaction or the second factor was found significant)
						# 0 if no other significant variable
		x2_name<-"stim_SPL_cat" # other significant variable	
		x2label_v<-"SPL (dB)"
		save_name<-"fcsX13_1vsSwarm-effect"
	
	# No need to change:
	var_nam <- c("Y_Min_diff_7s","Y_Max_diff_7s","Z_Min_diff_7s","Z_Max_diff_7s","vel_Max_diff_1s","avel_Max_diff_1s","wbf_Amax_diff_7s")
	ylab_v <- c("Diff of min height (m)","Diff of max height (m)", "Diff of min dist to speaker (m)","Diff of max dist to speaker (m)","Diff of max lin-vel (m/s)","Diff of max ang-vel (rad/s)","Diff of max WBF (Hz)")
	outliersShape=23
	meanSize=0.3
	for (kk in seq(1,length(var_nam))){
		if (kk %in% seq(1,4)){
			ylim_v<- c(-0.4,0.4)
			}
		else{
			ylim_v<- c(min(data[,var_nam[kk]]),max(data[,var_nam[kk]]))
			}		
		
		if (all(var_nam[kk] %in% var_name_inter)) {
				eval(parse(text = paste("dp",kk,"<- ggboxplot(data[row,],y=var_nam[kk],x=x_name,color= x2_name,ylab= ylab_v[kk],xlab= xlabel_v,ylim=ylim_v,add=c(\"mean\",\"mean_se\"),add.params=list(size= meanSize), showWarnings = 0,las=2,outlier.shape= outliersShape)	+
				theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5)) +
				theme(legend.title = element_text(size = 7),
				        legend.text = element_text(size = 7),
				        legend.key.size =unit(.01, \"cm\"),
				        legend.box = \"vertical\" )+
			scale_fill_discrete(name = x2label_v) "
				        ,sep="")))	
				}	
		else{
			eval(parse(text = paste("dp",kk,"<- ggboxplot(data[row,],y=var_nam[kk],x=x_name,ylab= ylab_v[kk],xlab=xlabel_v,ylim=ylim_v,add=c(\"mean\",\"mean_se\"),add.params=list(size= meanSize), showWarnings = 0,las=2,outlier.shape= outliersShape)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))",sep="")))
			}					
	}
	ggarrange(dp1,dp2,dp3,dp4,dp5,dp6,dp7,
	          labels = c("A", "B", "C","D","E","F","G"),
	          ncol = 4, nrow = 2)
	ggsave(paste( subDir1,save_name,'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))









######## Statistical analysis: With coluzzii female stim, testing syntetic versus natural sound, single/group
# stim SPL (natural, single fem) = 25±0.9dB
# stim SPL (natural, fem swarm) = 33±0.5dB
# stim SPL (synthetic, single fem) = 26±0.2dB
# stim SPL (synthetic, fem swarm) = 31.2±0.4dB
# ==> pour les mles on est intéressé par les single females stimuli, qui sont 25±0.9 et 26±0.2 dB
row<- locationStim==1 & stim_NumbHarmonics==1 &  stim_sex=='f'  & stim_species=='c'

# Selected parameters
var_name="avel_Max_diff_1s"	# anova stim_1VSswarm p=0.02*
	# Distribution statistics compared to intercept:
	# [1] "one-sample t(9)=2.62745 p=0.02747 mean=3.61"
	# [1] "one-sample t(9)=0.7964 p=0.4463 mean=1.39"
	# [1] "one-sample t(9)=3.13284 p=0.01207 mean=5.51"
	# [1] "one-sample t(8)=0.30332 p=0.76939 mean=0.6"
	# > p.adjust(pp,method="BH") # Adjust p-values
	# [1] 0.05494656 0.59506307 0.04826542 0.76938625
	# [1] n.sgl n.grp s.sgl s.grp
var_name="wbf_Amax_diff_7s"	# anova stim_1VSswarm p=002**
	# Distribution statistics compared to intercept:
	# [1] "one-sample t(9)=6.95075 p=7e-05 mean=53.97"
	# [1] "one-sample t(9)=4.55923 p=0.00137 mean=23.11"
	# [1] "one-sample t(9)=4.8226 p=0.00094 mean=41.49"
	# [1] "one-sample t(8)=3.59172 p=0.00707 mean=26.57"
	# > p.adjust(pp,method="BH") # Adjust p-values
	# [1] 0.0002671624 0.0018236964 0.0018236964 0.0070667513
	# [1] n.sgl n.grp s.sgl s.grp	


var_name="Y_Min_diff_7s"	# anova stim_type: stim_1VSswarm p=0.02*,
var_name="Y_Max_diff_7s"	# anova stim_type:stim_1VSswarm p=0.03*,
var_name="Z_Max_diff_7s"	# anovas NS
var_name="Z_Min_diff_7s"	# anovas NS
var_name="vel_Max_diff_1s"	# anova stim_type p=0.02*, stim_1VSswarm p=0.01*


=> no effect of synth/natural

# Create folder
subDir1="fig/"
subDir2=paste("f-c-X-1-1-3_",var_name,"/",sep="")
mainDir=getwd() 
dir.create(file.path(mainDir, subDir1))
dir.create(file.path(mainDir, subDir1,subDir2))

# Model redution
mod<-blmer(eval(parse(text = var_name)) ~ stim_type* stim_1VSswarm + (1|ds), data=data[row,],REML='false')
mod1<-update(mod,~.-stim_type: stim_1VSswarm, data=data[row,]); anova(mod,mod1) 

library(car)
Anova(mod,type=3)

mod2test<-update(mod1,~.-stim_1VSswarm); 	anova(mod1,mod2test)
mod2test<-update(mod1,~.-stim_type); 	anova(mod1,mod2test)

mod2<-	  update(mod1,~.-stim_1VSswarm); anova(mod1,mod2)
mod3<-	  update(mod2,~.-stim_type);		anova(mod2,mod3)

mod2<-	  update(mod1,~.-stim_type); 	anova(mod1,mod2)
mod3<-	  update(mod2,~.-stim_1VSswarm); anova(mod2,mod3)


# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_type",color="stim_1VSswarm",notch =TRUE,ylab= var_name,xlab="stim_type",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fc_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))

# Commpare each distribution to 0
dd<- unique(stim_type[row])
pp<-0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_type ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
	print(paste("one-sample t(",round(tt$parameter,5),")=",round(tt$statistic,5)," p=",round(tt$p.value,5)," mean=",round(tt$estimate,2),sep=""))
}
p.adjust(pp,method="BH") # Adjust p-values

# Commpare each distribution to 0
data$stim_type_1VSswarm <- interaction(stim_type, stim_1VSswarm)
attach(data)
dd<- unique(stim_type_1VSswarm[row])
pp<-0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_type_1VSswarm ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
	print(paste("one-sample t(",round(tt$parameter,5),")=",round(tt$statistic,5)," p=",round(tt$p.value,5)," mean=",round(tt$estimate,2),sep=""))
}
p.adjust(pp,method="BH") # Adjust p-values
print(dd)







######## Statistical analysis: With coluzzii female stim, testing syntetic versus natural sound ############## 
# stim SPL (natural, single fem) = 25±0.9dB
# stim SPL (natural, fem swarm) = 33±0.5dB
# stim SPL (synthetic, single fem) = 26±0.2dB
# stim SPL (synthetic, fem swarm) = 31.2±0.4dB
# ==> pour les mles on est intéressé par les single females stimuli, qui sont 25±0.9 et 26±0.2 dB
row<- locationStim==1 & stim_NumbHarmonics==1 &  stim_sex=='f'  & stim_species=='c' & stim_1VSswarm=='sgl'

# Selected parameters
var_name="Y_Min_diff_7s"	# anova stim_type p=0.048*, none distrib sign diff (natural p=0.07, synthetic p=0.06)
var_name="Y_Max_diff_7s"	# anova stim_type p=0.038*, none distrib sign diff (natural p=0.2, synthetic p=0.06)
var_name="Z_Max_diff_7s"	# anova stim_type p=0.038*, none distrib sign diff (natural p=0.2, synthetic p=0.2)
var_name="Z_Min_diff_7s"	# anova stim_type NS (p=0.6,chisq=0.3), none distrib sign diff (both p=0.8)
var_name="vel_Max_diff_1s"	# anova stim_type NS (p=0.07, chisq=3.2), natural dist p=0.2, synthetic dist p=0.03*
var_name="avel_Max_diff_1s"	# anova stim_type NS (p=0.4, chisq=0.8), both distrib p=0.03*
var_name="wbf_Amax_diff_7s"	# anova stim_type NS (p=0.3, chisq=1.3), natural dist p=0.0001***, synthetic dist p=0.0009***

=> no effect of synth/natural

# Create folder
subDir1="fig/"
subDir2=paste("f-c-X-1-1-3_",var_name,"/",sep="")
mainDir=getwd() 
dir.create(file.path(mainDir, subDir1))
dir.create(file.path(mainDir, subDir1,subDir2))

# Model redution
mod<-blmer(eval(parse(text = var_name)) ~ stim_type + (1|ds), data=data[row,],REML='false')
mod1<-update(mod,~.-stim_type, data=data[row,]); anova(mod,mod1) 

# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_type",color="stim_1VSswarm",notch =TRUE,ylab= var_name,xlab="stim_type",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"fc_perSPL",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))

# Commpare each distribution to 0
dd<- unique(stim_type[row])
pp=0
for (i in 1:length(dd)){
	# compare distribution of a particular SPL to 0 (Steven Young method)
	tt<- t.test( data[row & (stim_type ==dd[i]), colnames(data)==var_name ] ) 
	pp[i]<- tt$p.value
}
dd
p.adjust(pp,method="BH") # Adjust p-value



## Paper plot with selected parameters

	# Dependent of the analysis, to be reviewed:
	x_name<-"stim_type"# Singificant varianle or at least tested variable
	xlabel_v<-"Synth vs Natural"	
	var_name_inter <- 0 # VAriable name for which we need an interaction plot (because the interaction or the second factor was found significant)
						# 0 if no other significant variable
		x2_name<-"stim_SPL_cat" # other significant variable	
		x2label_v<-"SPL (dB)"
		save_name<-"fcX113_synthVSnatural-effect"
	
	# No need to change:
	var_nam <- c("Y_Min_diff_7s","Y_Max_diff_7s","Z_Min_diff_7s","Z_Max_diff_7s","vel_Max_diff_1s","avel_Max_diff_1s","wbf_Amax_diff_7s")
	ylab_v <- c("Diff of min height (m)","Diff of max height (m)", "Diff of min dist to speaker (m)","Diff of max dist to speaker (m)","Diff of max lin-vel (m/s)","Diff of max ang-vel (rad/s)","Diff of max WBF (Hz)")
	outliersShape=23
	meanSize=0.3
	for (kk in seq(1,length(var_nam))){
		if (kk %in% seq(1,4)){
			ylim_v<- c(-0.4,0.4)
			}
		else{
			ylim_v<- c(min(data[,var_nam[kk]]),max(data[,var_nam[kk]]))
			}		
		
		if (all(var_nam[kk] %in% var_name_inter)) {
				eval(parse(text = paste("dp",kk,"<- ggboxplot(data[row,],y=var_nam[kk],x=x_name,color= x2_name,ylab= ylab_v[kk],xlab= xlabel_v,ylim=ylim_v,add=c(\"mean\",\"mean_se\"),add.params=list(size= meanSize), showWarnings = 0,las=2,outlier.shape= outliersShape)	+
				theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5)) +
				theme(legend.title = element_text(size = 7),
				        legend.text = element_text(size = 7),
				        legend.key.size =unit(.01, \"cm\"),
				        legend.box = \"vertical\" )+
			scale_fill_discrete(name = x2label_v) "
				        ,sep="")))	
				}	
		else{
			eval(parse(text = paste("dp",kk,"<- ggboxplot(data[row,],y=var_nam[kk],x=x_name,ylab= ylab_v[kk],xlab=xlabel_v,ylim=ylim_v,add=c(\"mean\",\"mean_se\"),add.params=list(size= meanSize), showWarnings = 0,las=2,outlier.shape= outliersShape)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))",sep="")))
			}					
	}
	ggarrange(dp1,dp2,dp3,dp4,dp5,dp6,dp7,
	          labels = c("A", "B", "C","D","E","F","G"),
	          ncol = 4, nrow = 2)
	ggsave(paste( subDir1,save_name,'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))























########## Archive for R exemples	
	
######## Statistical analysis: avel_Max_1s_diff ############## 
# (WBF standard deviation difference between stimulus ans no stimulus over 1s-analysis window)

# Parameter to study:
var_name="avel_Max_1s_diff"	

# If we consider a parameter computed from the diff between no-stimulus ans stimulus (its name finishes by _diff), then we only keep the values for locationStim==1 as we already have the reference inside each parameter value locationStim==0 for the reference (without using locationStim, since locationStim==0 is already coded in  stim_SPL (lowest value))
# Else, we keep 
#if ( substr(var_name,nchar(var_name)-3,nchar(var_name)) =="diff"){
#	row<-stim_type=='n' & stim_NumbHarmonics!='1' & stim_1VSswarm=='grp' &  locationStim==1
#} else { 
	row<-stim_type=='n' & stim_NumbHarmonics!='1' & stim_1VSswarm=='grp'
#}

# Interaction variable for multicomparison
data$stim_SPLsex <- interaction(  list(as.factor(stim_SPL), stim_sex))
data$stim_SPLsexSpp <- interaction(  list(as.factor(stim_SPL), stim_sex,stim_species))
data$stim_SPLspp <- interaction(  list(as.factor(stim_SPL),stim_species))
data$stim_SPL_fact<-as.factor(stim_SPL)
ordered(data$stim_SPL_fact)
#data$stim_SPL_fact_grp <- fct_other(stim_SPL_fact, drop = c("20.4","25.8","36.2"),other_level="20.4-25.8-36.2")
#data$stim_SPL_fact_grp <- factor(data$stim_SPL_fact_grp,ordered=FALSE)
attach(data)

# Create folder
subDir1="fig/"
subDir2=paste("X-X-n-2-2a-X_",var_name,"/",sep="")
mainDir=getwd() 
dir.create(file.path(mainDir, subDir1))
dir.create(file.path(mainDir, subDir1,subDir2))

# Model redution
mod<-blmer(eval(parse(text = var_name)) ~ stim_SPL*stim_sex*stim_species +(1|d),REML=FALSE, data=data[row,]) 
mod1<-update(mod,~. -stim_SPL:stim_sex: stim_species); 	anova(mod1,mod) #p=1
mod2test<-update(mod1,~. -stim_SPL: stim_sex) ; 		anova(mod1, mod2test) # p=0.4
mod2test<-update(mod1,~. -stim_sex: stim_species); 		anova(mod1, mod2test) # p=0.02*
mod2test<-update(mod1,~. -stim_SPL: stim_species) ; 	anova(mod1, mod2test) # p=0.07
mod2<-update(mod1,~. -stim_SPL: stim_sex); 
mod3test<-update(mod2,~. -stim_sex: stim_species) ; 		anova(mod2, mod3test) # p=0.02*
mod3test<-update(mod2,~. -stim_SPL: stim_species) ; 	anova(mod2, mod3test) # p=0.07
mod3<-update(mod2,~. -stim_SPL: stim_species); 
mod4test<-update(mod3,~. -stim_sex: stim_species) ; 	anova(mod3, mod4test) # p=0.02*
# mod4<-update(mod3,~. -stim_SPL: stim_sex); 
# mod5test<-update(mod4,~. -stim_SPL) ; 	anova(mod4, mod5test) # p=0.002**
# mod5test<-update(mod4,~. -stim_species) ; 	anova(mod4, mod5test) # p=0.2
# mod5test<-update(mod4,~. -stim_sex) ; 	anova(mod4, mod5test) # p=0.5
# mod5<-update(mod4,~. -stim_sex) ; 
# mod6test<-update(mod5,~. -stim_SPL) ; 	anova(mod5, mod6test) # p=0.002**
# mod6test<-update(mod5,~. -stim_species) ; 	anova(mod5, mod6test) # p=0.2
# mod6<-update(mod5,~. -stim_species) ; 
# mod7test<-update(mod6,~. -stim_SPL) ; 	anova(mod6, mod7test) # p=0.002**. 
 library(car)
 Anova(mod3,type=3)
	 # (Intercept)           2.1251  1   0.144905   
	# stim_SPL              7.1803  1   0.007371 **
	# stim_sex              0.8320  1   0.361702   
	# stim_species          1.9762  1   0.159788   
	# stim_sex:stim_species 5.7110  1   0.016859 * 

if ( substr(var_name,nchar(var_name)-3,nchar(var_name)) =="diff"){ # ie we can make comparison to a single distribution (which is a 0-ditribution)
	# If SPL only efffect:
	#mod_glt <- blmer(eval(parse(text = var_name)) ~ stim_SPL_fact  +(1|d) ,REML=FALSE, data=data[row,])
	#glht <- glht(mod_glt, linfct = mcp(stim_SPL_fact ="Dunnet")) 
	# If SPL, sex and spp effects (or interaction):
	mod_glt <- blmer(eval(parse(text = var_name)) ~ stim_SPLsexSpp  +(1|d) ,REML=FALSE, data=data[row,])
	glht <- glht(mod_glt, linfct = mcp(stim_SPLsexSpp ="Dunnet")) 
	# If both SPL and sex effects (or interaction):
	#mod_glt <- blmer(eval(parse(text = var_name)) ~ stim_SPLsex  +(1|d) ,REML=FALSE, data=data[row,])
	#glht <- glht(mod_glt, linfct = mcp(stim_SPLsex ="Dunnet")) 
	# If both SPL and spp effects (or interaction):	
	#mod_glt <- blmer(eval(parse(text = var_name)) ~ stim_SPLspp  +(1|d) ,REML=FALSE, data=data[row,])
	#glht <- glht(mod_glt, linfct = mcp(stim_SPLspp ="Dunnet")) 
	print(summary(glht))
	# very few significant and not interesting
	# 17.1.f.c - 6.9.f.c == 0 -2.77299    1.44603  -1.918   0.5796  
	# 23.1.f.c - 6.9.f.c == 0 -3.11539    1.44603  -2.154   0.3896  
	# 32.9.f.c - 6.9.f.c == 0  1.49779    1.50917   0.992   0.9980  
	# 44.9.f.c - 6.9.f.c == 0  4.92433    1.50914   3.263   0.0196 *
	# 6.9.m.c - 6.9.f.c == 0   0.04102    0.92874   0.044   1.0000  
	# 20.4.m.c - 6.9.f.c == 0  1.47199    1.41220   1.042   0.9963  
	# 25.8.m.c - 6.9.f.c == 0 -0.45130    1.46448  -0.308   1.0000  
	# 36.2.m.c - 6.9.f.c == 0  0.97293    1.36414   0.713   1.0000  
	# 48.m.c - 6.9.f.c == 0    3.70277    1.41220   2.622   0.1352  
	# 6.9.f.g - 6.9.f.c == 0   0.01360    0.94022   0.014   1.0000  
	# 16.2.f.g - 6.9.f.c == 0  1.64534    1.50957   1.090   0.9939  
	# 22.2.f.g - 6.9.f.c == 0  4.64323    1.44603   3.211   0.0233 *
	# 32.4.f.g - 6.9.f.c == 0  0.68599    1.50957   0.454   1.0000  
	# 44.f.g - 6.9.f.c == 0    0.52575    1.50917   0.348   1.0000  
	# 6.9.m.g - 6.9.f.c == 0   0.08824    0.91275   0.097   1.0000  
	# 20.3.m.g - 6.9.f.c == 0 -2.56468    1.36414  -1.880   0.6110  
	# 25.m.g - 6.9.f.c == 0   -1.76270    1.36414  -1.292   0.9659  
	# 35.7.m.g - 6.9.f.c == 0 -3.26462    1.40909  -2.317   0.2802  
	# 47.6.m.g - 6.9.f.c == 0  2.50600    1.36414   1.837   0.6469  		                
}


# Boxplot
ggboxplot(data[row,],y= var_name,x="stim_SPLsexSpp",color="sex",notch =TRUE,ylab= var_name,xlab="stim_SPLsex",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
ggsave(paste( subDir1, subDir2,"perSPLsexSpp",'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))

# Alternative method with data subset (?)
# IF SPL is a singificant factors (any order):
	row2 <- row & stim_species=='c'
	
	# Multicomparison (female only)  --> can be done only if SPL is significant factor
	multi_SPLsex_SPL(data,row2,'f',var_name,paste(subDir1,subDir2,sep=""),'Dunnet')
		# mixed-model anova stim_SPL: p=0.04*
	# 20.4 - 6.9 == 0   1.4215     1.4077   1.010   0.7652  
	# 25.8 - 6.9 == 0  -0.5409     1.4653  -0.369   0.9925  
	# 36.2 - 6.9 == 0   0.9897     1.3627   0.726   0.9139  
	# 48 - 6.9 == 0     3.6523     1.4077   2.594   0.0367 * --> fem can. hear 48±2dB col stim
	
	# Multicomparison (male only) --> can be done only if SPL is significant factor
	multi_SPLsex_SPL(data,row2,'m',var_name,paste(subDir1,subDir2,sep=""),'Dunnet')
		# mixed-model anova stim_SPL: p=0.004**
	# 17.1 - 6.9 == 0   -2.787      1.114  -2.503   0.0475 *  --> male can. hear 17.1±2dB col stim	   (decrease of angular vel)
	# 23.1 - 6.9 == 0   -3.130      1.114  -2.810   0.0194 *  --> male can. hear 23.1!=2dB col stim		(decrease of angular vel)	
	# 32.9 - 6.9 == 0    1.520      1.163   1.307   0.5582    
	# 44.9 - 6.9 == 0    4.934      1.163   4.244   <1e-04 *** --> male can. hear 44.9±2dB col stim		(increase of angular vel)

# IF species is a sinigicant factor (any order), we can look for species effect on females:
	row2 <- row & data$sex== 'f' & locationStim==1
	mod_glt <- blmer(eval(parse(text = var_name)) ~ stim_SPLspp  +(1|d) ,REML=FALSE, data=data[row2,])
	glht <- glht(mod_glt, linfct = mcp(stim_SPLspp ="Tukey")) 
	print(summary(glht)) 
	# Nothing significant
	
	# sex_s<-as.character(unique(data$sex[row2]))	
	# # ggboxplot(data[row2,],y= var_name,x="stim_species",color="stim_SPL_fact",notch =TRUE,ylab= var_name,xlab="stim_SPL",add=c("mean","mean_se"),add.params=list(size=0.8), showWarnings = 0,las=2)	+   theme(axis.text.x=element_text(angle=90,hjust=1,vjust=0.5))
	# # ggsave(paste( paste(subDir1,subDir2,sep=""),"perSPLspp_",sex_s,'_',format(Sys.time(), "%y%m%d" ),".png",sep="" ))
	
	




######################## DOC ##############################
## Mixed-model
#Tu as fais tes manipes à des jours différents. Il peut y avoir
#une variabilité que tu ne maitrise pas (lot de stique, pression atmo,  ...)
#et qui peut contenir une part de ta variabilité de la réponse. Il faut en 
#tenir compte. ca s'appel un effet aleatoir (random effect). il faut 
#l'introduire dans ton model sinon tu auras des pseudo réplications =
# surestimation du nombre de réplicats réel et nombre de degré de liberté 
#trop grand. tu ne peux pas faire d'anova mais le principe est le même. 
#ce n'est qu'une variante de l'anova = model mixte

# LMER arguments / grammar
	# REM should be set to false (i.e. ML , ie. maximum likelihood) if we want to use the models in Anova (cf Crawley The R book p.636)
	# ":" que les interactions; "*" = factor + factor interactions


# mod<-lmer(poupou ~ koukou +(1|d),REML=FALSE) # ":" que les interactions; "*" = cross effects
# mod1<-lm(poupou ~ koukou +d) # only with the day as effect (random)
# anova(mod1,mod)
# Singitficatif =>  what could be got out of it?
 # First, this method is said to be anti-conservative (Statistician Steven Young, see slides from Ulrich Halekoh  &  Søren Højsgaard)
 # If significant, it means that the removed variable (fixed or random) should be taken into account, as mod1 significantly differnet from mod2
 # Aparemment c'est compliqué les mixed models pour avoir des p-values, genre faire un anova(mod) puis faire confiance aux p-values
 # Comparer 2 modèles en utilisant ANova (anova(mod1,mod) ) semble ok (c'est ce que fait Crawley dans son R book) ; Statistician Steven Young dit que c'est moins conservatif que d'utiliser anova(mod0) pour tester la singificativité d'une variable donnée. See below.
 # library(lmerTest) # allows to get p-values: The lmerTest package overloads the lmer function, so you can just re-fit the model using exactly the same code, but the summary() will now include approximate degrees of freedom and p-values. More conservative method according to Statistician Steven Young
                       

# To see the effect of a particular variable before simplificating the model:
plot(effect(mod=mod_T3,term="stim_species"), ylab="", xlab="",main="",asp=1)

# Model simplification	(Olivier Roux)
 - remove the variable 1 by 1, by starting by the highest-order interaction
 - when removing 1 of the interaction of a same order level makes a different to the model, stop there, and from the previous model, do
 library(car)
 Anova(mod,type=3)
 
 
 ###### MICHALENOUS ###### 
# For each factor:
library(car)
qqPlot(wbf_Sd_1s_diff[locationStim==1],distribution="norm",stim_soundLevel[locationStim==1])   
qqPlot(wbf_Amax_1s_diff[locationStim==1],distribution="norm",stim_soundLevel[locationStim==1])   
## Normality test
# A normality test does not have much sense if N~<30 (Steven)
# A test for normality should not be preocessed for the full set of data, but either on the model residu, or for each factor
# shapiro.test(mean_wbf_Amax) # 
# Homogenéité des variances des variabes explicatives ; 
fligner.test(wbf_Amax_7s_diff,stim)    #X²= 42, df = 23, p-value = 0.009


library(car)

qqPlot(wbf_Amax_1s)                   
shapiro.test(wbf_Amax_1s_diff)
dotchart(wbf_Amax_1s,groups=stim_sex) 
shapiro.test(wbf_Amax_1s)